/*=========================================================================
Project: Wealth, marriage and sex selection
Author: Girija Borker, Jan Eeckhout, Nancy Luke, Shantidani Minz, Kaivan Munshi and Soumya Swaminathan. 
---------------------------------------------------------------------------
Do file: 0_master.do

=========================================================================*/

*******************************************
*** SET ENVIRONMENT ***
*******************************************

	version 16
	clear all
	set maxvar 32767
	set more off
	set varabbrev on
	*cap ssc install dm79

	* change this global to your own file path to the 'sex-selection-india' folder.
	global sexselection "....." 

	
	* Working directory
	cd "$sexselection"
	
	* Global to folders
	global stata "${sexselection}/code/stata"
	global subcode "${stata}/subcode"
	global data "${sexselection}/data"
	global raw "${data}/raw"
	global coded "${data}/coded"
	global out "${sexselection}/output"
	
	* Setting the ado path with required packages
	sysdir set PLUS "${stata}/ado"
	
	/* Install packages
	ssc install ttable2
	ssc install matsave
	ssc install reghdfe
	ssc install ftools
	ssc install listtab
	ssc install dm79
	ssc install gtools
	*/
	
	* Start log
	cap log close
	log using "${sexselection}/log_sexselection.txt", replace text

*******************************************
*** CLEAN and CODE RAW DATA ***
*******************************************

	* cleans the raw data
	do "${stata}/1_master_cleaning.do" // MasterCleaning_22092015.do

	* identify chidren in the HH
	do "${stata}/2_identifying_children.do" // Identifying_children_swgsb.do

	* identify HH structure 
	do "${stata}/3_hh_structure.do" // HH_structure_1711.do
		
	* clean historical data
	do "${stata}/4_adding_historical_data.do" // adding_historical_data0311.do
		
*******************************************
*** PREPARE DATA FOR ANALYSIS ***	
*******************************************

	* merge family structure variables and historical data to create final data for analysis - currently named DataForReg
	do "${stata}/5_dataprep.do" // Bs_dataprep_0311.do
		
	* create ranks and variables for analysis

*******************************************
*** HYPERGAMY AND RELATIVE WEALTH *** 
*******************************************

	* (Table 2, Figure 5a (vDec2021))
	* crates table regressing relative income and education of groom on relative wealth and education of bride
	do "${stata}/6_hypergamy_analyses_with_histdata.do" // 2018-01-30_Hypergamy_Analyses_with_Hist1871Data_FINAL.do

*******************************************	
*** SEX SELECTION AND WEALTH ***
*******************************************
	
	* run the main bootstrap regressions for all kids under 6 (for table)
	* Table 6 (vDec2021) // do boot_breg_2020-11-12.do
	do "${stata}/7_bootstrap_breg_ar.do" // bootstrap_breg_2023-07-28 
	
	* Most recent - updated!!
	do "${stata}/8_robinson_newpredinc_castefe_lpoly_v2.do" // robinson_villagefe.do
		
	* Sex selection with all HH and HH with atleast one under 6 [Figure 6a (vDec2021); 6b to be deleted]
	do "${stata}/9_robinson_lowess_hh_withunder6_server.do" // robinson_HH_withunder6_server.do - needs to be changed to lowess
	
	* run the benchmark robinson regression with control function
	do "${stata}/10_OLS_robinson.do" // robinson_2020-10-03_server.do - 
		
	* Sex selection across age groups: Figure 7a	
	do "${stata}/11_robinson_lowess_over7.do" // robinson_2020-10-03_over7.do
		
	* Sex selection across birth order: Figure 7b	
	do "${stata}/12_robinson_firstborn_lowess_server.do" // robinson_2020-10-03_firstborn_server.do
		
	* Sex selection and relative wealth, Caste by caste: Figire 9a and 9b
	do "${stata}/13_lpoly_castebycaste_final.do" // lpoly_castebycaste.do - needs to be updated to lowess
	
******************* CONTINUE TO MASTER_2.m IN MATLAB ***************************