/*=========================================================================
Project: Wealth, marriage and sex selection
Author: Girija Borker, Jan Eeckhout, Nancy Luke, Shantidani Minz, Kaivan Munshi and Soumya Swaminathan. 
---------------------------------------------------------------------------
Do file: 3_master.do

=========================================================================*/

*******************************************
*** SET ENVIRONMENT ***
*******************************************

	version 16
	clear all
	set maxvar 32767
	set more off
	set varabbrev on
	*cap ssc install dm79

	* change this global to your own file path to the 'sex-selection-india' folder.
	global sexselection "......" 

	
	* Working directory
	cd "$sexselection"
	
	* Global to folders
	global stata "${sexselection}/code/stata"
	global subcode "${stata}/subcode"
	global data "${sexselection}/data"
	global raw "${data}/raw"
	global coded "${data}/coded"
	global out "${sexselection}/output"
	
	* Setting the ado path with required packages
	sysdir set PLUS "${stata}/ado"
	mata: mata mlib index // added by Luise to solve an error in do-file 20
	
*******************************************
*** TABLES WITH SELECTED SAMPLES ***	
*******************************************

	* cross validation with control function: Figure 8a and 8b
	* mean forecast sum of squared errors: Table A3
	do "${stata}/14_cross_validation_edit.do" // cross_validation_edit.do DONE

	* Marriage Patterns - uses HH survey data: Table 1
	
	do "${stata}/15_marriage_analysis_ar1.do" // MarriageAnalysis_2205.do - to be cleaned up and esttab code written to look like Table 1 (vDec2021) in paper DONE
	
*********************************************
*** DOWRY
*********************************************

	* Dowry and Relative wealth: Table 4 and Figure 4, Figure 3
	do "${stata}/16_dowry_income_analysis.do" // Dowry_Income_Analyses_FINAL.do - need to update to new robinson DONE		
	
*******************************************
*** Appendix Tables and Figures ***
*******************************************

		* Comparison of Demographic and Socioeconomic Characteristics: Table A1
		do "${stata}/17_table_A1" // DONE
			
		* Age diff between husband and wife by birth cohorts: Figure A1
		* Proportion married by age: Figure A2
		* Variation in age at marriage by relative wealth: Figure A3
		* Variation in spousal age gap by relative wealth: Figure A4
		do "${stata}/18_age_diff_prop_married.do" // age_diff_prop_married.do DONE
		
		* School enrollment and sex selection-india
		do "${stata}/19_hsc_enroll.do" //DONE
		
		* Sex ratios
		do "${stata}/20_sex_ratios.do" // DONE
	
*******************************************
*** MATLAB CODE *** 
*******************************************

	* Structural parameter estimates
		
	* Data for tables / figures crated in Matlab
		* Figure 1
		* Figure 2
		* Figure 10
		* Table 7

	* Final tables / figures created in Stata
	do "${stata}/21_structural_figures.do" // structural_figures.do DONE

	* Close log
	cap log close