function newX = interpolateFullHistogramData(mydata, req_classes)
% interpolateFullHistogramData - Interpolates inc, m, f, t, csr, Hk, X to req_classes bins.
% Input:
%   mydata - Nx7 matrix with columns: [inc, m, f, t, csr, Hk, X]
% Output:
%   newX - req_classesx7 matrix with interpolated values and preserved relationships

    % Extract columns
    inc = mydata(:, 1);
    t   = mydata(:, 4);
    csr = mydata(:, 5);

    % New inc values (req_classes bins)
    new_inc = linspace(min(inc), max(inc), req_classes);

    % Interpolate t and csr
    interp_t = interp1(inc, t, new_inc, 'linear');
    interp_csr = interp1(inc, csr, new_inc, 'linear');

    % Normalize t to preserve original sum
    total_t_orig = sum(t);
    scale_factor = total_t_orig / sum(interp_t);
    t_new = interp_t * scale_factor;

    % Recalculate m and f from t and csr
    m_new = (interp_csr ./ (interp_csr + 1)) .* t_new;
    f_new = t_new - m_new;

    % Compute x = t / 2
    x_new = t_new / 2;

    % Compute Hk = (csr - 1) / (csr + 1)
    hk_new = (interp_csr - 1) ./ (interp_csr + 1);

    % Combine all into output
    newX = [new_inc' m_new' f_new' t_new' interp_csr' hk_new' x_new'];
end
