function [ diff, uxx, uyy, dy, dgiven, S, T, ky, ks, Hky] = set_vin( din, Q, X, Y )
%set_vin Function to set initial value of v(x)
%   This function solves the model to get a value of v(x) for the last
%   matched boy and the income xbar of this boy.

if numel(Q)==4
    a = Q(1);
    phi0 = 0.0;
    v0 = Q(2);
    beta = Q(3);
    mo_x = Q(4);
    mo_y = 80.0;
end

persistent vxx

H = makedist('Uniform','lower',0,'upper',a);

n = length(X); %Number of income classes
x = n;
y = n;
S(:,1) = (2 * (log(X(:,1)/2))) + v0 - mo_x;
T(:,1) = (2 * (log(Y(:,1)/2))) + phi0 - mo_y;

d = din*Y(y,1);

Cx = (X(x,1)+d) * (beta/2);
cx = (X(x,1)+d) * (beta/2);

if Cx<0 || cx<0
    diff=nan;
    disp('error neg cx');
    return
end

vin = log(Cx) + log(cx) + v0;
ky = zeros(n,1);
Hky = zeros(n,1);
ks = zeros(n,n);

if vin<0
    diff = nan;
    disp('error neg vin');
    return
end

if isempty(vxx)
    disp('new vxx')
    din
    vxx = zeros(n,1);
    vxx(x) = vin;
    delta = (vin-S(1))/(n-1);
    for i=n-1:-1:1
        vxx(i) = vxx(i+1)-delta*0.0;
    end
    disp(vxx)
end


vyy(:,1) = Y(:,1);
dy(:,1) = X(:,1);
dgiven(:,1) = X(:,1);
dgiven(:,2) = zeros(n,1);
dgiven(:,3) = zeros(n,1);
dy(x,2) = d;

Cy = Y(y,1) - d;
cy = (X(x,1) + d) * (1-beta);

if Cy<0 || cy<0
    diff=nan;
    disp('error neg cy');
    return
end

vyy(y,2) = log(Cy) + log(cy);
vxx(x) = log(Cx) + log(cx) + v0;


kstr = vxx(y) - vyy(y,2);
ky(y) = kstr;
Hk = cdf(H,kstr);
Hky(y) = Hk;
X(y,2) = X(y,2) + Hk*Y(y,2);
Y(y,2) = Y(y,2) * (1 - Hk);
dgiven(y,2) = d * Y(y,2);
dgiven(y,3) = Y(y,2);
ks(y,x) = kstr;

X(x,2) = X(x,2) - Y(y,2);
if X(x,2)>=0
    Y(y,2) = 0;
end

negflag=0;
yflag=0;

while y>0
    while X(x,2)>=0
        y = y-1;
        if y==0
            yflag=1;
            break
        end

        Cy = Y(y,1) - dy(x,2);
        cy = (X(x,1) + dy(x,2)) * (1-beta);
        if Cy<0 || cy<0
            negflag=1;
            break
        end
        
        vyy(y,2) = log(Cy) + log(cy);

        if vyy(y,2)<0 || ~isreal(vyy(y,2))
            negflag=1;
            break
        end
        
        kstr = vxx(y) - vyy(y,2);
        ky(y) = kstr;
        Hk = cdf(H, kstr);
        Hky(y) = Hk;
        X(y,2) = X(y,2) + Hk*Y(y,2);
        Y(y,2) = Y(y,2) * (1 - Hk);
        
        ks(y,x) = kstr;
        if (Y(y,2) < X(x,2))
            dgiven(y,2) = dgiven(y,2) + (dy(x,2) * Y(y,2));
            dgiven(y,3) = dgiven(y,3) + Y(y,2);
        elseif (Y(y,2) > X(x,2))
            dgiven(y,2) = dgiven(y,2) + (dy(x,2) * X(x,2));
            dgiven(y,3) = dgiven(y,3) + X(x,2);
        end

        X(x,2) = X(x,2) - Y(y,2);
        if X(x,2)>=0
            Y(y,2) = 0;
        end
    end
    if negflag==1
        break
    end

    if yflag==1
        break
    end

    Y(y,2) = (-1) * X(x,2);
    x = x-1;
    if x==0
        break
    end
    vxsolver = @(v) real(my_phi(v,vyy(y,2),X(x,1),Y(y,1),beta,v0));


    fsolve_options = optimoptions('fsolve', 'Display','off', 'MaxFunctionEvaluations', 500, 'MaxIterations', 800);
    [z, fval, outputflag, ~] = fsolve(vxsolver, vxx(x+1), fsolve_options);
    if outputflag<0
        negflag=1;
        break
    end
    if fval>1e-3
        negflag=1;
        break
    end
    vxx(x)=z;
    
    epower = (vxx(x) - v0)/2;
    eterm = (2 * exp(epower))/beta;
    dy(x,2) = eterm - X(x,1);
    X(x,2) = X(x,2) - Y(y,2);
    ks(y,x) = kstr;
    if X(x,2)>=0
        Y(y,2) = 0;
    end
end
if negflag==1
    diff=nan;
    uxx=vxx;
    uyy=vyy(:,2);
    return
end
if yflag==1
    diff = abs(vxx(x)-S(x));
    while (x ~= 1)
        x=x-1;
        vxx(x) = S(x);
    end
    uxx = vxx;
    uyy = vyy(:,2);
end
end
