clc;
clearvars;
clear all;

rng(50); %Random seed for reproducability
pop = 26078;
n = 100; %Number of income classes

X = zeros(n,1);
xin = 1;
xl = 2.75;
mu = 0.669397;
sigma = 0.193725;
Xdist = makedist('Lognormal','mu',mu ,'sigma', sigma);
X(:,1) = linspace(xin,xl,n); %Income classes
X(:,2) = pdf(Xdist,X(:,1));
X(:,2) = pop*(X(:,2)/sum(X(:,2)));
X(:,1) = X(:,1)*1000;
Y = X;

jlim=1;
l=0;

for j=1:jlim
    
    sigma = sigma + (0.0 * l * sigma);
    mu = mu + (0.0 * l * mu);
    Xdist = makedist('Lognormal','mu', mu ,'sigma', sigma);
    X(:,1) = linspace(xin,xl,n); %Income classes
    X(:,2) = pdf(Xdist,X(:,1));
    X(:,2) = pop*(X(:,2)/sum(X(:,2)));
    X(:,1) = X(:,1)*1000;
    Y = X;
    
    a=23 + (00 * l);
    beta = 0.81 - (0 * l)/30;
    mo_x=0.12 + (0.0 * l);
    v0=0.71 + (0.0 * l);
    Q = [a, v0, beta, mo_x];

    [vxx, vyy, d, dgiven, S, T, ky, ks, Hky, ~] = solve_model(X,Y,Q);

    PG(:,j)=(1-Hky)./2;
    dy(:,j) = d(:,2);
    dy(dy(:,j)==0,j) = NaN;
    dgiven_avg(:,j) = dgiven(:,2)./dgiven(:,3);
    myvar(j) = mo_x;
    l=l+1;
end
%%

figure(1)
set(figure(1),'defaulttextinterpreter','latex');
% title(strcat('Dowry/Wealth and Pr(Girl)',' | $u_0=$',num2str(v0)),'FontSize',14)
xlabel('wealth class','FontSize',14)
lvar = {};
% lvar{1} = 'Pr(Girl)';
% lvar{2} = 'Received';
% lvar{3} = 'Given';
hold on
for j=1:jlim
    yyaxis left
    plot(linspace(1,n,n),PG(:,j))
    yyaxis right
    % plot(linspace(1,n,n), dgiven_avg(:,j)./X(:,1))
     drec = plot(linspace(1,n,n),dy(:,j)./X(:,1))
     dgiv = plot(linspace(1,n,n), dgiven_avg(:,j)./X(:,1))
    lvar{j} = strcat('mo_x = ', num2str(myvar(j)));
end
yyaxis right
ylabel('dowry given/wealth','FontSize',14)
% ylabel('dowry/wealth', 'FontSize',14)
% legend ([drec dgiv],lvar{2},lvar{3}, 'Location','southwest')
legend(lvar,'Location','southwest')
legend('boxoff')
yyaxis left
ylabel('Pr(Girl)','FontSize',14)
writematrix(X, 'data/coded/data_for_charts/X.csv')
writematrix(dgiven_avg, 'data/coded/data_for_charts/dgiven.csv')
writematrix(dy, 'data/coded/data_for_charts/dy.csv')
writematrix(PG, 'data/coded/data_for_charts/PG.csv')

%%
figure(2)
set(figure(2),'defaulttextinterpreter','latex');
hold on
kvl = (ks(:,:)>0)';
[kvlx, kvly] = find(kvl);
%plot(kvlx,kvly,'.-r','LineWidth',0.5,'MarkerSize',2)
plot(kvly,kvlx,'.-r','LineWidth',0.5,'MarkerSize',2)
xlim([1 n])
ylim([1 n])
%spy(kvals(:,:,1),'r',7)
%spy(kvals(:,:,2),'g')
%spy(kvals(:,:,3),'b')
grid on
set(gca,'YDir','normal', 'GridLineStyle', ':')
refline(1,0)
ylabel('male wealth class','FontSize',14)
xlabel('female wealth class','FontSize',14)
match_mat = [kvly,kvlx];
T = array2table(match_mat);
T.Properties.VariableNames(1:2) = {'female_wealth_class','male_wealth_class'};
writetable(T,'data/coded/data_for_charts/matching_data.csv');
%set(gca,'XTickLabel',labmy)
%set(gca,'YTickLabel',labmy)
%legend(lvar,'Location','southeast')
%title('Matching','FontSize',14)
% print('-dpdf', strcat(figurepath, 'Match.pdf'));
% close