/*=========================================================================
Project: Wealth, marriage and sex selection
Author: Girija Borker, Jan Eeckhout, Nancy Luke, Shantidani Minz, Kaivan 
Munshi and Soumya Swaminathan. 
---------------------------------------------------------------------------
Do file: 10_OLS_robinson.do

OLS equivalent of the robinson regressions
=========================================================================*/
clear
set more off


	use "${coded}/HHvariation_predincome_controlfunction_data_1", clear
		
		drop *dummy_1 *dummy_2 *dummy_3 // drop the family size dummies
		drop resid_dummy_1_1 resid_dummy_2_1 resid_dummy_3_1 resid_pred_income_cluster_vfe_1 // drop resid of family size dummies and the abs income
		ds dummy_*
		
		local specific0 = "`r(varlist)'" // caste and village dummies
		local vlist  `specific0'
		di "`vlist'"
		
		reg stage_1_resid_1 resid_*, noconstant
		gen Z_0 = 0 
		foreach v in `vlist'{
					sum `v'
					gen temp = r(mean)
					gen temp2_0 = _b[resid_`v'_1] * (`v' - temp)
					replace Z_0 = Z_0 + temp2_0
					drop temp*
				} //end foreach v
				
				gen y_0 = y - Z_0
		
		gen numid =_n
		merge 1:1 numid using "${coded}/predincome_under6_data_06" 
				
// OLS regressions: coefficient on relative wealth after partialling out non-parametrically the other controls.
		
		// Figure 3a : blue
		eststo robinson_col01:reg y_1 x1
		su y_1 if e(sample)==1
		qui estadd scalar control_mean = r(mean)
		qui estadd local caste_fe = "Yes"
		qui estadd local village_fe = "Yes"
		qui estadd local absolute_wealth = "No"
		qui estadd local family_size_dummies = "No"
		
		// Figure 3a: red
		eststo robinson_col02:reg y_06 x06
		su y_06 if e(sample)==1
		qui estadd scalar control_mean = r(mean)
		qui estadd local caste_fe = "Yes"
		qui estadd local village_fe = "Yes"
		qui estadd local absolute_wealth = "No"
		qui estadd local family_size_dummies = "No"
		
		// Figure 3b: red
		eststo robinson_col03:reg y_0 x1
		su y_0 if e(sample)==1
		qui estadd scalar control_mean = r(mean)
		qui estadd local caste_fe = "Yes"
		qui estadd local village_fe = "Yes"
		qui estadd local absolute_wealth = "Yes"
		qui estadd local family_size_dummies = "Yes"


		esttab robinson_col01 robinson_col02 robinson_col03 using ///
		"${out}/tables/robinson_ols_np.tex", ///
			drop(_cons) replace se booktabs ///
			stats(control_mean N caste_fe, ///
				labels(`"Mean of dependent variable"' ///
						`"Observations"' ///
						`"Caste FE"' ///
						`"Village FE"' ///
						`"Absolute wealth"' ///
						`"Family size dummies"')) ///
				coeflabels(x1 "Rank in caste per capita wealth distribution") ///
				rename(x06 x1) ///
				nomtitles nostar ///
				nonotes
		
/*
global PredictedIncome pred_income_cluster_vfe

use  "${coded}/data_for_robinson.dta", clear

	egen caste_A2 = group(caste A2)

	replace famsize = 5 if famsize> 5 
	tab famsize, gen(dfamsize)
	//drop dfamsize4 //base is family size >= 5

		eststo robinson_col01:reghdfe d_girl6 ref_rank_pred_inc_yg2p if ref_rank_pred_inc_pca!=. & inc_famsize!=., noconstant absorb(caste A2) vce(cluster caste_A2)
		su d_girl6 if e(sample)==1
		qui estadd scalar control_mean = r(mean)
		qui estadd local caste_fe = "Yes"
		qui estadd local village_fe = "Yes"

		eststo robinson_col02:reghdfe d_girl6 ref_rank_pred_inc_yg2p06 if ref_rank_pred_inc_pca!=. & inc_famsize!=., noconstant absorb(caste A2) vce(cluster caste_A2)
		su d_girl6 if e(sample)==1
		qui estadd scalar control_mean = r(mean)
		qui estadd local caste_fe = "Yes"
		qui estadd local village_fe = "Yes"

		eststo robinson_col03:reghdfe d_girl6 ref_rank_pred_inc_yg2p $PredictedIncome dfamsize2 dfamsize3 if ref_rank_pred_inc_pca!=. & inc_famsize!=., absorb(caste A2) vce(cluster caste_A2) noconstant
		su d_girl6 if e(sample)==1
		qui estadd scalar control_mean = r(mean)
		qui estadd local caste_fe = "Yes"

		/*eststo robinson_col04:reghdfe d_girl6 ref_rank_pred_inc_yg2p_new $PredictedIncome_new, absorb(caste) vce(cluster A2)
		su d_girl6 if e(sample)==1
		qui estadd scalar control_mean = r(mean)
		qui estadd local caste_fe = "Yes"		
		
		eststo robinson_col05:reghdfe d_girl6 ref_rank_pred_inc_yg2p_new, absorb(caste) vce(cluster A2)
		su d_girl6 if e(sample)==1
		qui estadd scalar control_mean = r(mean)
		qui estadd local caste_fe = "Yes"*/
		
		//esttab robinson_col01 robinson_col02 robinson_col03 robinson_col04 robinson_col05 using 
		
		esttab robinson_col01 robinson_col02 robinson_col03 using ///
		"${out}/tables/robinson_ols_final.tex", ///
			drop(_cons) replace se booktabs ///
			stats(control_mean N caste_fe, ///
				labels(`"Mean of dependent variable"' ///
						`"Observations"' ///
						`"Caste FE"')) ///
				coeflabels(ref_rank_pred_inc_yg2p "Rank in caste per capita wealth distribution" ///
					pred_income "Household wealth" ///
					dfamsize2 "Family size = 3" ///
					dfamsize3 "Family size = 4") ///
				rename(ref_rank_pred_inc_yg2p06 ref_rank_pred_inc_yg2p ///
				ref_rank_pred_inc_yg2p_new ref_rank_pred_inc_yg2p ///
				pred_income_new pred_income) ///
				star(^{*} 0.10 ^{**} 0.05 ^{***} 0.01) nomtitles ///
				nonotes