/*=========================================================================
Project: Wealth, marriage and sex selection
Author: Girija Borker, Jan Eeckhout, Nancy Luke, Shantidani Minz, Kaivan Munshi and Soumya Swaminathan. 
---------------------------------------------------------------------------
Do file: 14_robinson_firstborn_server.do

Girl dummy as dependent variable
=========================================================================*/

clear all
set more off
capture log close
set seed 1234
set matsize 11000

global PredictedIncome pred_income_cluster_vfe
global Option 0
//global ns = 5

	use "${coded}/data_for_robinson", clear

//create variables for regression

	//caste_dummies
	tab caste, gen(dummy_caste)
	drop dummy_caste1

	
	//village_dummies
	tab A2, gen(dummy_A2)
	drop dummy_A21
	
	
	ds dummy_caste*
	local ncaste: word count `r(varlist)'
	local ic = 0 // this is the last digit of dummy_* created above
	foreach v in `r(varlist)'{
		local ic = `ic'+1
		ren `v' dummy_`ic'
	} //end foreach v
	
	ds dummy_A2*
	local nA2: word count `r(varlist)'
	local ic = 56 // this is the last digit of dummy_* created above
	foreach v in `r(varlist)'{
		local ic = `ic'+1
		ren `v' dummy_`ic'
	} //end foreach v
	
	
	*****************************
	* regressions by birth order
	****************************
	
	
	ren  ref_rank_pred_inc_yg2p x1
	ren d_girl6 y
	drop caste A2
	
	tempfile data_prebo
	save "`data_prebo'"

		forval bo = 0/1{
			
			use "`data_prebo'"

			ds dummy_* // caste and village dummies 
			//linear
			local specific1 = "`r(varlist)'"
		
			foreach ispec in 1{
					
					//assign varlist
					local vlist  `specific`ispec''
					di "`vlist'"
					
					//lowess y on x , and predict residuals
					lowess y x`ispec' if d_bo1==`bo', bw(0.1) gen(y_x`ispec')  nograph
					gen stage_1_resid_`ispec' = y - y_x`ispec'
					
					//regress vlist on x, and predict residuals
					foreach v in `vlist'{
						di "`v'"
						lowess `v' x`ispec' if d_bo1==`bo', bw(0.1) gen(`v'_x`ispec')  nograph
						gen resid_`v'_`ispec' = `v' - `v'_x`ispec'
						drop `v'_x`ispec'
					} //end foreach v
					
					//regress stage 1 residual on stage 2 residuals
					reg stage_1_resid_`ispec' resid_* if d_bo1==`bo', noconstant
					//construct matrix Z
					gen Z_`ispec' = 0 
					foreach v in `vlist'{
						sum `v'
						gen temp = r(mean)
						gen temp2_`ispec' = _b[resid_`v'_`ispec'] * (`v' - temp)
						replace Z_`ispec' = Z_`ispec' + temp2_`ispec'
						drop temp*
					} //end foreach v
					
					gen y_`ispec' = y - Z_`ispec'
					
					rename y_1 y`bo'
					rename x1 x`bo'
					
					gen numid = _n
					
					save "${coded}/predincome_bo`bo'_data_`ispec'", replace
					
				}	
				
		}	
				
		// create graph for paper
		use "${coded}/predincome_bo0_data_1", clear
		merge 1:1 numid using "${coded}/predincome_bo1_data_1"
		
		set scheme s2color		
		tw 	(lpolyci y1 x1 if d_bo1==1, ///
			bw(0.06) xtitle("Rank in caste wealth distribution") ytitle("Pr(Girl)") ///
			lpattern("-") lcolor(red) lwidth(medthick) fcolor("red%30") alcolor("red%30") alstyle("l")) ///
			(lpolyci y0 x0 if d_bo1==0, bw(0.06) lcolor(blue) fcolor("blue%30") alcolor("blue%30")), ///
			legend(order(2 "First born" 4 "Later borns") col(1)) graphregion(color(white)) bgcolor(white)					
			graph export "${out}/figures/birthorder.pdf", replace

	