/*=========================================================================
Project: Wealth, marriage and sex selection
Author: Girija Borker, Jan Eeckhout, Nancy Luke, Shantidani Minz, Kaivan Munshi and Soumya Swaminathan. 
---------------------------------------------------------------------------
Do file: 13_lpoly_castebycaste.do
=========================================================================*/

clear all
set more off
capture log close
set seed 1234
set matsize 11000

global PredictedIncome pred_income_cluster_vfe
global Option 0
//global ns = 5

	use "${coded}/data_for_robinson", clear

	label define castelabel 4 "Ambattan"
	label define castelabel 17 "Irula", add 
	label define castelabel 44 "Naikar", add 
	label define castelabel 7 "Boya", add 
	label define castelabel 23 "Kammalan"  , add 
	label define castelabel 5 "Balija"  , add 
	label define castelabel 10 "Chakkliyan"  , add 
	label define castelabel 33 "Labbai"  , add 
	label define castelabel 14 "Idaiyar"  , add 
	label define castelabel 1 "Kakliyan"  , add 
	label define castelabel 38 "Paraiyar"  , add 
	label define castelabel 28 "Vanniya"  , add 
	label values caste castelabel

preserve

		* number of 0-6 year olds in a caste: to be reported as part of the graphs
		gen d_0to6 = 0
		replace d_0to6 = 1 if d_girl6!=.           
		bys caste: egen num_0to6= total(d_0to6)

		* 3 * lpoly - caste by caste
		levelsof caste if numHH_caste>=2000, local(castenumber) 
			foreach x of local castenumber{
							local cl_`x' : label castelabel `x'
							su numHH_caste if caste==`x'
							local castesize `r(mean)'				
							su num_0to6 if caste==`x'
							local 0_6_size `r(mean)'
							lpoly d_girl6 ref_rank_pred_inc_yg2p if caste==`x', bw(0.1) gen(caste`x'grid_pred_inc_yg2p caste_`x'_d_girl6) nograph
							set scheme s2color
							qui tw line caste_`x'_d_girl6 caste`x'grid_pred_inc_yg2p, xtitle("") ytitle("") legend(off) ///
							title(" `cl_`x'' ")subtitle("Num 0-6 yrs= `0_6_size'") note("Caste Size = `castesize'") ///
							graphregion(color(white)) bgcolor(white)
							graph save "${out}/figures/csr_caste`x'", replace
						}

		sort num_0to6
		duplicates drop caste, force
		//br caste num_0to6 if numHH_caste>2000

		* top 12 castes sorted desccending order


		graph combine "${out}/figures/csr_caste28.gph" "${out}/figures/csr_caste38.gph" "${out}/figures/csr_caste1.gph" ///
		"${out}/figures/csr_caste14.gph" "${out}/figures/csr_caste33.gph" "${out}/figures/csr_caste10.gph" "${out}/figures/csr_caste5.gph" ///
		"${out}/figures/csr_caste23.gph" "${out}/figures/csr_caste7.gph" "${out}/figures/csr_caste44.gph"   ///
		"${out}/figures/csr_caste17.gph" "${out}/figures/csr_caste4.gph", graphregion(color(white)) 


		graph export "${out}/figures/csr_castescombined_desc_sort.pdf", replace

restore
	
	* number of 7-13 year olds in a caste: to be reported as part of the graphs
	gen d_7to13 = 0
	replace d_7to13 = 1 if d_girl713!=.           
	bys caste: egen num_7to13= total(d_7to13)	
		
	levelsof caste if numHH_caste>=2000, local(castenumber) 
	foreach x of local castenumber{
					local cl_`x' : label castelabel `x'
					su numHH_caste if caste==`x'
					local castesize `r(mean)'				
					su num_7to13 if caste==`x'
					local 7_13_size `r(mean)'
					lpoly d_girl713 ref_rank_pred_inc_yg2p if caste==`x', bw(0.1) gen(caste`x'grid_pred_inc_yg2p caste_`x'_d_girl713) nograph
					set scheme s2color
					qui tw line caste_`x'_d_girl713 caste`x'grid_pred_inc_yg2p, xtitle("") ytitle("") legend(off) ///
					title(" `cl_`x'' ")subtitle("Num 7-13 yrs= `7_13_size'") note("Caste Size = `castesize'") ///
					graphregion(color(white)) bgcolor(white)
					graph save "${out}/figures/csr713_caste`x'", replace
				}

	graph combine "${out}/figures/csr713_caste28.gph" "${out}/figures/csr713_caste38.gph" "${out}/figures/csr713_caste1.gph" ///
	"${out}/figures/csr713_caste14.gph" "${out}/figures/csr713_caste33.gph" "${out}/figures/csr713_caste10.gph"  "${out}/figures/csr713_caste5.gph" ///
	"${out}/figures/csr713_caste23.gph" "${out}/figures/csr713_caste7.gph" "${out}/figures/csr713_caste44.gph"   ///
	"${out}/figures/csr713_caste17.gph" "${out}/figures/csr713_caste4.gph", graphregion(color(white)) 

	
	graph export "${out}/figures/csr713_castescombined_desc_sort.pdf", replace
	
	
	levelsof caste if numHH_caste>=2000, local(castenumber) 
	foreach x of local castenumber{
	erase "${out}/figures/csr713_caste`x'.gph"
	erase "${out}/figures/csr_caste`x'.gph"
	}
	
	* create the data which will be the input for the structural model
		do "${stata}/subcode/13_1_smodel_data.do"