/*=========================================================================
Project: Wealth, marriage and sex selection
Author: Girija Borker, Jan Eeckhout, Nancy Luke, Shantidani Minz, Kaivan Munshi and Soumya Swaminathan. 
---------------------------------------------------------------------------
Do file: 14_cross_validation_edit.do

Implement cross-validation 
=========================================================================*/

cls

global PredictedIncome pred_income_cluster_vfe

//Load the basic data
use "${coded}/data_for_robinson.dta", clear



//set the seed
set seed 0

//keep only castes with more than or equal to 100 observations
sort caste
by caste:gen freq = _N
drop if freq < 100
//gdistinct caste  //29 castes

//unique id for each observation
gen id = _n

tempfile f1
save `f1'



//within each caste, randomly generate 10 groups
levelsof caste, local(clevel)  // levelsof caste_A2
foreach lv in `clevel'{
	di "`lv'"
	preserve
		keep id caste //caste_A2
		keep if caste==`lv' // caste_A2==`lv'
		gen runif = runiform()
		egen cunif = cut(runif), at(0(0.1)1) icodes
		assert(!missing(cunif))
		replace cunif = 1 + cunif
		
		qui sum cunif, d
		assert(r(min)==1 & r(max) == 10)
		/*gen check = (r(min)==1 & r(max) == 10)
		su check
		if r(mean) == 1 {
			di "All values satisfy the condition"
		}
		else {
			di "Some values do not satisfy the condition"
		}
		
		keep id cunif check
		ren cunif  cunif`lv'
		ren check check`lv'*/
		
		keep id cunif 
		ren cunif  cunif`lv'
		
		sort id
		merge 1:1 id using `f1', assert(2 3) nogen
		save `f1', replace	
	restore
}

use `f1', clear

egen group= rowtotal(cunif*)
drop cunif* id




//create variables for regression

	//family size
	replace famsize = 5 if famsize> 5 
	tab famsize, gen(dfamsize)
	drop dfamsize4 //base is family size >= 5
	
	/* //caste_dummies
	tab caste, gen(dummy_caste)
	drop dummy_caste1
	
	//village_dummies
	tab A2, gen(dummy_A2)
	drop dummy_A21
	*/

	
	//predicted income
	forv j = 1/4{
		gen pred`j' = $PredictedIncome^`j'
	} //end forv j
	
	
	//rename dummies to help in looping variables
	ren (dfamsize1 dfamsize2 dfamsize3) (dummy_1 dummy_2 dummy_3)
	
	/*ds dummy_caste*
	local ncaste: word count `r(varlist)'
	local ic = 3
	foreach v in `r(varlist)'{
		local ic = `ic'+1
		ren `v' dummy_`ic'
	} //end foreach v
	
	*** addition: village FE
	ds dummy_A2*
	local nA2: word count `r(varlist)'
	local ic = 59 // this is the last digit of dummy_* created above
	foreach v in `r(varlist)'{
		local ic = `ic'+1
		ren `v' dummy_`ic'
	} //end foreach v
	*/
	
	//================================================================
	//construct different specifications to implement cross-validation
	//
	//Search is done over following specifications:
	//
	//1. linear predicted income, no interaction
	//2. linear predicted income, interacted with family dummies
	//3. quadratic predicted income, no interaction
	//4. quadratic predicted income, interaction with only linear part
	//...
	//...
	//================================================================
	
	forv ifam = 1/3{
		forv ipred = 1/4{
			gen int_`ifam'_pred`ipred' = dummy_`ifam' * pred`ipred'
		} //end forv ipred
	} //end forv ifam
	
	//generate specifications
	ds dummy_*
	
	//linear
	local specific0 = "`r(varlist)'"
	local specific1 = "pred1"
	local specific2 = "pred1 int_1_pred1 int_2_pred1 int_3_pred1"
	
	//quadratic	
	local specific3 = "pred1 pred2"
	local specific4 = "pred1 pred2 int_1_pred1 int_2_pred1 int_3_pred1"
	local specific5 = "pred1 pred2 int_1_pred1 int_2_pred1 int_3_pred1  int_1_pred2 int_2_pred2 int_3_pred2"
	
	
	//cubic
	local specific6 = "pred1 pred2 pred3"
	local specific7 = "pred1 pred2 pred3 int_1_pred1 int_2_pred1 int_3_pred1"
	local specific8 = "pred1 pred2 pred3 int_1_pred1 int_2_pred1 int_3_pred1  int_1_pred2 int_2_pred2 int_3_pred2"
	local specific9 = "pred1 pred2 pred3 int_1_pred1 int_2_pred1 int_3_pred1  int_1_pred2 int_2_pred2 int_3_pred2    int_1_pred3 int_2_pred3 int_3_pred3"
	
	//quartic
	local specific10 = "pred1 pred2 pred3 pred4"
	local specific11 = "pred1 pred2 pred3 pred4 int_1_pred1 int_2_pred1 int_3_pred1"
	local specific12 = "pred1 pred2 pred3 pred4 int_1_pred1 int_2_pred1 int_3_pred1  int_1_pred2 int_2_pred2 int_3_pred2"
	local specific13 = "pred1 pred2 pred3 pred4 int_1_pred1 int_2_pred1 int_3_pred1  int_1_pred2 int_2_pred2 int_3_pred2    int_1_pred3 int_2_pred3 int_3_pred3 "
	local specific14 = "pred1 pred2 pred3 pred4 int_1_pred1 int_2_pred1 int_3_pred1  int_1_pred2 int_2_pred2 int_3_pred2    int_1_pred3 int_2_pred3 int_3_pred3   int_1_pred4 int_2_pred4 int_3_pred4 "
	
	
	
	//create the storage matrix for mean square error
	mat define mse =J(10,14,.)
	mat define mse2 =J(10,14,.)
	
	//rename dependent and independent variable
	ren ref_rank_pred_inc_yg2p x
	ren d_girl6 y
	drop pred_income caste famsize freq
	
	
	
	//==================================================
	//
	//Cross-validation
	//
	//===================================================
	local runfullcode = 1
	if `runfullcode' == 1{
			forv ig = 1/10{
				tempvar regsample 
				gen `regsample' = 1 - inlist(group,`ig')
				tab `regsample'
				gen lx_grid = x if ~`regsample'
				cap drop num_id
				tempfile data_`ig'
				save `data_`ig'', replace
				
				forv ispec = 0/0{
					use `data_`ig'', clear
					//assign varlist
					local vlist  `specific`ispec''
					di "`vlist'"
					
					gen num_id = _n
					
					//regress vlist on x, and predict residuals
					foreach v in `vlist'{
						lowess `v' x if `regsample', bw(0.1) gen(`v'_x) at(x) nograph
						gen resid_`v' = `v' - `v'_x if `regsample'
						drop `v'_x
					} //end foreach v
					
					keep num_id resid*
					
					tempfile resid_spec0_`ig'
					save `resid_spec0_`ig''
					} //end foreach v
				
				forv ispec = 1/14{
					
					use `data_`ig'', clear
					//assign varlist
					local vlist  `specific`ispec''
					di "`vlist'"
					
					gen num_id = _n
					
					//lowess y on x , and predict residuals
					lowess y x if `regsample', bw(0.1) gen(y_x) at(x) nograph
					gen stage_1_resid = y - y_x if `regsample'
					
					//regress vlist on x, and predict residuals
					foreach v in `vlist'{
						lowess `v' x if `regsample', bw(0.1) gen(`v'_x) at(x) nograph
						gen resid_`v' = `v' - `v'_x if `regsample'
						drop `v'_x
					} //end foreach v
					
					// merge specification 0 residuals
					cap drop _merge
					merge 1:1 num_id using `resid_spec0_`ig''
					
					//regress stage 1 residual on stage 2 residuals
					reg stage_1_resid resid_*, noconstant
					
					//construct matrix Z
					gen Z = 0 
					foreach v in `vlist'{
						sum `v' if `regsample'
						replace Z = Z + _b[resid_`v'] * (`v' - r(mean)) 
					} //end foreach v
					
					gen ynew = y - Z
					
					
					//do the lowess now
					lpoly ynew x if `regsample', gen(ynew_x) at(lx_grid) bw(0.1) nograph
					
					
					//generate mean square error
					gen diff = (y - ynew_x - Z)^2
					egen temp = total(diff)
					count if ~`regsample'
					gen mse = temp/r(N)
					drop temp
					
					
					gen diff2 = (y - ynew_x )^2
					egen temp = total(diff2)
					count if ~`regsample'
					gen mse2 = temp/r(N)
					drop temp
					
					
					sum mse
					mat mse[`ig',`ispec'] = r(mean)
					
					sum mse2
					mat mse2[`ig',`ispec'] = r(mean)
					
					drop  y_x stage_1_resid resid_* Z ynew ynew_x diff mse diff2 mse2
					
				} //end forv ispec
				
				drop lx_grid
			} //end forv ig
			
			
			preserve
				drop _all
				svmat mse
				drop if missing(mse1)
				save "${coded}/data_for_tables/mse", replace
			restore
			
			
			preserve
				drop _all
				svmat mse2
				drop if missing(mse21)
				save mse2, replace
			restore
	
	} //end if `runfullcode'
	
	
	
//===================================================
//
//Run the code with the different specifications
//
//===================================================
//Load the basic data
use "${coded}/data_for_robinson.dta", clear


//create variables for regression

	//family size
	replace famsize = 5 if famsize> 5
	tab famsize, gen(dfamsize)
	drop dfamsize4 //base is family size >= 5
	
	
	/*
	//caste_dummies
	tab caste, gen(dummy_caste)
	drop dummy_caste1

	//village_dummies
	tab A2, gen(dummy_A2)
	drop dummy_A21
	*/
	
	//predicted income
	forv j = 1/4{
		gen pred`j' = $PredictedIncome^`j'
	} //end forv j
	
	
	//rename dummies to help in looping variables
	ren (dfamsize1 dfamsize2 dfamsize3) (dummy_1 dummy_2 dummy_3)
	drop famsize 
	
	
	/*
	ds dummy_caste*
	local ncaste: word count `r(varlist)'
	local ic = 3 // this is the last digit of dummy_* created above
	foreach v in `r(varlist)'{
		local ic = `ic'+1
		ren `v' dummy_`ic'
	} //end foreach v
	
	** addition of code
	ds dummy_A2*
	local nA2: word count `r(varlist)'
	local ic = 59 // this is the last digit of dummy_* created above
	foreach v in `r(varlist)'{
		local ic = `ic'+1
		ren `v' dummy_`ic'
	} //end foreach v
	*/
	
	//================================================================
	//construct different specifications to implement cross-validation
	//
	//Search is done over following specifications:
	//
	//1. linear predicted income, no interaction
	//2. linear predicted income, interacted with family dummies
	//3. quadratic predicted income, no interaction
	//4. quadratic predicted income, interaction with only linear part
	//...
	//...
	//================================================================
	
	forv ifam = 1/3{
		forv ipred = 1/4{
			gen int_`ifam'_pred`ipred' = dummy_`ifam' * pred`ipred'
		} //end forv ipred
	} //end forv ifam
	
	//generate specifications
	
	
	//rename dependent and independent variable
	ren ref_rank_pred_inc_yg2p x
	ren d_girl6 y
	drop pred_income caste  
	ds dummy_*
	
	//linear
	local specific0 = "`r(varlist)'"
	local specific1 = "pred1"
	local specific2 = "pred1 int_1_pred1 int_2_pred1 int_3_pred1"
	
	//quadratic	
	local specific3 = "pred1 pred2"
	local specific4 = "pred1 pred2 int_1_pred1 int_2_pred1 int_3_pred1"
	local specific5 = "pred1 pred2 int_1_pred1 int_2_pred1 int_3_pred1  int_1_pred2 int_2_pred2 int_3_pred2"
	
	
	//cubic
	local specific6 = "pred1 pred2 pred3"
	local specific7 = "pred1 pred2 pred3 int_1_pred1 int_2_pred1 int_3_pred1"
	local specific8 = "pred1 pred2 pred3 int_1_pred1 int_2_pred1 int_3_pred1  int_1_pred2 int_2_pred2 int_3_pred2"
	local specific9 = "pred1 pred2 pred3 int_1_pred1 int_2_pred1 int_3_pred1  int_1_pred2 int_2_pred2 int_3_pred2    int_1_pred3 int_2_pred3 int_3_pred3"
	
	//quartic
	local specific10 = "pred1 pred2 pred3 pred4"
	local specific11 = "pred1 pred2 pred3 pred4 int_1_pred1 int_2_pred1 int_3_pred1"
	local specific12 = "pred1 pred2 pred3 pred4 int_1_pred1 int_2_pred1 int_3_pred1  int_1_pred2 int_2_pred2 int_3_pred2"
	local specific13 = "pred1 pred2 pred3 pred4 int_1_pred1 int_2_pred1 int_3_pred1  int_1_pred2 int_2_pred2 int_3_pred2    int_1_pred3 int_2_pred3 int_3_pred3 "
	local specific14 = "pred1 pred2 pred3 pred4 int_1_pred1 int_2_pred1 int_3_pred1  int_1_pred2 int_2_pred2 int_3_pred2    int_1_pred3 int_2_pred3 int_3_pred3   int_1_pred4 int_2_pred4 int_3_pred4 "
				
				tempfile data_main
				save `data_main', replace
				
				
				forv ispec = 0/0{
				
					//assign varlist
					local vlist  `specific`ispec''
					di "`vlist'"
					
					gen num_id = _n
					
					//regress vlist on x, and predict residuals
					foreach v in `vlist'{
						di "`v'"
						lowess `v' x, bw(0.1) gen(`v'_x) nograph
						gen resid_`v' = `v' - `v'_x 
						drop `v'_x
					} //end foreach v
					
					keep num_id resid*
					
					tempfile resid_spec0
					save `resid_spec0'
				} //end foreach v
				
				
				
				forval ispec=1/14 {
					use `data_main', clear
					
					//assign varlist
					local vlist  `specific`ispec''
					di "`vlist'"
					
					gen num_id= _n
					
					//lowess y on x , and predict residuals
					lowess y x, bw(0.1) gen(y_x)  nograph
					gen stage_1_resid = y - y_x
					
					
					//regress vlist on x, and predict residuals
					foreach v in `vlist'{
						di "`v'"
						lowess `v' x, bw(0.1) gen(`v'_x)  nograph
						gen resid_`v' = `v' - `v'_x
						drop `v'_x
					} //end foreach v
					
					// merge specification 0 residuals
					merge 1:1 num_id using `resid_spec0'
					
					//regress stage 1 residual on stage 2 residuals
					reg stage_1_resid resid_*, noconstant
					//construct matrix Z
					gen Z = 0 
					foreach v in `vlist'{
						sum `v'
						gen temp = r(mean)
						gen temp2 = _b[resid_`v'] * (`v' - temp)
						//replace Z = Z + _b[resid_`v'] * (`v' - temp)
						replace Z = Z + temp2
						drop temp*
					} //end foreach v
					
					gen ynew = y - Z
					
					/*
					tw (lpolyci ynew x, ///
					bw(0.06) xtitle("Rank in caste wealth distribution") ytitle("Pr(Girl)") lpattern("-") lcolor(red) lwidth(medthick) fcolor("red%30") alcolor("red%30") alstyle("l")) ///
					(lpolyci y x, ///
					bw(0.06) xtitle("Rank in caste wealth distribution") ytitle("Pr(Girl)") lcolor(blue) fcolor("blue%30") alcolor("blue%30")), ///
					legend(order(4 "No control function" 2 "With control function" ) col(1)) graphregion(color(white)) bgcolor(white)
					*/
					
					preserve
						keep y x ynew 
						gen spec = `ispec'
						
						if `ispec' == 1{
						    tempfile fspec
							save `fspec'
						}
						else {
						    append using `fspec'
							save `fspec', replace
						}
					restore
					//gr export "figure_spec`ispec'.pdf", replace
					
					drop  y_x stage_1_resid resid_* Z ynew  

				} //end forv ispec
				
				
		
use `fspec', clear
save output_from_diff_specs, replace


//plot results together
use output_from_diff_specs, clear


//best specification
tw (lpolyci ynew x if spec==1, ///
					bw(0.06) xtitle("Rank in caste wealth distribution") ytitle("Pr(Girl)") lpattern("-") lcolor(red) lwidth(medthick) fcolor("red%30") alcolor("red%30") alstyle("l")) ///
					(lpolyci y x if spec==1, ///
					bw(0.06) xtitle("Rank in caste wealth distribution") ytitle("Pr(Girl)") lcolor(blue) fcolor("blue%30") alcolor("blue%30")), ///
					legend(order(4 "No control function" 2 "With control function" ) col(1)) graphregion(color(white)) bgcolor(white)
					
gr export "${out}/figures/best_specification.pdf", replace

// specification with all controls - predicted income quadratic, interacted with fam size dummies
tw (lpolyci ynew x if spec==14, ///
					bw(0.06) xtitle("Rank in caste wealth distribution") ytitle("Pr(Girl)") lpattern("-") lcolor(red) lwidth(medthick) fcolor("red%30") alcolor("red%30") alstyle("l")) ///
					(lpolyci y x if spec==1, ///
					bw(0.06) xtitle("Rank in caste wealth distribution") ytitle("Pr(Girl)") lcolor(blue) fcolor("blue%30") alcolor("blue%30")), ///
					legend(order(4 "No control function" 2 "With control function" ) col(1)) graphregion(color(white)) bgcolor(white)

gr export "${out}/figures/full_interaction_specification.pdf", replace
					
sum x if spec==1,d
gen lx_grid =r(p1) + (_n-1) * (r(p99) - r(p1))/(100) if _n <= 101


//do the lpoly in a loop
forv j =1/14{
    lpoly ynew x if spec==`j',bw(0.06) gen(ynew_`j') at(lx_grid) nograph
} //end forv j

	#delimit;
		gr twoway (line ynew_1 lx_grid, lw(medthick) lcolor(grey%20) )
					(line ynew_2 lx_grid, lw(medthick) lcolor(grey%20) )
					(line ynew_3 lx_grid, lw(medthick) lcolor(grey%20) )
					(line ynew_4 lx_grid, lw(medthick) lcolor(grey%20) )
					(line ynew_5 lx_grid, lw(medthick) lcolor(grey%20) )
					(line ynew_6 lx_grid, lw(medthick) lcolor(grey%20) )
					(line ynew_7 lx_grid, lw(medthick) lcolor(grey%20) )
					(line ynew_8 lx_grid, lw(medthick) lcolor(grey%20) )
					(line ynew_9 lx_grid, lw(medthick) lcolor(grey%20) )
					(line ynew_10 lx_grid, lw(medthick) lcolor(grey%20) )
					(line ynew_11 lx_grid, lw(medthick) lcolor(grey%20) )
					(line ynew_12 lx_grid, lw(medthick) lcolor(grey%20) )
					(line ynew_13 lx_grid, lw(medthick) lcolor(grey%20) )
					(line ynew_14 lx_grid, lw(medthick) lcolor(grey%20) 
					xtitle("Rank in caste wealth distribution")
					ytitle("Pr (girl)")),legend(off)
					graphregion(color(white));
	#delimit cr

	gr export "${out}/figures/all_specifications.pdf", replace
	
	
* calculate the mean forecast sum of square errors by specifications

	use "${coded}/data_for_tables/mse.dta" , clear
		
	gen id = 1
	collapse (mean) mse*, by(id)     
	drop id

	* Interchange observations and variables
	xpose, clear varname

	** Organize rows and columns for reshape
	* Columns
	gen x = 1
	replace x = 2 if _varname == "mse3" | _varname == "mse4" | _varname == "mse5"
	replace x = 3 if _varname == "mse6" | _varname == "mse7" | _varname == "mse8" | _varname == "mse9"
	replace x = 4 if _varname == "mse10" | _varname == "mse11" | _varname == "mse12" | _varname == "mse13" | _varname == "mse14"

	* Rows
	gen y = "a"
	replace y = "b" if _varname == "mse2" | _varname == "mse4" | _varname == "mse7" | _varname == "mse11"
	replace y = "c" if _varname == "mse5" | _varname == "mse8" | _varname == "mse12" 
	replace y = "d"  if _varname == "mse9" | _varname == "mse13" 
	replace y = "e"  if _varname == "mse14"

	* Reshape
	drop _varname
	reshape wide v1, i(y) j(x)

	* Rename first column values
	replace y = "No interaction" if y== "a"
	replace y = "Linear interaction" if y== "b"
	replace y = "Linear + quadratic interaction" if y== "c"
	replace y = "Linear + quadratic + cubic interaction" if y== "d"
	replace y = "All interactions" if y== "e"

	* Organize numbers format
	format v11 v12 v13 v14 %10.6f

	** Create output table

	listtab y v11 v12 v13 v14 using "${out}/tables/cross_validation_mse.tex", type rstyle(tabular) replace ///
		   head("\begin{threeparttable}" ///
		   "\begin{tabular}{l*{5}{c}} \hline" ///
		   "& Linear& Quadratic & Cubic & Quartic \\" ///
		   "& (1) & (2) & (3) & (4) \\  \hline ") ///
		   foot("\hline" "\end{tabular}" "\begin{tablenotes}" "\footnotesize" "\item{Notes.  Mean forecast error is based on k-fold cross validation, with k=10. We consider 14 specifications of the control function: linear, quadratic, cubic and quartic functions on wealth, with varying degrees of interaction between the wealth terms and the family size dummies.}" ///
		   "\end{tablenotes} \end{threeparttable}")