/*=========================================================================
Project: Wealth, marriage and sex selection
Author: Girija Borker, Jan Eeckhout, Nancy Luke, Shantidani Minz, Kaivan Munshi and Soumya Swaminathan. 
---------------------------------------------------------------------------
Do file: 17_marriage_analysis_ar.do

Creates Table 1 which shows descriptive information for daughter and son.
=========================================================================*/

clear all
set more off
cap log close

set seed 1412024
********************************************************************************
* merge section A with section using mpr_id
	use "${raw}/MPR/MPR_SEC_E_comb.dta", clear

	gen ind_id = mpr_id
	// this is child level data i.e each row is a child

	/*merge m:1 mpr_id using "MPR_SEC_A_edit.dta"
	keep if _m==1 | _m==3
	rename _merge E_A_simplemerge */

	merge m:1 E3_ind_id using "${raw}/ROSTER/HOUSEROSTER_P2forE3_edit.dta"
	keep if _merge ==3| _merge ==1
	rename _merge E3_Z2roster_merge

	merge m:1 E10_ind_id using "${raw}/ROSTER/HOUSEROSTER_P2forE10_edit.dta"
	keep if _merge ==3| _merge ==1
	rename _merge E10_Z2roster_merge

	merge m:1 ind_id using "${raw}/ROSTER/HOUSEROSTER_P2_edit.dta"
	keep if _merge ==3
	drop _merge

	rename Z14 z14
	tostring z14, replace
	gen zero= "0"
	gen zerozero = "00"
	replace z14 = zero+z14 if length(z14)==2
	replace z14 = zerozero+z14 if length(z14)==1

	do "${subcode}/15_1_recoding_castes_survey.do"

//////////////////////////// ******* need to come back to step ****////
	destring z14, replace
	replace caste= z14 if caste==.

* replace variables for the HH members in marriage data
* complete marriage data

	************** Son/Dau ****************
	* relationship (based on gender) - daughter or son
		replace E4 = 1 if E3_Z4==1 & E3_ind_id!=""
		replace E4 = 2 if E3_Z4==2 & E3_ind_id!=""

	* age at marriage
	//replace E5 =  if E3_ind_id!="" // just using age in years from the roster data

	* current residence
		replace E6= E3_Z12 if E3_ind_id!=""
		replace E6_1= E3_Z12_1 if E3_ind_id!=""
		replace E6_2= E3_Z12_2 if E3_ind_id!=""
		replace E6_3= E3_Z12_3 if E3_ind_id!=""

	* current occupation
		replace E7 = E3_Z9 if E3_ind_id!=""

	* highest level of education 
		replace E8 = E3_Z8 if E3_ind_id!=""

	*  avg monthly income
		//replace E9

************** SIL/DIL ****************

	* current residence
		replace E11 = E10_Z12 if E10_ind_id!=""
		replace E11_1 = E10_Z12_1 if E10_ind_id!=""
		replace E11_2 = E10_Z12_2 if E10_ind_id!=""
		replace E11_3 = E10_Z12_3 if E10_ind_id!=""

	* sil or dil age at marriage
		//replace E12 = 

	* current occupation
		replace E13 = E10_Z9 if E10_ind_id!=""

	* highest level of education
		replace E14 = E10_Z8 if E10_ind_id!=""

	* same caste or not
	* need to infer using E16 below
	// E15
		replace E16 = E10_Z14 if E10_ind_id!=""

		gen caste_ownchild = E3_Z14 if E3_ind_id!=""

		replace E15 = 0 if E16!=caste_ownchild & E15==.
		replace E15 = 1 if E16==caste_ownchild & E15==.

	*  avg monthly income
	//replace E17

		drop E3_* E10_*

	* recode education variable
		replace E8 = trim(E8)			
		replace educ_E8 = 	0	if E8 == "0"
		replace educ_E8 = 	0	if E8 == "97"
		replace educ_E8 = 	0	if E8 == "ANG"
		replace educ_E8 = 	0	if E8 == "PKG"
		replace educ_E8 = 	0	if E8 == "LKG"
		replace educ_E8 = 	0	if E8 == "UKG"
		replace educ_E8 = 	1	if E8 == "S1"
		replace educ_E8 = 	2	if E8 == "S2"
		replace educ_E8 = 	3	if E8 == "S3"
		replace educ_E8 = 	4	if E8 == "S4"
		replace educ_E8 = 	5	if E8 == "S5"
		replace educ_E8 = 	6	if E8 == "S6"
		replace educ_E8 = 	7	if E8 == "S7"
		replace educ_E8 = 	8	if E8 == "S8"
		replace educ_E8 = 	9	if E8 == "S9"
		replace educ_E8 = 	10	if E8 == "S10"
		replace educ_E8 = 	11	if E8 == "S11"
		replace educ_E8 = 	11	if E8 == "P1"
		replace educ_E8 = 	11	if E8 == "P12"
		replace educ_E8 = 	12	if E8 == "P2"
		replace educ_E8 = 	11	if E8 == "DP10"
		replace educ_E8 = 	13	if E8 == "DPP2"
		replace educ_E8 = 	13	if E8 == "C1"
		replace educ_E8 = 	14	if E8 == "C2"
		replace educ_E8 = 	15	if E8 == "C3"
		replace educ_E8 = 	16	if E8 == "C4"
		replace educ_E8 = 	17	if E8 == "C5"
		replace educ_E8 = 	17	if E8 == "PG"

		replace E14 = trim(E14)				
		replace educ_E14 = 	0	if E14 == "0"
		//replace educ_E14 = 	0	if E14 == "88" // don't know
		replace educ_E14 = 	0	if E14 == "97"
		replace educ_E14 = 	0	if E14 == "ANG"
		replace educ_E14 = 	0	if E14 == "PKG"
		replace educ_E14 = 	0	if E14 == "LKG"
		replace educ_E14 = 	0	if E14 == "UKG"
		replace educ_E14 = 	1	if E14 == "S1"
		replace educ_E14 = 	2	if E14 == "S2"
		replace educ_E14 = 	3	if E14 == "S3"
		replace educ_E14 = 	4	if E14 == "S4"
		replace educ_E14 = 	5	if E14 == "S5"
		replace educ_E14 = 	6	if E14 == "S6"
		replace educ_E14 = 	7	if E14 == "S7"
		replace educ_E14 = 	8	if E14 == "S8"
		replace educ_E14 = 	9	if E14 == "S9"
		replace educ_E14 = 	10	if E14 == "S10"
		replace educ_E14 = 	10	if E14 == "S101"
		replace educ_E14 = 	11	if E14 == "S11"
		replace educ_E14 = 	11	if E14 == "P1"
		replace educ_E14 = 	12	if E14 == "P2"
		replace educ_E14 = 	11	if E14 == "DP10"
		replace educ_E14 = 	13	if E14 == "DPP1"
		replace educ_E14 = 	13	if E14 == "DPP2"
		replace educ_E14 = 	13	if E14 == "DPPL"
		replace educ_E14 = 	13	if E14 == "DDP2"
		replace educ_E14 = 	13	if E14 == "C1"
		replace educ_E14 = 	14	if E14 == "C2"
		replace educ_E14 = 	15	if E14 == "C3"
		replace educ_E14 = 	16	if E14 == "C4"
		replace educ_E14 = 	17	if E14 == "C5"
		replace educ_E14 = 	17	if E14 == "PG"
		
		isid P_CODE V_CODE NIRT_NO RSN MPR_ROW_ID_SEC_E E3
		
		save "${coded}/Survey_data_formerge", replace

****************
* DESCRIPTIVES *
****************

 * Do file that creates descriptives for parents columns
	preserve
	do "${subcode}/15_2_marriage_analysis_parents.do"
	restore
	
	* "balanced" HH where there is a son and a daughter
		egen hhid = group(P_CODE V_CODE NIRT_NO RSN MPR_FIID)
		gen son = 1 if E4==2
		bys hhid: egen max_son = max(son)
		gen daughter = 1 if E4==1
		bys hhid: egen max_daughter = max(daughter)
		gen balanced_sample = max_son + max_daughter
		gen d_bal = 1 if balanced_sample>=2 & balanced_sample!=.
		
		* keep one random child from mult child HH in sample
		bys hhid: egen tot_daughter = sum(daughter)
		bys hhid: egen tot_son = sum(son)
		gen tot_kids= tot_daughter+tot_son
		gen d_bal_mult = 1 if E4==1 & d_bal==1 & tot_kids>2 & tot_daughter>=2 // at least one son and one daughter + more than two kids + daughters are 2 or more
		replace d_bal_mult = 1 if E4==2 & d_bal==1 & tot_kids>2 & tot_son>=2 // at least one son and one daughter + more than two kids + sons are 2 or more
		
		gen rand = runiform() if d_bal_mult==1
		bys hhid: egen max_rand = max(rand)
		
		
		* keep the child closest in age to the one child of opposite sex
		gen years_since_marr = 2016 - E2_2 // 2016 is when the HH survey was conducted
		gen curr_age = E5+ years_since_marr if E4==2
		
		bys hhid: gen ageofonechild = curr_age if d_bal==1 & d_bal_mult==. // what is the age of the one child who is of opp sex 
		bys hhid: egen ageofonechild_max = max(ageofonechild) if d_bal==1
		gen age_diff = curr_age - ageofonechild_max // calculate diff in age of the one child and the two children of same sex 
		
		// keep child who has least age diff
		bys hhid: egen min_age_diff = min(age_diff)
		
		// we are missing the age information for 5 kids (of 15), sticking to choosing at random
		replace d_bal=. if rand== max_rand & rand!=.
		
		// curr age of child's spouse
		gen curr_age_spouse = E12 + years_since_marr if E4==1
		
		// plot age dist of girls' husband and the sons
		//tw 	(kdensity curr_age_spouse if E4==1 & curr_age_spouse<=50) || ///
		//	(kdensity curr_age if E4==2 & curr_age<=50)
		
		count if curr_age_spouse !=. // 732
		local tot = `r(N)'
		
		// calculate probability of each age showing up in girls husband's age distribution
		bys curr_age_spouse: egen num_in_age = count(curr_age_spouse)
		gen prop_in_age = num_in_age/`tot'
		bys curr_age: egen num_age = count(curr_age)

		
		preserve
			keep curr_age_spouse  num_in_age  prop_in_age
			duplicates drop
			rename curr_age_spouse curr_age // to enable the merge
			rename prop_in_age prop_spouse
			//rename num_in_age weight
			tempfile spouse_prop
			save `spouse_prop'
		restore
		
		merge m:1 curr_age using `spouse_prop', nogen
		
		gen prop_son = num_age/`tot'
		
		gen weight = prop_spouse/prop_son
		
		// plot age dist of girls' husband and the sons
		tw 	(kdensity curr_age_spouse if E4==1 & curr_age_spouse<=50) || ///
			(kdensity curr_age if E4==2 & curr_age<=50 [aweight=weight])
		
 * Descriptives for children
	matrix m = J(4,6,.)

	matlist m
	* children's generation
	* i.e. MPR's children
		tab E4 
		
	* bride and groom from same caste
		bys E4: tab E15, nolab
		sum E15 if E4 == 1
		matrix m[1,1] = `r(mean)'
		
		*balanced
		sum E15 if E4 == 1 & d_bal == 1 
		matrix m[1,4] = `r(mean)'

		preserve 
		replace E15 = 0 if E15 ==99
		sum E15 if E4 == 2 [aweight=weight]
		matrix m[1,2] = `r(mean)'
		sum E15 if E4 == 2 & d_bal == 1
		matrix m[1,5] = `r(mean)'
		restore
		
		ttest E15, by(E4)
		matrix m[1,3] = `r(p)'
		ttest E15 if d_bal == 1, by(E4) 
		matrix m[1,6] = `r(p)'
		
	* related
		bys E4: tab E22
		
		preserve
		replace E22 = 1 if E22 ==1 | E22 ==2 | E22 ==3 | E22 ==4 | E22 ==5 
		replace E22 = 0 if E22 ==6 | E22 ==99 | E22 ==88
		sum E22 if E4 == 2 [aweight=weight]
		matrix m[2,1] = `r(mean)'
		sum E22 if E4 == 2 & d_bal == 1
		matrix m[2,4] = `r(mean)'
		
		sum E22 if E4 == 1 
		matrix m[2,2] = `r(mean)'
		sum E22 if E4 == 1 & d_bal == 1 
		matrix m[2,5] = `r(mean)'
		restore
		
		ttest E22, by(E4)
		matrix m[2,3] = `r(p)'
		ttest E22 if d_bal == 1, by(E4)
		matrix m[2,6] = `r(p)'
		
	* who chose sil/dil
		bys E4: tab E18
		preserve
		replace E18 = 1 if E18 ==1 | E18 ==2 
		replace E18 = 0 if E18 ==3 | E18 ==4 | E18 ==5 | E18 ==6 | E18 ==88
		sum E18 if E4 == 2 [aweight=weight]
		matrix m[3,1] = `r(mean)'
		sum E18 if E4 == 2 & d_bal == 1
		matrix m[3,4] = `r(mean)'
		
		sum E18 if E4 == 1 
		matrix m[3,2] = `r(mean)'
		sum E18 if E4 == 1 & d_bal == 1
		matrix m[3,5] = `r(mean)'
		restore
		
		ttest E18, by(E4)
		matrix m[3,3] = `r(p)'
		ttest E18 if d_bal == 1, by(E4)
		matrix m[3,6] = `r(p)'

	* same village?
		tab E19, nolab
		bys E4: tab E19, nolab
		
		preserve
		replace E19 = 2 if E19==0
		replace E19 = 1 if E19 ==88 | E19 ==99 
		replace E19 = 0 if E19 ==1
		replace E19 = 1 if E19 == 2
		sum E19 if E4 == 2 [aweight=weight]
		matrix m[4,1] = `r(mean)'
		sum E19 if E4 == 2 & d_bal == 1
		matrix m[4,4] = `r(mean)'
		
		sum E19 if E4 == 1 
		matrix m[4,2] = `r(mean)'
		sum E19 if E4 == 1 & d_bal == 1
		matrix m[4,5] = `r(mean)'
		restore
		
		ttest E19, by(E4)
		matrix m[4,3] = `r(p)'
		ttest E19 if d_bal == 1, by(E4) 
		matrix m[4,6] = `r(p)'

	* inlaws family's relative wealth
		tab E27
		matrix w = J(3,4,.)
		
		* wealthier
		gen d_wealthier = 0 if E27<4
		replace d_wealthier=1 if E27==1

		sum d_wealthier if E4== 2 [aweight=weight]
		matrix w[1,1] = `r(mean)'
		sum d_wealthier if E4== 1 
		matrix w[1,2] = `r(mean)'
		
		sum d_wealthier if E4== 2 & d_bal == 1
		matrix w[1,3] = `r(mean)'
		sum d_wealthier if E4== 1 & d_bal == 1
		matrix w[1,4] = `r(mean)'
		
		* same wealth
		gen d_s_wealth = 0 if E27<4
		replace d_s_wealth=1 if E27==2
		
		sum d_s_wealth if E4== 2 [aweight=weight]
		matrix w[2,1] = `r(mean)'
		sum d_s_wealth if E4== 1 
		matrix w[2,2] = `r(mean)'
		
		sum d_s_wealth if E4== 2 & d_bal == 1
		matrix w[2,3] = `r(mean)'
		sum d_s_wealth if E4== 1 & d_bal == 1
		matrix w[2,4] = `r(mean)'
		
		* less wealthy
		gen d_l_wealth = 0 if E27<4
		replace d_l_wealth=1 if E27==3
		
		sum d_l_wealth if E4== 2 [aweight=weight]
		matrix w[3,1] = `r(mean)'
		sum d_l_wealth if E4== 1 
		matrix w[3,2] = `r(mean)'
		
		sum d_l_wealth if E4== 2 & d_bal == 1
		matrix w[3,3] = `r(mean)'
		sum d_l_wealth if E4== 1 & d_bal == 1
		matrix w[3,4] = `r(mean)'
		
		ttable2 d_wealthier, by(E4)

		* Kolmogorov-Smirnov test of equality 
		ksmirnov E27, by(E4) 
		global smirnov : display %04.3fc `r(p)'
		
		ksmirnov E27 if d_bal ==1 , by(E4)
		global smirnov_b : display %04.3fc `r(p)'
		
	** Parents + children information for table
	matrix a = p,m
	matlist a

	* dowry

	* dowry = E32, only for daughters
		gen dowry = E32/1000 if E4==1 
		lab var dowry "Dowry (in thousands)"

	* see how diff components contribute/are correlated with the dowry
		forval i=0/17{	
			replace E30_`i' = 0 if E30_`i'==.
			replace E31_`i' = 0 if E31_`i'==.
		}
		// now all the E30 and E31 variables are dummies
		gen dowry_calc = 0

	* for daughters, dowry =what her side gave to the couple
	* dummy variables, assume if yes, then one unit of the good is given
		replace dowry_calc =E30_1*2240.82+ E30_2*1329.16 + E30_3*15000+ E30_4*25000+ ///
		E30_5* 736+E30_6* 1099+E30_7* 9890+E30_8*5490 +E30_9*4150 +E30_10*3869 +E30_11* 20000+ ///
		E30_13*11700 +E30_14*3201.48 +E30_15*285000 +E30_16*2793+E30_17 if E4==1 // excluding groceries because no way of attaching a valuation

	* for sons, dowry =what his side received
		replace dowry_calc = E31_1*2240.82+ E31_2*1329.16 + E31_3*15000+ E31_4*25000+ ///
		E31_5* 736+E31_6* 1099+E31_7* 9890+E31_8*5490 +E31_9*4150 +E31_10*3869 +E31_11* 20000+ ///
		E31_13*11700 +E31_14*3201.48 +E31_15*285000 +E31_16*2793+E31_17 if E4==2

		replace dowry_calc = dowry_calc/1000
		lab var dowry_calc "dowry calculated in '000s"


* SECTION S *
* to get HH wealth measure
* merge for each child the HH wealth
	merge m:1 mpr_id using "${raw}/MPR/MPR_SEC_S_comb.dta"
	keep if _merge ==3
	drop _merge

	gen annual_income = monthlyincome_survey*12
	lab var annual_income "Annual income (in thousand Rupees)"

	gen d_fem = 0
	replace d_fem = 1 if E4==1
	su d_fem

	gen monthlyincome_survey_fem = monthlyincome_survey * d_fem
	su monthlyincome_survey_fem

	* dowry as a fraction of monthly income
	local dowry_list dowry_calc dowry
	foreach d of local dowry_list{
		gen frac_`d' = `d'/(monthlyincome_survey*12) // all 826 kids matched
		lab var frac_`d' "`d' as a fraction of annual income"
	}

* dowry as a proportion of annual income
	bys E4: su dowry_calc, d
	bys E4: su frac_dowry_calc, d

	bys E4: su dowry, d
	bys E4: su frac_dowry, d

	su frac_dowry_calc
	ttable2 frac_dowry_calc, by(d_fem)
	
* Dowry information

	* Mean
	eststo est1: estpost sum dowry_calc
	eststo est2: estpost sum dowry_calc if E4== 2 [aweight=weight]
	eststo est3: estpost sum dowry_calc if E4== 1	
	eststo est10: estpost ttest dowry_calc, by(E4)
	eststo est2_b: estpost sum dowry_calc if E4== 2 & d_bal==1
	eststo est3_b: estpost sum dowry_calc if E4== 1	& d_bal==1
	eststo est10_b: estpost ttest dowry_calc if d_bal==1, by(E4)
	
	* Min and max
	eststo est4: estpost tabstat dowry_calc, ///
		columns(variables) statistics(min max)
	eststo est5: estpost tabstat dowry_calc ///
		if E4==2, columns(variables) statistics(min max)
	eststo est6: estpost tabstat dowry_calc ///
		if E4==1, columns(variables) statistics(min max)
	eststo est5_b: estpost tabstat dowry_calc ///
		if E4==2 & d_bal==1, columns(variables) statistics(min max)
	eststo est6_b: estpost tabstat dowry_calc ///
		if E4==1 & d_bal==1, columns(variables) statistics(min max)

	* Mean (fraction of annual income)
	eststo est7: estpost sum frac_dowry_calc
	eststo est8: estpost sum frac_dowry_calc if E4== 2
	eststo est9: estpost sum frac_dowry_calc if E4== 1
	eststo est8_b: estpost sum frac_dowry_calc if E4== 2 & d_bal==1
	eststo est9_b: estpost sum frac_dowry_calc if E4== 1 & d_bal==1
	
* Total observations data 

	count if E4 == 2
	global males : display `r(N)'
	
	count if E4 == 1
	global females : display `r(N)'
	
	count if E4 == 2 & d_bal == 1
	global males_b : display `r(N)'
	
	count if E4 == 1 & d_bal == 1
	global females_b : display `r(N)'
		
******************* 
* Final table: 1 *
*******************

		esttab matrix(a, fmt(2)) using "${out}/tables/Table_marriage_analysis.tex", ///
			nomtitle noobs nolines noeqlines nonumbers collabels(,none) ///
			coeflabel (r1 "Same Caste" r2 "Related" r3 "Arranged" r4 "Female moved outside natal village") label ///
			replace fragment ///
			prehead("\begin{threeparttable}" ///
			"\begin{tabular}{ lccccccc} \hline" ///
			"Generation & Parents & \multicolumn{2}{c}{Children} & & \multicolumn{2}{c}{Balanced sample} & \\ \cmidrule(lr){3-4} \cmidrule(lr){6-7} & & Males & Females & P-value & Males & Females & P-value\\ & (1) & (2) & (3) & (4) & (5) & (6) & (7) \\ \cmidrule(lr){2-8}") 
	
	esttab est1 est2 est3 est10 est2_b est3_b est10_b using "${out}/tables/Table_marriage_analysis.tex", ///
			cells("mean (pattern(0 1 1 0 1 1 0) fmt(2)) p(pattern(0 0 0 1 0 0 1) fmt(2))") ///
			nomtitle noobs nolines label coeflabel(dowry_calc "Mean dowry [As a fraction of annual income]") nonumbers collabels(none) ///
			prehead("\\") ///
			append fragment		
			
	esttab est7 est8 est9 est10 est8_b est9_b est10_b using "${out}/tables/Table_marriage_analysis.tex", ///
			cells("mean (pattern(0 1 1 0 1 1 0) fmt(2) par([ ]))") ///
			nomtitle nolines noobs coeflabels(none) nonumbers collabels(none) ///
			append fragment		
			
	esttab est4 est5 est6 est10 est5_b est6_b est10_b using "${out}/tables/Table_marriage_analysis.tex", ///
			cells(dowry_calc (pattern(0 1 1 0 1 1 0) fmt(%12.1fc))) ///
			nomtitle nolines label nonumbers collabels(none) noobs ///
			coeflabel(min "Minimum dowry (in thousand Rupees)" max "Maximum dowry (in thousand Rupees)") ///
			append fragment	///
			postfoot(" \vspace{0.1cm} Observations & $total & $males & $females & & $males_b & $females_b & \\ \hline" ///
			"\end{tabular}" ///
		"\begin{tablenotes} \footnotesize \item{\textit{Source:} SICHS household survey} " ///
		"\end{tablenotes} \end{threeparttable}") 
		
******************* 
* Final table: 2 *
*******************

		esttab matrix(w, fmt(2)) using "${out}/tables/Table_marital_matching.tex", ///
			nomtitle noobs nolines noeqlines nonumbers collabels(,none) ///
			coeflabel (r1 "Wealthier" r2 "Same wealth" r3 "Less wealthy") label ///
			replace fragment ///
			prehead("\begin{threeparttable}" ///
			"\begin{tabular}{lcccc} \hline" ///
			"Sex of the child & \multicolumn{2}{c}{Full sample} & \multicolumn{2}{c}{Balanced sample} \\ \cmidrule(lr){2-3} \cmidrule(lr){4-5} & Males & Females & Males & Females\\ & (1) & (2) & (3) & (4) \\ \cmidrule(lr){2-5}" ///
			"Partner's parental household & & & & \\") ///
			postfoot("\\ Kolmogorov-Smirnov test of equality & \multicolumn{2}{c}{P-value $=$ $smirnov} & \multicolumn{2}{c}{P-value $=$ $smirnov_b} \\" ///
			" \\ Observations & $males & $females & $males_b & $females_b  \\" ///
			"\hline" ///
			"\end{tabular}" ///
		"\begin{tablenotes} \footnotesize \item{\textit{Source:} SICHS household survey} " ///
		"\end{tablenotes} \end{threeparttable}") 

		/*
******************* 
* dowry regressions *
*******************

	local reglist dowry_calc frac_dowry_calc //dowry 
			foreach reg of local reglist{
					* income per child *
					reg `reg' d_fem monthlyincome_survey, robust
					//outreg2 using "output/tables/`reg'_wealth.tex", se label addtext(Caste FE, No) replace
					
					areg `reg' d_fem monthlyincome_survey, robust absorb(caste)		
					//outreg2 using "output/tables/`reg'_wealth.tex", se label addtext(Caste FE, Yes) append				
	}

* dowry and frac_dowry regressions	
local reglist dowry_calc frac_dowry_calc //dowry 
		foreach reg of local reglist{
				* income per child *
				reg `reg' d_fem monthlyincome_survey, robust
				//outreg2 using "output/tables/`reg'_wealth.tex", se label addtext(Caste FE, No) replace
				
				areg `reg' d_fem monthlyincome_survey, robust absorb(caste)		
				//outreg2 using "output/tables/`reg'_wealth.tex", se label addtext(Caste FE, Yes) append
				
				areg `reg' d_fem monthlyincome_survey educ_E8, robust absorb(caste)		
				//outreg2 using "output/tables/`reg'_wealth.tex", se label addtext(Caste FE, Yes) append	
				
				areg `reg' d_fem monthlyincome_survey monthlyincome_survey_fem, robust absorb(caste)		
				//outreg2 using "output/tables/`reg'_wealth.tex", se label addtext(Caste FE, Yes) append
				
				areg `reg' d_fem monthlyincome_survey monthlyincome_survey_fem educ_E8, robust absorb(caste)		
				//outreg2 using "output/tables/`reg'_wealth.tex", se label addtext(Caste FE, Yes) append	
				
				areg `reg' d_fem educ_E8, robust absorb(caste)		
				//outreg2 using "output/tables/`reg'_wealth.tex", se label addtext(Caste FE, Yes) append	
	}				

* dowry regressions with flexible controls for income
forval i = 2/4{
	gen income_survey_`i' = (monthlyincome_survey)^`i'
}

reg dowry_calc d_fem monthlyincome_survey, robust	
areg dowry_calc d_fem monthlyincome_survey, robust absorb(caste)

reg dowry_calc d_fem monthlyincome_survey income_survey_2, robust

reg dowry_calc d_fem monthlyincome_survey income_survey_2 income_survey_3, robust	
areg dowry_calc d_fem monthlyincome_survey income_survey_2 income_survey_3, robust absorb(caste)

******************* 
* Final table: A1 *
*******************

areg dowry_calc d_fem monthlyincome_survey income_survey_2, robust absorb(caste)
//outreg2 using "output/tables/dowry_wealth_fin.tex", se label addtext(Caste FE, No) replace
su dowry_calc if e(sample)
testparm monthlyincome_survey income_survey_2

* dowry regression with HH fixed effects
* variation: HH with 2 kids or more, of different gender
areg dowry_calc d_fem, absorb(mpr_id) robust	
//outreg2 using "output/tables/dowry_wealth_fin.tex", se label addtext(Household FE, Yes) append
su dowry_calc if e(sample)
********************
	
*****************************************************************	
* multinomial logit analysis for wealth distribution of partner *
*****************************************************************

* replace the don't knows to missing
replace E27 = . if E27 ==88 
replace E27 = . if E27 ==99

lab def E27_lab 1 "Wealthier" 2 "Same" 3 "Less wealthy"
lab values E27 E27_lab


******************* 
* Final table: A2 *
*******************

mlogit E27 i.d_fem, base(2) 
//outreg2 using "output/tables/partner_wealth_fin.tex", se label  replace ///
keep (1.d_fem)

mlogit E27 i.d_fem educ_E8, base(2) 
//outreg2 using "output/tables/partner_wealth_fin.tex", se label  append ///
keep (i.d_fem educ_E8)

********************


mlogit E27 i.d_fem i.caste, base(2) 
//outreg2 using "output/tables/partner_wealth.tex", se label  append ///
keep (i.d_fem) addtext(Caste FE, Yes)

* adding education
mlogit E27 i.d_fem, base(2) 
//outreg2 using "output/tables/partner_wealth_educ.tex", se label  replace ///
keep (i.d_fem) addtext(Caste FE, Yes)

mlogit E27 i.d_fem educ_E8, base(2) 
//outreg2 using "output/tables/partner_wealth_educ.tex", se label  append ///
keep (i.d_fem educ_E8) addtext(Caste FE, Yes)

mlogit E27 i.d_fem i.caste, base(2) 
//outreg2 using "output/tables/partner_wealth_educ.tex", se label  append ///
keep (i.d_fem) addtext(Caste FE, Yes)

mlogit E27 i.d_fem educ_E8 i.caste, base(2) 
//outreg2 using "output/tables/partner_wealth_educ.tex", se label  append ///
keep (i.d_fem educ_E8) addtext(Caste FE, Yes)

* base category is "same wealth"
mlogit E27 i.d_fem monthlyincome_survey i.caste, base(2)
//outreg2 using "output/tables/partner_wealth.tex", se label replace ///
keep (i.d_fem monthlyincome_survey) addtext(Caste FE, Yes)
test [Wealthier]1.d_fem = [Less_wealthy]1.d_fem

/*
qui margins d_fem, atmeans predict(outcome(1))
qui marginsplot, name(wealthier) 
qui margins d_fem, atmeans predict(outcome(2))
qui qui marginsplot, name(same) 
qui margins d_fem, atmeans predict(outcome(3))
qui marginsplot, name(less) 
qui graph combine wealthier same less, ycommon
graph save "Charts/$date/mlogit_wealth_byfem", replace */

mlogit E27 i.d_fem monthlyincome_survey monthlyincome_survey_fem i.caste, base(2) 
//outreg2 using "output/tables/partner_wealth.tex", se label  append ///
keep (i.d_fem monthlyincome_survey monthlyincome_survey_fem) addtext(Caste FE, Yes)

mlogit E27 i.d_fem monthlyincome_survey monthlyincome_survey_fem educ_E8 i.caste, base(2) 
//outreg2 using "output/tables/partner_wealth.tex", se label  append ///
keep (i.d_fem monthlyincome_survey monthlyincome_survey_fem educ_E8) addtext(Caste FE, Yes)

* only child's education
mlogit E27 i.d_fem educ_E8 i.caste, base(2) 
//outreg2 using "output/tables/partner_wealth_educ.tex", se label  replace ///
keep (i.d_fem educ_E8) addtext(Caste FE, Yes)

* mlogit for females
	mlogit E27 monthlyincome_survey i.caste if d_fem==1, base(2) 
	test [Wealthier]monthlyincome_survey = [Less_wealthy]monthlyincome_survey
	//outreg2 using "output/tables/partner_wealth_bygender.tex", se label replace ///
	keep (monthlyincome_survey) addtext(Caste FE, Yes)

	mlogit E27 educ_E8 i.caste if d_fem==1, base(2) 
	
* mlogit for males
	mlogit E27 monthlyincome_survey i.caste if d_fem==0, base(2) 
	test [Wealthier]monthlyincome_survey = [Less_wealthy]monthlyincome_survey
	//outreg2 using "output/tables/partner_wealth_bygender.tex", se label append ///
	keep (monthlyincome_survey) addtext(Caste FE, Yes)
	
	mlogit E27 educ_E8 i.caste if d_fem==0, base(2) 

gen educ_E8_fem = educ_E8* d_fem

mlogit E27 i.d_fem educ_E8 educ_E8_fem i.caste, base(2)
mlogit E27 i.d_fem educ_E8 educ_E8_fem monthlyincome_survey i.caste, base(2)

mlogit E27 i.d_fem  i.caste, base(2)
	
* creating quantiles of income
xtile income_qtiles = monthlyincome_survey, nq(5)
mlogit E27 i.income_qtiles if d_fem==1, base(2)

/*
margins income_qtiles, atmeans predict(outcome(1))
marginsplot, name(wealthier_inc) 
margins income_qtiles, atmeans predict(outcome(2))
marginsplot, name(same_inc) 
margins income_qtiles, atmeans predict(outcome(3))
marginsplot, name(less_inc) 
graph combine wealthier_inc same_inc less_inc, ycommon
graph save "Charts/$date/mlogit_wealth_byfem", replace
*/

* education of partner
areg educ_E14 monthlyincome_survey educ_E8, absorb(caste)
//outreg2 using "output/tables/partner_educ.tex", se label addtext(Caste FE, Yes) replace	

* merge data with census data
replace Z2 = lower(Z2)
replace Z2 = trim(Z2)

replace Z3 = lower(Z3)
replace Z3 = trim(Z3)

* unique id for marriages used for merges
sort P_CODE V_CODE NIRT_NO RSN
gen unique_id = _n

preserve
	merge n:1 P_CODE V_CODE NIRT_NO using "data/coded/DataForSurvey.dta"
	keep if _merge==1|_merge==3
	drop _merge
	// 167 marriages in survey data not matched
	tempfile sur_cen_merge1
	save `sur_cen_merge1', replace
restore

merge m:m P_CODE V_CODE NIRT_NO Z2 Z3 using "data/coded/DataForReg_survey.dta"
keep if _merge==3
drop _merge
merge 1:1 unique_id using `sur_cen_merge1', nogen
tempfile sur_cen_merge2
save `sur_cen_merge2', replace

use `sur_cen_merge2', clear
keep if HHid == "" //previously unmatched

replace P_CODE = trim(P_CODE)
replace V_CODE = trim(V_CODE) 
replace NIRT_NO = trim(NIRT_NO)

joinby P_CODE V_CODE NIRT_NO using "data/coded/DataForReg_survey.dta", unmatched(both) update
 
keep if _merge == 3
drop _merge
duplicates drop P_CODE V_CODE NIRT_NO Z2 Z3 HHid, force
duplicates tag unique_id, gen(tag_un)
drop if tag_un==1 // 2 obs dropped
merge 1:1 unique_id using `sur_cen_merge2', nogen
// 15 (of 1,032) marriages not matched = 1.5%

* these variables come from the DataForReg_survey merge
drop monthlyincome_census
drop ref_rank_pred_inc_yg2p pred_inc_younggen2p

* data created in breg_actual&pred_2017_03_08
merge m:1 HHid using "data/coded/CensusVars.dta", keep(3) nogen
// 636 marriages matched, 396 not matched. This is because predicted income 
// per youngest gen is created only for LivesWithFather==1 & LivesWithMother==1 & d_youngestgen==1

rename monthlyincome monthlyincome_census
tempfile marriages_withrefrank

save `marriages_withrefrank'

corr monthlyincome_survey monthlyincome_census

* divide household income by number of members
gen income_permem = monthlyincome_survey/(total_yg_own+2)
gen income_permem_fem = income_permem * d_fem

use `marriages_withrefrank', clear

local reglist dowry_calc frac_dowry_calc //dowry 
		foreach reg of local reglist{
				* income per child *
				reg `reg' ref_rank_pred_inc_yg2p , robust
				//outreg2 using "output/tables/`reg'_rank.tex", se label addtext(Caste FE, No) replace
				
				areg `reg' ref_rank_pred_inc_yg2p, robust absorb(caste)		
				//outreg2 using "output/tables/`reg'_rank.tex", se label addtext(Caste FE, Yes) append						
				
				areg `reg' ref_rank_pred_inc_yg2p pred_income, robust absorb(caste)		
				//outreg2 using "output/tables/`reg'_rank.tex", se label addtext(Caste FE, Yes) append	
				
				areg `reg' ref_rank_pred_inc_yg2p monthlyincome_census, robust absorb(caste)		
				//outreg2 using "output/tables/`reg'_rank.tex", se label addtext(Caste FE, Yes) append					
	}


