/*=========================================================================
Project: Wealth, marriage and sex selection
Author: Girija Borker, Jan Eeckhout, Nancy Luke, Shantidani Minz, Kaivan Munshi and Soumya Swaminathan. 
---------------------------------------------------------------------------
Do file: 19_hsc_enroll.do

Creates school enrollment table
=========================================================================*/

* Table A3
use "${coded}/DataForReg_coded.dta", clear

	eststo ed_1: reghdfe hsc_enroll mother_EdYears father_EdYears if IsFemale == 0, absorb(caste) noconstant
						su hsc_enroll if e(sample)==1
						estadd scalar control_mean = r(mean)
						
	eststo ed_2: reghdfe hsc_enroll mother_EdYears father_EdYears if IsFemale == 1, absorb(caste) noconstant
						su hsc_enroll if e(sample)==1
						estadd scalar control_mean = r(mean)
	
	eststo ed_3: reghdfe d_girl6 mother_EdYears father_EdYears, absorb(caste) noconstant
						su d_girl6 if e(sample)==1
						estadd scalar control_mean = r(mean)
	
	esttab ed_1 ed_2 ed_3 using "${out}/tables/table_A3.tex", ///
	replace se booktabs nolines noeqlines nonumbers ///
	stats(control_mean N, labels(`"Mean of dependent variable"' `"Observations"')) ///
	coeflabels(mother_EdYears "Mother's educations" father_EdYears "Father's education") ///
	star(* 0.10 ** 0.05 *** 0.01) nomtitles ///
	nonotes ///
	prehead("\begin{threeparttable}" ///
			"\begin{tabular}{lccc} \hline" ///
			"Dependent variable & Boys higher secondary & Girls higher secondary & Girl dummy \\ \vspace{0.1cm} & enrollment & enrollment &  \\ Age range & 14-17 & 14-17 & 0-6 \\ & (1) & (2) & (3) \\ \cmidrule(lr){2-4}") ///
	postfoot("Caste FE & Yes & Yes & Yes \\ \hline" ///
		"\end{tabular}" ///
		"\begin{tablenotes} \footnotesize \item{\textit{Notes:} Higher secondary enrollment indicates whether the child is enrolled in school. The lower bound for the age range is set at 14 because most children in rural Tamil Nadu study till the 8th grade (age 13). The upper bound is set at 17 because girls start to marry (and leave their parental homes) by the age of 18. Sex selection is measured by the probability that the child (aged 0-6) is a girl. *** p$<$0.01. Source: SICHS census} " ///
		"\end{tablenotes} \end{threeparttable}") 

	