/*=========================================================================
Project: Wealth, marriage and sex selection
Author: Girija Borker, Jan Eeckhout, Nancy Luke, Shantidani Minz, Kaivan Munshi and Soumya Swaminathan. 
---------------------------------------------------------------------------
Do file: 20_sex_ratios.do

Creates sex ratio table

Download DHS data:
- 2005
	https://dhsprogram.com/data/dataset/India_Standard-DHS_2006.cfm?flag=1
- 2015
	https://dhsprogram.com/data/dataset/India_Standard-DHS_2015.cfm?flag=1
=========================================================================*/

			*********************************************************
			*														*
			*		INDIA											*
			*														*
			*********************************************************
			mat define sratio_2005 = J(3,1,.)
			mat define sratio_2015 = J(3,1,.)
			mat define sratio_2012 = J(3,1,.)
			
			//**** 2005 ****//
			use "${raw}/IAIR52FL", clear
			keep caseid bord* b8_* b4_* v005 v024 v025
			
			* Organize national women's weight variables
			replace v005 = v005/1000000
				
			* Organize birth order number variable
			forv j = 1/9{
					ren bord_0`j' bord_`j'
					ren b8_0`j' b8_`j'
					ren b4_0`j' b4_`j'
				}
				
			greshape long b8_ b4_ bord_, i(caseid) j(child)
			drop if bord_ == .
			
			* Gen variable for South India
			gen south = inlist(v024, 33,29, 27,28) // maharashtra, andhra pradesh, karnataka, tamil nadu

			gen male = b4_ == 1
			
			* Create dummy for ttest
			gen d_bo1 = 1 if bord_ == 1
			replace d_bo1 = 0 if bord_ != 1

			* Rural south India 2005-2006
			sum male if b8_ < 7 & d_bo1 == 1 & south==1 & v025==2 [iw = v005]
			mat sratio_2005[1,1] =  100 * (r(mean)/(1 - r(mean)))
			
			sum male if b8_ < 7 & d_bo1 == 0 & south==1 & v025==2 [iw = v005]
			mat sratio_2005[2,1] =  100 * (r(mean)/(1 - r(mean)))
			
			sum male if b8_ < 7 & south == 1 & v025==2 [iw = v005]
			mat sratio_2005[3,1] =  100 * (r(mean)/(1 - r(mean)))
			
			* ttest (first children vs other)
			ttest male if b8_ < 7 & south == 1 & v025==2, by(d_bo1)
			global ttest_1 : display %04.3fc `r(p)'

			count if b8_ < 7 & south == 1 & v025==2
			global DHS_05 : display %12.0fc `r(N)'
			
			* Tempfile for t-test (DHS vs SICHS)
			preserve
			keep if b8_ < 7 & south == 1 & v025==2
			keep male d_bo1
			gen sample = 1
			tempfile dhs_05
			save `dhs_05'
			restore
			
			preserve
			//**** 2016 ****//
			use "${raw}/IAIR74FL", clear
			keep caseid bord* b8_* b4_* v005 v024 v025
			replace v005 = v005/1000000
				
			forv j = 1/9{
					ren bord_0`j' bord_`j'
					ren b8_0`j' b8_`j'
					ren b4_0`j' b4_`j'
				}
				
			greshape long b8_ b4_ bord_, i(caseid) j(child)
			drop if bord_ == .
			
			* Gen variable for South India
			gen south = inlist(v024, 36,31, 20, 16, 2)
			
			gen male = b4_ == 1
			
			gen d_bo1 = 1 if bord_ == 1
			replace d_bo1 = 0 if bord_ != 1
			
			* Rural south india 2015-2016
			sum male if b8_ < 7 & d_bo1 == 1 & south==1 & v025==2 [iw = v005]
			mat sratio_2015[1,1] =  100 * (r(mean)/(1 - r(mean)))
			
			sum male if b8_ < 7 & d_bo1 == 0 & south==1 & v025==2 [iw = v005]
			mat sratio_2015[2,1] =  100 * (r(mean)/(1 - r(mean)))
			
			sum male if b8_ < 7 & south == 1 & v025==2 [iw = v005]
			mat sratio_2015[3,1] =  100 * (r(mean)/(1 - r(mean)))
			
			* ttest (first children vs other)
			ttest male if b8_ < 7 & south == 1 & v025==2, by(d_bo1)
			global ttest_2 : display %04.3fc `r(p)'
			
			count if b8_ < 7 & south == 1 & v025==2
			global DHS_15 : display %12.0fc `r(N)'
			
			* Tempfile for t-test (DHS vs SICHS)
			keep if b8_ < 7 & south == 1 & v025==2
			keep male d_bo1
			gen sample = 2
			tempfile dhs_15
			save `dhs_15'		
			restore
			
			//**** SICHS 2012 ****//
			preserve 
			use "${coded}/data_for_robinson.dta", clear
		
			* first borns
			reg d_girl6 ref_rank_pred_inc_yg2p
			su d_girl6 if d_bo1==1 & e(sample)
			mat sratio_2012[1,1] = ((1 - `r(mean)')/`r(mean)')*100
			
			* first borns
			reg d_girl6 ref_rank_pred_inc_yg2p
			su d_girl6 if d_bo1==0 & e(sample)
			mat sratio_2012[2,1] = ((1 - `r(mean)')/`r(mean)')*100
		
			* all children
			reg d_girl6 ref_rank_pred_inc_yg2p
			su d_girl6 if e(sample)
			mat sratio_2012[3,1] = ((1 - `r(mean)')/`r(mean)')*100
			
			gen male = 1 if d_girl6 == 0 & e(sample)
			replace male = 0 if d_girl6 == 1 & e(sample)
			
			* ttest (first children vs other)
			reg d_girl6 ref_rank_pred_inc_yg2p
			ttest male, by(d_bo1)
			global ttest_3 : display %04.3fc `r(p)'
			
			count if !missing(male)
			global DHS_12 : display %12.0fc `r(N)'
			
			keep if !missing(male)
			keep male d_bo1
			gen sample = 3
			
			** T- test DHS vs SICHS
			matrix define test = J(3,2,.)
	
			append using `dhs_05'
			ttest male if d_bo1==1, by(sample)
			matrix test[1,1] = `r(p)'
			
			ttest male if d_bo1==0, by(sample)
			matrix test[2,1] = `r(p)'
			
			ttest male, by(sample)
			matrix test[3,1] = `r(p)'
			
			drop if sample == 1
			
			append using `dhs_15'
			ttest male if d_bo1==1, by(sample)
			matrix test[1,2] = `r(p)'
			
			ttest male if d_bo1==0, by(sample)
			matrix test[2,2] = `r(p)'
			
			ttest male, by(sample)
			matrix test[3,2] = `r(p)'
			restore

			* Put matrices together
			matrix sex_ratio = sratio_2005, sratio_2015,sratio_2012,test
			mat list sex_ratio
			
			* ${out} table
			
			esttab matrix(sex_ratio, fmt(3)) using "${out}/tables/Table_Sex_Ratios_upd_v2.tex" , ///
			nomtitle noobs nolines noeqlines nonumbers collabels(,none) ///
			coeflabel (r1 "First-born children" r2 "Later-born children" r3 "All children") label ///
			replace fragment ///
			prehead("\begin{tabularx}{0.8\textwidth}{lYYYYY} \toprule" ///
			"Population & \multicolumn{2}{c}{Rural South India} & Rural Vellore \\ \cmidrule(lr){2-3} \cmidrule(lr){4-4} Data Source & \thead{DHS \\ 2005-06} & \thead{DHS \\ 2015-16} & \thead{SICHS census \\ 2012-14} & \multicolumn{2}{c}{\thead{t-test\\ P-value}} \\ & (1) & (2) & (3) & (4) & (5) \\ \cmidrule(lr){2-6}") ///
			postfoot("& & & & &\\" ///
			"t-test P-value & $ttest_1 & $ttest_2 & $ttest_3 & & \\ \\" ///
			"Observations & $DHS_05 & $DHS_15 & $DHS_12 & & \\ \bottomrule" ///
			"\multicolumn{6}{p{0.77\textwidth}}{\footnotesize \textit{Source}: The India Demographic and Health Survey (DHS) is also known as the Indian National Family Health Survey (NFHS). Sex ratios are computed for children aged 0-6 as the number of boys per 100 girls.The DHS statistics are computed for the entire South Indian region because sample sizes are too small to measure sex ratios in Tamil Nadu. The comparison with SICHS sex ratios is still valid because we saw in Appendix Table \ref{tab:Demographic_Socioeconomic_Comparisons} that the study area is representative of rural Tamil Nadu and rural South India with respect to socioeconomic and demographic characteristics, as well as child sex ratios. The t-test reports the p-value of a two sample unpaired t-test for equality of the sex ratio for the first borns and all children in each column. The Kolmogorov-Smirnov result reports the p-value for equality of the distribution of sex ratios in DHS 2005-06 and DHS 2015-16 compared to the SICHS data in Column (1) and (2) respectively.}" ///
		"\end{tabularx}") 

			
			
			
			