/*=========================================================================
Project: Wealth, marriage and sex selection
Author: Girija Borker and Akhil Lohia
Date: 25 September 2021
---------------------------------------------------------------------------
Do file: 21_structural_figures.do

This files creates figures from data extracted during the structural estimation
The data is extracted as a last step in .csv
=========================================================================*/

	** housekeeping
		clear all
		set more off
		cap log close

	** figure on counterfactuals
	
		* input data
		
			import delimited using "${coded}/data_for_charts/counterfactuals_data.csv", clear
		
		* figure
			tw (line no_transfer inc_class,  lcolor(gs10) ) ///
			(line transfer_to_girl_families inc_class, lpattern (dash) lcolor(gs10) lwidth(medthick)) ///
			(line transfer_to_poor_girl_families inc_class, lpattern(longdash_dot) lcolor("0 116 0")) ///
			(line transfer_directly_to_girls inc_class, lcolor("0 116 0") lwidth(medthick)), ///
			legend(order(	1 "No transfer" ///
							2 "Transfer to girls families" ///
							3 "Transfer to poor girl families" ///
							4 "Transfer directly to girls") ///
							position(6) col(2) region(lcolor(black))) ///
			xtitle("Wealth class") ytitle("Pr(Girl)") xlabel(1(1)10, nogrid) ///
			ylabel(, angle(vertical)) ///
			graphregion(color(white)) bgcolor(white)
			 
			graph export "${out}/figures/structural_counterfactual.pdf", replace 
			
	** figure on dowry and Pr(Girl)
	
		* input data
		
			import delimited using "${coded}/data_for_charts/PG.csv", clear
			gen id = _n
			rename v1 pg
			tempfile pg		
			save `pg'
			
			import delimited using "${coded}/data_for_charts/dy.csv", clear
			gen id = _n
			rename v1 dy
			tempfile dy
			save `dy'
			
			import delimited using "${coded}/data_for_charts/X.csv", clear
			gen id = _n
			rename v1 x
			tempfile x
			save `x'
			
			import delimited using "${coded}/data_for_charts/dgiven.csv", clear
			rename v1 dgiven
			gen id = _n
			
			merge 1:1 id using `pg', nogen
			merge 1:1 id using `dy', nogen
			merge 1:1 id using `x', nogen
			
			gen dy_x = dy/x
			gen dgiven_x = dgiven/x
			
			tw (line pg id,  yaxis(2) yscale(lc(blue) axis(2)) ytitle("Pr(Girl)", color(blue) axis(2)) lcolor(blue) ///
			ylabel( ,labcolor(blue) axis(2) tlc(blue) angle(vertical))) ///
			(line dy_x id, yaxis(1) yscale(lc(red)) ylabel( ,labcolor(red) axis(1) tlc(red) angle(vertical)) ///
			ytitle("Dowry/ Wealth", color(red) axis(1)) lcolor(red) lpattern(dash)) ///
			(line dgiven_x id, yaxis(1) lcolor(red)), ///
			legend(order(2 "Received" 3 "Given") col(2) position(6) region(lcolor(black))) ///
			xtitle("Wealth class") xlabel(0(10)100, nogrid) ///
			graphregion(color(white)) bgcolor(white)
			
			graph export "${out}/figures/structural_dowry.pdf", replace 
			
	** figure on varying beta	
/*			
			import delimited using "${coded}/data_for_charts\beta_PG.csv", clear
			gen id = _n
			rename v1 pg_1
			rename v2 pg_2
			tempfile pg		
			save `pg'
			
			import delimited using "${coded}/data_for_charts\beta_X.csv", clear
			gen id = _n
			rename v1 x
			tempfile x
			save `x'
			
			import delimited using "${coded}/data_for_charts\beta_dgiven.csv", clear
			rename v1 dgiven_1
			rename v2 dgiven_2
			gen id = _n
			
			merge 1:1 id using `pg', nogen
			merge 1:1 id using `x', nogen
			
			gen dgiven_x1 = dgiven_1/x
			gen dgiven_x2 = dgiven_2/x
			
			tw (line pg_1 id,  yaxis(2) yscale(lc(blue) axis(2)) ytitle("Pr(Girl)", color(blue) axis(2)) ///
			lcolor(blue) ylabel( ,labcolor(blue) axis(2) tlc(blue))) ///
			(line pg_2 id,  yaxis(2) yscale(lc(blue) axis(2)) ytitle("Pr(Girl)", color(blue) axis(2)) ///
			lcolor(blue) ylabel( ,labcolor(blue) axis(2) tlc(blue)) lpattern(dash)) ///
			(line dgiven_x1 id, yaxis(1) yscale(lc(red)) ylabel( ,labcolor(red) axis(1) tlc(red)) ///
			ytitle("Dowry given/ Wealth", color(red) axis(1)) lcolor(red)) ///
			(line dgiven_x2 id, yaxis(1) lcolor(red) lpattern(dash)), ///
			legend(order(1 "" 3 "{&beta} = 0.80" 2 "" 4 "{&beta} = 0.73") col(2) keygap(1)) ///
			xtitle("Wealth class") xlabel(0(10)100) ///
			graphregion(color(white)) bgcolor(white)
			
			graph export "output/figures/structural_beta.pdf", replace 
		
	** figure on varying u_0
			
			import delimited using "${coded}/data_for_charts\u0_PG.csv", clear
			gen id = _n
			rename v1 pg_1
			rename v2 pg_2
			tempfile pg		
			save `pg'
			
			import delimited using "${coded}/data_for_charts\u0_X.csv", clear
			gen id = _n
			rename v1 x
			tempfile x
			save `x'
			
			import delimited using "${coded}/data_for_charts\u0_dgiven.csv", clear
			rename v1 dgiven_1
			rename v2 dgiven_2
			gen id = _n
			
			merge 1:1 id using `pg', nogen
			merge 1:1 id using `x', nogen
			
			gen dgiven_x1 = dgiven_1/x
			gen dgiven_x2 = dgiven_2/x
			
			tw (line pg_1 id,  yaxis(2) yscale(lc(blue) axis(2)) ytitle("Pr(Girl)", color(blue) axis(2)) ///
			lcolor(blue) lpattern(dash) ylabel( ,labcolor(blue) axis(2) tlc(blue))) ///
			(line pg_2 id,  yaxis(2) yscale(lc(blue) axis(2)) ytitle("Pr(Girl)", color(blue) axis(2)) ///
			lcolor(blue) ylabel( ,labcolor(blue) axis(2) tlc(blue)) lpattern(solid)) ///
			(line dgiven_x1 id, yaxis(1) yscale(lc(red)) ylabel( ,labcolor(red) axis(1) tlc(red)) ///
			lpattern(dash) ytitle("Dowry given/ Wealth", color(red) axis(1)) lcolor(red)) ///
			(line dgiven_x2 id, yaxis(1) lcolor(red) lpattern(solid)), ///
			legend(order(2 "" 4 "u{subscript:b} = 0.90"  1 "" 3 "u{subscript:b} = 0.75") col(2) keygap(1)) ///
			xtitle("Wealth class") xlabel(0(10)100) ///
			graphregion(color(white)) bgcolor(white)
			
			graph export "output/figures/structural_ub.pdf", replace 
			
	** figure on varying a
			
			import delimited using "${coded}/data_for_charts\a_PG.csv", clear
			gen id = _n
			rename v1 pg_1
			rename v2 pg_2
			tempfile pg		
			save `pg'
			
			import delimited using "${coded}/data_for_charts\a_X.csv", clear
			gen id = _n
			rename v1 x
			tempfile x
			save `x'
			
			import delimited using "${coded}/data_for_charts\a_dgiven.csv", clear
			rename v1 dgiven_1
			rename v2 dgiven_2
			gen id = _n
			
			merge 1:1 id using `pg', nogen
			merge 1:1 id using `x', nogen
			
			gen dgiven_x1 = dgiven_1/x
			gen dgiven_x2 = dgiven_2/x
			
			tw (line pg_1 id,  yaxis(2) yscale(lc(blue) axis(2)) ytitle("Pr(Girl)", color(blue) axis(2)) ///
			lcolor(blue) ylabel( ,labcolor(blue) axis(2) tlc(blue))) ///
			(line pg_2 id,  yaxis(2) yscale(lc(blue) axis(2)) ytitle("Pr(Girl)", color(blue) axis(2)) ///
			lcolor(blue) ylabel( ,labcolor(blue) axis(2) tlc(blue)) lpattern(dash)) ///
			(line dgiven_x1 id, yaxis(1) yscale(lc(red)) ylabel( ,labcolor(red) axis(1) tlc(red)) ///
			ytitle("Dowry given/ Wealth", color(red) axis(1)) lcolor(red)) ///
			(line dgiven_x2 id, yaxis(1) lcolor(red) lpattern(dash)), ///
			legend(order(1 "" 3 "a = 23" 2 ""  4 "a = 33") col(2) keygap(1)) ///
			xtitle("Wealth class") xlabel(0(10)100)  ///
			graphregion(color(white)) bgcolor(white)
			
			graph export "output/figures/structural_a.pdf", replace 			

			
	** figure on varying mo_x
			
			import delimited using "${coded}/data_for_charts\mox_PG.csv", clear
			gen id = _n
			rename v1 pg_1
			rename v2 pg_2
			tempfile pg		
			save `pg'
			
			import delimited using "${coded}/data_for_charts\mox_X.csv", clear
			gen id = _n
			rename v1 x
			tempfile x
			save `x'
			
			import delimited using "${coded}/data_for_charts\mox_dgiven.csv", clear
			rename v1 dgiven_1
			rename v2 dgiven_2
			gen id = _n
			
			merge 1:1 id using `pg', nogen
			merge 1:1 id using `x', nogen
			
			gen dgiven_x1 = dgiven_1/x
			gen dgiven_x2 = dgiven_2/x
			
			tw (line pg_1 id,  yaxis(2) yscale(lc(blue) axis(2)) ytitle("Pr(Girl)", color(blue) axis(2)) ///
			lcolor(blue) ylabel( ,labcolor(blue) axis(2) tlc(blue))) ///
			(line pg_2 id,  yaxis(2) yscale(lc(blue) axis(2)) ytitle("Pr(Girl)", color(blue) axis(2)) ///
			lcolor(blue) ylabel( ,labcolor(blue) axis(2) tlc(blue)) lpattern(dash)) ///
			(line dgiven_x1 id, yaxis(1) yscale(lc(red)) ylabel( ,labcolor(red) axis(1) tlc(red)) ///
			ytitle("Dowry given/ Wealth", color(red) axis(1)) lcolor(red)) ///
			(line dgiven_x2 id, yaxis(1) lcolor(red) lpattern(dash)), ///
			legend(order(1 "" 3 "m{subscript:b} = 0.09" 2 ""  4 "m{subscript:b} = 0.11") col(2) keygap(1)) ///
			xtitle("Wealth class") xlabel(0(10)100) ///
			graphregion(color(white)) bgcolor(white)
			
			graph export "output/figures/structural_m_b.pdf", replace 			
	*/		
			
	** figure with aread marked		
			
			import delimited using "${coded}/data_for_charts/u0_decomposition_data.csv", clear
			gen p5 = 0.5
			
			tw (area p5 inc_class, acolor(red%70)) ///
			(area pg_without_u inc_class, lcolor(red) acolor(blue%70)) ///
			(area pg_with_u inc_class, color(white)), ///
			legend(order(1 "Marriage market" 2 "Son Preference") col(2) position(6) region(lcolor(black))) ///
			xtitle("Wealth class") ytitle("Pr(Girl)") xlabel(1(1)10) ///
			graphregion(color(white)) bgcolor(white) ylabel(,angle(vertical))
			
			graph export "${out}/figures/structural_ubarea.pdf", replace
			
			* total area
			integ p5 inc_class, gen(tot) trapezoid
			integ pg_without_u inc_class, gen(blue_white) trapezoid
			integ pg_with_u inc_class, gen(white) trapezoid
			
			/* Note
			
				Total area under the graph = 4.5
				White area = 4.31
				Missing girls = 0.19
				Blue area = Son Pref = 0.10 or 53%
				Red area = MM channel = 0.09 or 47%
			*/
			
			
			** structural estimates table

			import delimited using "${coded}/bootstrap/bootstrap_estimates.csv", clear
			
			rename(v1 v2 v3 v4)(a u0 beta mox)
			label var beta "Boys' bargaining position: $\beta$" 
			label var u0 "Son Preference: \$u_0\$" 
			label var mox "Boys' cost of being single: \$m_{b}\$" 
			label var a "Cost of sex selection: \$a\$" 
			
			* mean of structural estimates
				drop if a==0 & u0==0 & beta ==0 & mox ==0
				
				eststo est1: estpost tabstat beta u0 mox a, stat(mean sd p5 p95) columns(statistics) listwise 
				esttab est1 using "${out}/tables/structural_estimates_1.tex", cells(mean(fmt(3)) p5(fmt(3) par) p95(fmt(3) par)) eform ///
				gaps lines collabels(none) label nonumbers ///
				addnotes("95% confidence intervals in brackets; p-values in parentheses.") replace
				
				eststo est2: mean beta u0 mox a
				esttab est2 using "${out}/tables/structural_estimates_2.tex", cells(b(fmt(3)) ci(fmt(3) par) wide)  replace ///
				collabels(none) label nonumbers nomtitle noobs ///
				prehead("\begin{threeparttable}" ///
				"\begin{tabular}{lc} \hline" ///
				"& Mean \\" ///
				"& [95\% Confidence Interval] \\ ") /// 
				postfoot("\end{tabular} \hline" ///
				"\end{threeparttable}") 
			
	** figure with matching	
	
			import delimited "${coded}/data_for_charts/matching_data.csv", clear
			//set obs `=_N+1'
			
			* add intercept observation
			//replace male_wealth_class=male_wealth_class[1] in l
			//replace female_wealth_class=0 in l

			sort female_wealth_class
			
			tw 	(line male_wealth_class female_wealth_class, lcolor(red) lwidth(thin)) ///
				(line female_wealth_class female_wealth_class, lcolor(blue) lwidth(thin)), ///
				xtitle("Female wealth class") ytitle("Male wealth class") ///
				ylabel(0(10)100, angle(vertical)) xlabel(0(10)100, nogrid) legend(off) ///
				graphregion(color(white)) bgcolor(white)
			
			graph export "${out}/figures/structural_matching.pdf", replace
			
			
			
			