/*=========================================================================
Project: Wealth, marriage and sex selection
Author: Girija Borker, Jan Eeckhout, Nancy Luke, Shantidani Minz, Kaivan 
Munshi and Soumya Swaminathan. 
---------------------------------------------------------------------------
Do file: 2_identifying_children.do
=========================================================================*/

*************************************************
* Finding the children for each male and female *
*************************************************

//use "Census Data/Data_for_Pr_of_marr_v0710.dta", clear
* use "Census Data\Data_for_Pr_of_marr_v1209.dta", clear

*use test_sample, clear
drop if C2_6 == ""

*Chopping up relationship code into the last character (the relation type) and 
*everything that comes before the last character (which gives the person through whom
*the individual is related to the primary earner)
gen RelCodeLast = substr(C2_6,-1,1)
gen RelatedTo = "A" if length(C2_6) == 1
replace RelatedTo = "A" if RelatedTo == "Z" 

*** Why have we coded the illegal relation as being related to A directly?

replace RelatedTo = reverse(subinstr(reverse(C2_6),RelCodeLast,"",1)) if RelatedTo != "A" // gives all but the last digit when C2_6 != A

** DIRECT CODES **

*Creating dummies for people coded as a parent, child, sibling, primary earner, or wife
gen IsParent = 0
replace IsParent = 1 if regexm(RelCodeLast,"[MF]$")
gen IsChild = 0
replace IsChild = 1 if regexm(RelCodeLast,"[1-9GJKPQ]$") 

*** this should be 1-9?

gen IsSibling = 0
replace IsSibling = 1 if regexm(RelCodeLast,"[BCDESTUV]$")
gen IsPrimaryEarner = 0
replace IsPrimaryEarner = 1 if C2_6 == "A"
gen IsWife = 0
replace IsWife = 1 if regexm(RelCodeLast,"[WY]$")
gen IsHusband = 0
replace IsHusband = 1 if RelCodeLast == "H"

*------------------*

***********
* Husband *
***********

gen ishusband3 = 0
replace ishusband3 = 1 if C2_5 == 1 & C2_3==1

********
* Wife *
********

gen iswife3 = 0
replace iswife3 = 1 if C2_5 == 1 & C2_3==2

gen RelatedBy = reverse(subinstr(reverse(C2_6),RelCodeLast,"",1)) if length(C2_6)>1
replace  RelatedBy = substr(C2_6,-1,1) if length(C2_6) == 1

preserve
	* keeping only the couples
	keep if ishusband3==1| iswife3==1

	* cleaning the related by variable to create a unique couple id
	replace RelatedBy = "A" if RelatedBy=="W"| RelatedBy=="H" | RelatedBy =="Y" // primary earner
	replace RelatedBy = "M" if RelatedBy == "F" // parent

	replace RelatedBy = C2_6 if length(C2_6)==2 & regexm(C2_6, "[1-9BCDEFMSTUVLNRGJKPQ]$") // spouses of son's and daughter's e.g. Y1 and Y1W need common code to be Y1 or FBW
	gen tmp1 = substr(C2_6, -2,1) if length(C2_6)==2 & regexm(C2_6, "[FM]$")
	gen tmp2 = "M" if tmp1!=""
	egen tmp3 = concat(tmp1 tmp2) if tmp1!=""
	replace RelatedBy = tmp3 if length(C2_6)==2 & regexm(C2_6, "[FM]$")
	replace RelatedBy = "FM" if C2_6 == "FFW" // this should be FM	

	replace RelatedBy = C2_6 if length(C2_6)==3 & regexm(C2_6, "[1-9BCDEFMSTUVLNRGJKPQ]$") // e.g. FB1 and FB1W

	egen Coupleid = concat(HHid RelatedBy)
	bys Coupleid: gen tmp4 = C2_4 if C2_3==1
	bys Coupleid: gen tmp5 = C2_4 if C2_3 == 2
	bys Coupleid: egen husband_age = mean(tmp4)
	bys Coupleid: egen wife_age = mean(tmp5)

	keep IndividualId ishusband3 iswife3 husband_age wife_age
	tempfile Husband_wife
	save "`Husband_wife'" //
	*save "Census Data\Husband_wife_1209", replace
	
restore

*------------------*

*Testing for Parents coded as M or F:
*First step: group all people coded as parents or siblings of any person together
gen ParentTest1 = RelatedTo if IsParent | IsSibling
replace ParentTest1 = C2_6 if ParentTest1 == ""

*Second step: get the number of people in the group
by HHid ParentTest1, sort: gen ParentTest2 = _N

*Third step: remove parents from the group; if the number in the group changes, 
*then there were parents in the group
*this is not necessarily the simplest way of doing this, but it will be robust 
*to permissible duplications of relationship codes and will
*come in handy as we check for other kinds of relationships and look for other information
*about relationships
by HHid ParentTest1: egen ParentTest3 = total(IsParent)

*Fourth step: ParentTest4 will be zero if the "group" consists only of parents--
*this is not really relevant in this case, but will be important for other types of
*relationships. 
gen ParentTest4 = 0
replace ParentTest4 = ParentTest2-ParentTest3
gen LivesWithParent = 0
*again, ParentTest4 > 0 is irrelevant in this case - the second two conditions are 
*the relevant ones: ParentTest4 < ParentTest2 identifies "groups" with parents,
*and in those groups, we want to mark everyone who is not coded as a parent as living
*with a parent
replace LivesWithParent = 1 if ParentTest4 > 0 & ParentTest4 < ParentTest2 & !IsParent 

*Now determining specifically which parent is present
*NOTE: using sex to determine whether father or mother - but the sex of the primary
*earner might have been recorded incorrectly in some cases. This has to be addressed
*when cleaning the data.
gen IsFemale = 0
replace IsFemale = 1 if C2_3 == 2

gen LivesWithMother = 0
gen LivesWithFather = 0

*using same groups, finding out specifically which parent is present
by HHid ParentTest1: egen MotherTest1 = total(IsParent*IsFemale)
replace LivesWithMother = 1 if !IsParent & MotherTest1 > 0 & MotherTest1 < .

/*
*Need to test above, make sure it works properly
gen MotherTest2 = 0
replace MotherTest2 = ParentTest2 - MotherTest1
replace LivesWithMother = 1 if MotherTest2 < ParentTest2 & !IsParent
*/

by HHid ParentTest1: egen FatherTest1 = total(IsParent*(1-IsFemale))
replace LivesWithFather = 1 if !IsParent & FatherTest1 > 0 & FatherTest1 < .
/*
gen FatherTest2 = 0
replace FatherTest2 = ParentTest2 - FatherTest1
replace LivesWithFather = 1 if FatherTest2 < ParentTest2 & !IsParent
*/

assert (!LivesWithMother & !LivesWithFather) if !LivesWithParent
assert (LivesWithMother | LivesWithFather) if LivesWithParent

*construct counts for number of children of each sex, and their average ages
gen NumDaughters = .
gen DaughterAvAge = .
gen NumSons = .
gen SonAvAge = .

gen IsDaughter = 0
replace IsDaughter = LivesWithParent*IsFemale

gen IsSon = 0
replace IsSon = LivesWithParent*(1-IsFemale)

*Using same groups, find counts of daughters and sons in each group, then assign
*this count to the parents so that the number of children of each sex living in the
*household is readily identifiable for each observation

by HHid ParentTest1: egen CountDaught1 = total(IsDaughter)
replace NumDaughters = CountDaught1 if IsParent

by HHid ParentTest1: egen CountSon1 = total(IsSon)
replace NumSons = CountSon1 if IsParent

*Find the age for each daughter and son, then use this to find the average age of
*daughters and sons.
gen DaughterAge1 = C2_4 if IsDaughter
by HHid ParentTest1: egen DaughterAge2 = mean(DaughterAge1)
replace DaughterAvAge = DaughterAge2 if IsParent & DaughterAvAge == .

gen SonAge1 = C2_4 if IsSon
by HHid ParentTest1: egen SonAge2 = mean(SonAge1)
replace SonAvAge = SonAge2 if IsParent & SonAvAge == .

*Testing if there are grandparents present - I don't know if we care about whether
*parents themselves are also living with parents, but if not, we can just comment this
*part out
*procedure here is largely the same as above, the main difference is that there will be
*more missing observations, which need to be excluded from any final counts
gen IsGP = 0
replace IsGP = 1 if regexm(C2_6,"[MF][MF]$")
gen GPTest1 = RelatedTo if IsGP
replace GPTest1 = C2_6 if IsParent & !IsGP
by HHid GPTest1, sort: gen GPTest2 = _N if GPTest1 != "" 
by HHid GPTest1: egen GPTest3 = total(IsGP) if GPTest2 < .
gen GPTest4 = GPTest2 - GPTest3
replace LivesWithParent = 1 if GPTest2 < . & !IsGP & GPTest4 < GPTest2 & GPTest4 > 0

*Test Grandmother or Grandfather:
by HHid GPTest1: egen GMTest1 = total(IsGP*IsFemale) if GPTest2 < .
replace LivesWithMother = 1 if GMTest1 > 0 & GMTest1 < . & IsParent & !IsGP
by HHid GPTest1: egen GFTest1 = total(IsGP*(1-IsFemale)) if GPTest2 < .
replace LivesWithFather = 1 if GFTest1 > 0 & GFTest1 < . & IsParent & !IsGP
/*
gen GMTest2 = GPTest2 - GMTest1
replace LivesWithMother = 1 if GPTest2 < . & GMTest2 < GPTest1 & IsParent & !IsGP
by HHid GPTest1: egen GFTest1 = total(IsGP*(1-IsFemale)) if GPTest2 < .
gen GFTest2 = GPTest2 - GFTest1
replace LivesWithFather = 1 if GPTest2 < . & GFTest2 < GPTest1 & IsParent & !IsGP
*/
assert (!LivesWithMother & !LivesWithFather) if !LivesWithParent
assert (LivesWithMother | LivesWithFather) if LivesWithParent

*Count and age of grandparents' children
replace IsDaughter = LivesWithParent*IsFemale
replace IsSon = LivesWithParent*(1-IsFemale)

*Making sure code is working right - that children counts/ages have not yet been assigned
*for grandparents

*Since grandparents might have other children in the household (siblings) that were
*counted already, need to separate these out:
gen GPNumDaught = NumDaughters if IsGP
gen GPNumSons = NumSons if IsGP
gen GPDaughtAge = DaughterAvAge if IsGP
gen GPSonAge = SonAvAge if IsGP

by HHid GPTest1: egen CountDaught2 = total(IsDaughter)
replace NumDaughters = CountDaught2 + GPNumDaught if IsGP

by HHid GPTest1: egen CountSon2 = total(IsSon)
replace NumSons = CountSon2 + GPNumSons if IsGP

*finding a weighted average:
gen DaughterAge3 = C2_4 if GPTest2 < . & IsDaughter
by HHid GPTest1: egen DaughterAge4 = mean(DaughterAge3)
gen GPDaughtSumAge1 = GPNumDaught*GPDaughtAge
replace GPDaughtSumAge1 = 0 if GPNumDaught == 0
gen GPDaughtSumAge2 = DaughterAge4*CountDaught2
replace GPDaughtSumAge2 = 0 if CountDaught2 == 0
replace DaughterAvAge = (GPDaughtSumAge1 + GPDaughtSumAge2)/NumDaughters if IsGP & NumDaughters > 0

gen SonAge3 = C2_4 if GPTest2 < . & IsSon
by HHid GPTest1: egen SonAge4 = mean(SonAge3)
gen GPSonSumAge1 = GPNumSons*GPSonAge
replace GPSonSumAge1 = 0 if GPNumSons == 0
gen GPSonSumAge2 = SonAge4*CountSon2
replace GPSonSumAge2 = 0 if CountSon2 == 0
replace SonAvAge = (GPSonSumAge1 + GPSonSumAge2)/NumSons if IsGP & NumSons > 0


*Checking that children in household are living with parents

*Creating dummies to identify "not children" (i.e. not coded as children)
gen FemaleNotChild = IsFemale*(1-IsChild)
gen MaleNotChild = (1-IsFemale)*(1-IsChild)

*Since children will sometimes have the second parent specified, have to break up
*the test for individuals coded as children into two parts: 
*part 1: testing the direct relationship,
*part 2: testing the relationship with spouses.
*will do this to identify for each child whether they have a mother and/or father present
*will find the counts/ages of sons/daughters for each parent afterwards - have 
*to make sure not double-counting

*CHILD TEST: part 1
gen ChildTest1 = RelatedTo if IsChild
*note: in this section, we test the direct relationship between children and their parents,
*removing the spouse that indicates the second parent of the child
*Thus, we remove codes of current wife or ex-wife that may come before the child's 
*relationship code
replace ChildTest1 = regexr(ChildTest1,"X?[WY]$","")
*Next command addresses the rare case where a wife has a child from a previous husband
*Note that if the husband is specified for anyone other than the wife, this would mean
*that the woman is not the mother of the child
replace ChildTest1 = regexr(ChildTest1,"XH$","") if regexm(ChildTest1,"[WY]XH$")
*Deal with adopted children:
replace ChildTest1 = regexr(ChildTest1,"Z","")

replace ChildTest1 = "A" if IsChild & ChildTest1 == ""
replace ChildTest1 = C2_6 if ChildTest1 == ""
by HHid ChildTest1, sort: gen ChildTest2 = _N
by HHid ChildTest1: egen ChildTest3 = total(IsChild)
gen ChildTest4 = ChildTest2-ChildTest3
*Testing whether there are any people remaining in the group once children are removed -
*if not, then ChildTest 4 == 0, these children are not living with their parents. 
*If there are no children in the group, then ChildTest2 == ChildTest4, and this is also 
*not of interest.
replace LivesWithParent = 1 if ChildTest4 > 0 & ChildTest4 < ChildTest2 & IsChild
*generating a dummy for being grouped with a child but not being a child - this
*will (or should) capture parents of individuals coded as children
gen ParOfCh1 = 0
replace ParOfCh1 = 1 if ChildTest3 > 0 & !IsChild
*Identify whether living with mother/father (first test)
by HHid ChildTest1: egen ChildFTest1 = total(MaleNotChild)
replace LivesWithFather = 1 if IsChild & ChildFTest1 > 0
by HHid ChildTest1: egen ChildMTest1 = total(FemaleNotChild)
replace LivesWithMother = 1 if IsChild & ChildMTest1 > 0

assert (!LivesWithMother & !LivesWithFather) if !LivesWithParent
assert (LivesWithMother | LivesWithFather) if LivesWithParent

*Child test, part 2 - looking at spouses
*Note: I have made one important assumption: that if there is a second wife ("Y"),
*she only the mother of children specified as "Y1", "Y6", etc.
*This is generally reasonable, assures we don't double-count children, and simplifies
*the coding.
gen ChildTest1b = RelatedTo if IsChild
replace ChildTest1b = regexr(ChildTest1b,"[WH]$","")
replace ChildTest1b = regexr(ChildTest1b,"Z","")
replace ChildTest1b = "A" if IsChild & ChildTest1b == ""
*Excluding children of ex-spouses from this part of the test
replace ChildTest1b = "" if IsChild & regexm(ChildTest1b,"X$")
replace ChildTest1b = RelatedTo if RelCodeLast == "W" | RelCodeLast == "H"
replace ChildTest1b = C2_6 if RelCodeLast == "Y"
by HHid ChildTest1b, sort: gen ChildTest2b = _N if ChildTest1b != ""
by HHid ChildTest1b: egen ChildTest3b = total(IsChild) if ChildTest1b != ""
gen ChildTest4b = ChildTest2b-ChildTest3b
*Testing whether there are any people remaining in the group once children are removed -
*if not, then ChildTest 4 == 0, these children are not living with their parents. 
*If there are no children in the group, then ChildTest2 == ChildTest4, and this is also 
*not of interest.
replace LivesWithParent = 1 if ChildTest2b < . & ChildTest4b > 0 & ChildTest4b < ChildTest2b & IsChild
*generating a dummy for being grouped in this part with a child but not being a child
gen ParOfCh2 = 0
replace ParOfCh2 = 1 if ChildTest3b > 0 & ChildTest3b < . & !IsChild
*just to make sure this is doing what it's supposed to
assert (IsHusband | IsWife) if ParOfCh2

*Identify whether living with mother/father
by HHid ChildTest1b: egen ChildFTest2 = total(IsHusband)
replace LivesWithFather = 1 if IsChild & ChildFTest2 > 0 & ChildFTest2 < .
by HHid ChildTest1b: egen ChildMTest2 = total(IsWife)
replace LivesWithMother = 1 if IsChild & ChildMTest2 > 0 & ChildMTest2 < .

assert (!LivesWithMother & !LivesWithFather) if !LivesWithParent
assert (LivesWithMother | LivesWithFather) if LivesWithParent

*Find counts and average ages of children for parents identified above

replace IsDaughter = LivesWithParent*IsFemale
replace IsSon = LivesWithParent*(1-IsFemale)

*generating a dummy indicating found to be a parent in one of the two tests above
gen ParOfCh = ParOfCh1 + ParOfCh2 - (ParOfCh1*ParOfCh2)
assert (ParOfCh == 0 | ParOfCh == 1)

assert NumDaughters == . & NumSons == . & DaughterAvAge == . & SonAvAge == . if ParOfCh & !IsParent

*Have to deal with parents who have other children in the household which have already
*been identified in the parent or grandparent tests above (mostly this will be when the 
*father has children through a younger wife)
gen pnod = NumDaughters if IsParent
gen pnos = NumSons if IsParent
gen pad = DaughterAvAge if IsParent
gen pas = SonAvAge if IsParent

*In order to deal with double counting the same children for the same parents across the 
*two child tests, generating a third variable that concatenates the two ChildTest1 
*variables
*I'm pretty sure there will only be double counting when there's an "H" and "H1"/"H6",
*which will be quite rare

gen ChildTest1c = ChildTest1 + ChildTest1b

by HHid ChildTest1, sort: egen CCountDaught1a = total(IsDaughter*IsChild)
by HHid ChildTest1b, sort: egen CCountDaught1b = total(IsDaughter*IsChild) if ChildTest1b != ""
replace CCountDaught1b = 0 if CCountDaught1b == .
by HHid ChildTest1c, sort: egen CCountDaught1c = total(IsDaughter*IsChild) if ChildTest1b != ""
replace CCountDaught1c = 0 if CCountDaught1c == .
gen CCountDaught = CCountDaught1a + CCountDaught1b - CCountDaught1c

replace NumDaughters = CCountDaught if ParOfCh & !IsParent
replace NumDaughters = CCountDaught + pnod if ParOfCh & IsParent

by HHid ChildTest1, sort: egen CCountSon1a = total(IsSon*IsChild)
by HHid ChildTest1b, sort: egen CCountSon1b = total(IsSon*IsChild) if ChildTest1b != ""
replace CCountSon1b = 0 if CCountSon1b == .
by HHid ChildTest1c, sort: egen CCountSon1c = total(IsSon*IsChild) if ChildTest1b != ""
replace CCountSon1c = 0 if CCountSon1c == .
gen CCountSon = CCountSon1a + CCountSon1b - CCountSon1c
replace NumSons = CCountSon if ParOfCh & !IsParent
replace NumSons = CCountSon + pnos if ParOfCh & IsParent

*Ages (weighted averages for those coded as parents)
gen CDaughterAge = C2_4 if IsDaughter & IsChild
by HHid ChildTest1, sort: egen CDaughterAge2a = total(CDaughterAge)
by HHid ChildTest1b, sort: egen CDaughterAge2b = total(CDaughterAge)
replace CDaughterAge2b = 0 if ChildTest1b == ""
by HHid ChildTest1c, sort: egen CDaughterAge2c = total(CDaughterAge)
replace CDaughterAge2c = 0 if ChildTest1b == ""
gen CDaughterAgeSum = CDaughterAge2a + CDaughterAge2b - CDaughterAge2c
assert CDaughterAgeSum < .
gen CDaughterAge2 = CDaughterAgeSum/CCountDaught if CCountDaught > 0 & ParOfCh 
replace DaughterAvAge = CDaughterAge2 if ParOfCh & !IsParent

gen padsum1 = pad*pnod if IsParent & ParOfCh
replace padsum1 = 0 if pnod == 0
gen padsum2 = CDaughterAgeSum if IsParent & ParOfCh
replace DaughterAvAge = (padsum1 + padsum2)/NumDaughters if IsParent & ParOfCh

gen CSonAge = C2_4 if IsSon & IsChild
by HHid ChildTest1, sort: egen CSonAge2a = total(CSonAge)
by HHid ChildTest1b, sort: egen CSonAge2b = total(CSonAge)
replace CSonAge2b = 0 if ChildTest1b == ""
by HHid ChildTest1c, sort: egen CSonAge2c = total(CSonAge)
replace CSonAge2c = 0 if ChildTest1b == ""
gen CSonAgeSum = CSonAge2a + CSonAge2b - CSonAge2c
assert CSonAgeSum < . 
gen CSonAge2 = CSonAgeSum/CCountSon if CCountSon > 0 & ParOfCh
replace SonAvAge = CSonAge2 if ParOfCh & !IsParent

gen passum1 = pas*pnos if IsParent & ParOfCh
replace passum1 = 0 if pnos == 0
gen passum2 = CSonAgeSum if IsParent & ParOfCh
replace SonAvAge = (passum1 + passum2)/NumSons if IsParent & ParOfCh

*Next need to check grandchildren - not going to worry about multiple wives in this case
*identifying grandchildren
gen IsGC = 0
replace IsGC = 1 if IsChild & regexm(RelatedTo,"[0-9GJKPQ]$")
*constructing groups of people coded as children and those people's spouses and children
gen GCTest1 = RelatedTo if IsGC
replace GCTest1 = C2_6 if IsChild & !IsGC
replace GCTest1 = RelatedTo if (IsHusband | IsWife) & regexm(RelatedTo,"[0-9GJKPQ]$")
by HHid GCTest1, sort: gen GCTest2 = _N if GCTest1 != ""
by HHid GCTest1: egen GCTest3 = total(IsGC)
gen GCTest4 = GCTest2 - GCTest3
*If GCTest4 == 0, then there are grandchildren in the house without their parents
*If GCTest4 >= GCTest2 when there are granchildren present, then something is wrong with
*the way this code is written.
assert GCTest4 < GCTest2 if IsGC
replace LivesWithParent = 1 if IsGC & GCTest4 > 0 & GCTest4 < .

*Testing whether living with mother/father
*Need new binary for child or child's spouse but not grandchild - calling it NotGC
*although this is a little misleading because many non-grandchildren will have a value
*of 0 in this variable
gen NotGC = 0
replace NotGC = 1 if GCTest1 != "" & !IsGC

by HHid GCTest1: egen GCMotherTest1 = total(NotGC*IsFemale)
replace LivesWithMother = 1 if GCMotherTest1 > 0 & GCMotherTest1 < . & IsGC

by HHid GCTest1: egen GCFatherTest1 = total(NotGC*(1-IsFemale))
replace LivesWithFather = 1 if GCFatherTest1 > 0 & GCFatherTest1 < . & IsGC

assert (!LivesWithMother & !LivesWithFather) if !LivesWithParent
assert (LivesWithMother | LivesWithFather) if LivesWithParent

*Count and age of children's children
replace IsDaughter = LivesWithParent*IsFemale
replace IsSon = LivesWithParent*(1-IsFemale)

*making sure this is being done for the right people by checking that children count and
*average ages have not yet been calculated for the people labeled NotGC:
assert NumDaughters == . & NumSons == . & DaughterAvAge == . & SonAvAge == . if NotGC & !IsWife & !IsHusband

by HHid GCTest1: egen GCCountDaught = total(IsDaughter*IsGC) if GCTest1 != ""
replace NumDaughters = GCCountDaught if NotGC & !IsWife & !IsHusband

by HHid GCTest1: egen GCCountSon = total(IsSon*IsGC) if GCTest1 != ""
replace NumSons = GCCountSon if NotGC & !IsWife & !IsHusband

gen GDaughterAge = C2_4 if IsGC & IsDaughter
by HHid GCTest1: egen GDaughterAge2 = mean(GDaughterAge)
replace DaughterAvAge = GDaughterAge2 if NotGC & !IsWife & !IsHusband

gen GSonAge = C2_4 if IsGC & IsSon
by HHid GCTest1: egen GSonAge2 = mean(GSonAge)
replace SonAvAge = GSonAge2 if NotGC & !IsWife & !IsHusband

*There should be very few people coded as great-grandchildren or great-grandparents,
*so such cases should be handled manually
gen GG = regexm(C2_6,"([MF][MF][MF])|([0-9GJKPQ][0-9GJKPQ][0-9GJKPQ])$")
by HHid, sort: egen CheckManually = total(GG)
egen Tag = tag(HHid)

list HHid if Tag & CheckManually > 0

*Note: some son/daughter counts are still not filled in at this point. Here I replace
*these missing counts with 0, but I create a varibale to indicate that the counts were 
*missing, so some of these can be checked manually to make sure they seem accurate
gen ChildCountsMissing = 0
replace ChildCountsMissing = 1 if NumSons == . & NumDaughters == .

replace NumSons = 0 if NumSons == .
replace NumDaughters = 0 if NumDaughters == .

order HHid A1 C2_3 C2_4 C2_6 LivesWithParent LivesWithMother LivesWithFather NumDaughters DaughterAvAge NumSons SonAvAge, last

* Adding the identifier for husband and wife
merge 1:1 IndividualId using "`Husband_wife'"
* merge 1:1 IndividualId using "Census Data\Husband_wife_1209"
drop _merge

replace ishusband3 = 0 if ishusband3==.
replace iswife3 = 0 if iswife3==.

replace husband_age = . if C2_3==1
replace wife_age= . if C2_3==2 

