/*=========================================================================
Project: Wealth, marriage and sex selection
Author: Girija Borker, Jan Eeckhout, Nancy Luke, Shantidani Minz, Kaivan 
Munshi and Soumya Swaminathan. 
---------------------------------------------------------------------------
Do file: 3_hh_structure.do
=========================================================================*/

* Method 1
	sort C2_6
	by C2_6: gen q=1 if _n==1
	gen qx=sum(q)
	su qx

	forvalues val=`r(min)'/`r(max)'{
	gen c2_6_temp`val'=1 if qx==`val'
		replace c2_6_temp`val'=0 if qx!=`val'
		preserve
			keep if qx==`val'
			local newname  = C2_6[1]
		restore
		bys HHid: egen max_c2_6_temp`val' = max(c2_6_temp`val') //assigning dummy to whole HH
		rename max_c2_6_temp`val' C2_6_`newname'
		di "Running for `val'"
	}
	drop q
	drop c2_6_temp*

//save "Census Data/merged_stock_c2_withchild_reldum_$date.dta", replace 


//use "Census Data/merged_stock_c2_withchild_reldum_$date.dta", clear

drop if C2_6=="0"

cap drop pe_sex* fs
bys HHid: egen pe_sex_temp = mean(C2_3) if C2_6=="A"
bys HHid: egen pe_sex = max(pe_sex_temp)

* Family structure described
gen fs = .

* One member HH - only pe
replace fs=0 if C2_6_A==1 & C1==1

* Family with pe and pe's wife 
* A, WY
replace fs = 1 if C2_6_A==1 & (C2_6_W==1|C2_6_Y==1) & C1==2

* A is female
replace fs = 1 if C2_6_A==1 & C2_6_H==1 & C1==2


* hh with pe, pe's wife and their kids 
* A, WY, 1-9GJKOPQ

* pe male

	* Wife W
		replace fs = 2 if C2_6_A==1 & (C2_6_W==1) & ///
		(C2_6_1==1|C2_6_2==1|C2_6_3==1|C2_6_4==1|C2_6_5==1|C2_6_G==1|C2_6_6==1|C2_6_7==1|C2_6_8==1|C2_6_9==1) // C2_6_J==1|C2_6_K==1|C2_6_O==1|C2_6_P==1|C2_6_Q==1

		* just pe and kids
		replace fs = 2 if C2_6_A==1 & ///
		(C2_6_1==1|C2_6_2==1|C2_6_3==1|C2_6_4==1|C2_6_5==1|C2_6_G==1|C2_6_6==1|C2_6_7==1|C2_6_8==1|C2_6_9==1) // C2_6_J==1|C2_6_K==1|C2_6_O==1|C2_6_P==1|C2_6_Q==1
		
		* children coded as W1
		replace fs = 2 if C2_6_A==1 & ///
		(C2_6_W1==1|C2_6_W2==1|C2_6_W3==1|C2_6_W6==1|C2_6_W7==1|C2_6_W8==1) // C2_6_J==1|C2_6_K==1|C2_6_O==1|C2_6_P==1|C2_6_Q==1
		
		* dead wife's kids
		replace fs = 2 if C2_6_A==1 & ///
		(C2_6_XW1==1|C2_6_XW2==1|C2_6_XW3==1|C2_6_XW4==1|C2_6_XW6==1|C2_6_XW7==1|C2_6_XW8==1|C2_6_XW9==1) // C2_6_J==1|C2_6_K==1|C2_6_O==1|C2_6_P==1|C2_6_Q==1
		

	* Wife Y
		replace fs = 2 if C2_6_A==1 & (C2_6_Y==1) & ///
		(C2_6_Y1==1|C2_6_Y2==1|C2_6_Y3==1|C2_6_4==1|C2_6_Y6==1|C2_6_Y7==1|C2_6_Y8==1)
		
		* just pe and kids
		replace fs = 2 if C2_6_A==1 & ///
		(C2_6_Y1==1|C2_6_Y2==1|C2_6_Y3==1|C2_6_4==1|C2_6_Y6==1|C2_6_Y7==1|C2_6_Y8==1)
		
		* dead wife's kids
		replace fs = 2 if C2_6_A==1 & ///
		(C2_6_XY1==1|C2_6_XY2==1|C2_6_XY6==1|C2_6_XY7==1) // C2_6_J==1|C2_6_K==1|C2_6_O==1|C2_6_P==1|C2_6_Q==1
		
	
* pe female
	replace fs = 2 if C2_6_A==1 & (C2_6_H==1) & ///
	(C2_6_1==1|C2_6_2==1|C2_6_3==1|C2_6_4==1|C2_6_5==1|C2_6_G==1|C2_6_6==1|C2_6_7==1|C2_6_8==1|C2_6_9==1) // C2_6_J==1|C2_6_K==1|C2_6_O==1|C2_6_P==1|C2_6_Q==1


* hh with pe + family , his/her brother and family - by each brother code B C D E
	* we count all both families with and wihout a wife i.e just brother and kids and just brother's wife and kids
	
	gen num_sib=. // identifies the number of siblings with families in the following do files
	
	do "${subcode}/3_1_just_brother.do"
	
	* family with pe + family , his/her sister and family - by each brother code S T, U V excluded because no U/ V's with a husband

	do "${subcode}/3_2_just_sister.do"

* pe has no kids but the siblings do
	* MALE PRIMARY EARNER
	replace fs = 51 if js==. & jb==1 & pe_sex==1 & fs==.
	replace fs = 52 if js==1 & jb==. & pe_sex ==1 & fs==.
	replace fs = 5 if (js==1 & jb==1) & pe_sex ==1 & fs==. // either sibling's family lives with pe
	
	* his wife's siblings
	replace fs = 61 if ws==. & wb==1 & C2_6_W==1 & pe_sex==1 & fs==.
	replace fs = 62 if ws==1 & wb==. & C2_6_W==1 & pe_sex==1 & fs==.
	replace fs = 6 if ws==1 & wb==1 & C2_6_W==1 & pe_sex==1 & fs==.

	* FEMALE PRIMARY EARNER
	replace fs = 51 if hb==1 & hs==. & C2_6_H==1 & pe_sex==2 & fs==. // siblings of the husband matter for property purposes
	replace fs = 52 if hs==1 & hb==. & C2_6_H==1 & pe_sex ==2 & fs==.
	replace fs = 5 if (hs==1 & hb==1) & C2_6_H==1 & pe_sex ==2 & fs==. // either sibling's family lives with pe
	
	* the woman's siblings
	replace fs = 61 if js==. & jb==1 & pe_sex==2 & fs==.
	replace fs = 62 if js==1 & jb==. & pe_sex==2 & fs==.
	replace fs = 6 if js==1 & jb==1 & pe_sex==2 & fs==.

* hh with siblings
	* MALE PRIMARY EARNER
	replace fs = 31 if js==. & jb==1 & fs==2 & pe_sex==1
	replace fs = 32 if js==1 & jb==. & fs==2 & pe_sex ==1
	replace fs = 3 if (js==1 & jb==1) & fs==2 & pe_sex ==1 // either sibling's family lives with pe
	
	* his wife's siblings
	replace fs = 41 if ws==. & wb==1 & fs==2 & pe_sex==1
	replace fs = 42 if ws==1 & wb==. & fs==2 & pe_sex==1
	replace fs = 4 if ws==1 & wb==1 & fs==2 & pe_sex==1

	* FEMALE PRIMARY EARNER
	replace fs = 31 if hb==1 & hs==. & fs==2 & pe_sex==2 // siblings of the husband matter for property purposes
	replace fs = 32 if hs==1 & hb==. & fs==2 & pe_sex ==2
	replace fs = 3 if (hs==1 & hb==1) & fs==2 & pe_sex ==2 // either sibling's family lives with pe
	
	* the woman's siblings
	replace fs = 41 if js==. & jb==1 & fs==2 & pe_sex==2
	replace fs = 42 if js==1 & jb==. & fs==2 & pe_sex==2
	replace fs = 4 if js==1 & jb==1 & fs==2 & pe_sex==2

* hh with children of children (grandchildren of pe)

	gen num_child = .

	* daughter's family
	do "${subcode}/3_3_daughter_family.do"

	* son's family
	do "${subcode}/3_4_son_family.do"
	

* pe and children's family
replace fs = 7 if fs== 2 & (df==1 | sf==1) // just pe family and his kids' family

replace fs = 8 if (fs==3 | fs==31 | fs==32) & (df==1 | sf==1)  // pe family, sibling's family and kids' family

* pe with grandchildren (his or others)
gen RelBy2 = reverse(subinstr(reverse(C2_6),RelCodeLast,"",1)) if length(C2_6)>1 // All but the last letter in relationship code
gen gc = 1 if regexm(C2_6, "[1-9GJKOPQ]$") & regexm(RelBy2, "[1-9GJKOPQ]$") & length(RelBy2)==1
replace gc = 1 if regexm(C2_6, "[1-9GJKOPQ]$") & regexm(RelBy2, "[1-9GJKOPQ][W]$") & length(RelBy2)==2
replace gc = 1 if regexm(C2_6, "[1-9GJKOPQ]$") & regexm(RelBy2, "[X][1-9GJKOPQ]$") & length(RelBy2)==2
replace gc = 1 if regexm(C2_6, "[1-9GJKOPQ]$") & regexm(RelBy2, "[W][1-9GJKOPQ]$") & length(RelBy2)==2
replace gc = 1 if regexm(C2_6, "[1-9GJKOPQ]$") & regexm(RelBy2, "[Y][1-9GJKOPQ]$") & length(RelBy2)==2
replace gc = 1 if regexm(C2_6, "[1-9GJKOPQ]$") & regexm(RelBy2, "[X][W][1-9GJKOPQ]$") & length(RelBy2)==3
replace gc = 1 if regexm(C2_6, "[1-9GJKOPQ]$") & regexm(RelBy2, "[F][BCDESTUV][1-9GJKOPQ]$") & length(RelBy2)==3
replace gc = 1 if regexm(C2_6, "[1-9GJKOPQ]$") & regexm(RelBy2, "[BCDESTUV][1-9GJKOPQ]$") & length(RelBy2)==2

bys HHid: egen grandchild = max(gc)

* pe with child generation
gen child_gen = 1 if regexm(C2_6, "[1-9GJKOPQ]$") & length(C2_6)==1
replace child_gen = 1 if regexm(C2_6, "[X][W][1-9GJKOPQ]$") & length(C2_6)==3
replace child_gen = 1 if regexm(C2_6, "[Y][1-9GJKOPQ]$") & length(C2_6)==2
replace child_gen = 1 if regexm(C2_6, "[Z][1-9GJKOPQ]$") & length(C2_6)==2
replace child_gen = 1 if regexm(C2_6, "[1-9GJKOPQ]$") & regexm(RelBy2, "[BCDESTUV]$") & length(RelBy2)==1
replace child_gen = 1 if regexm(C2_6, "[1-9GJKOPQ]$") & regexm(RelBy2, "[BCDESTUV][W]$") & length(RelBy2)==2
replace child_gen = 1 if regexm(C2_6, "[1-9GJKOPQ]$") & regexm(RelBy2, "[X][BCDESTUV]$") & length(RelBy2)==2
replace child_gen = 1 if regexm(C2_6, "[1-9GJKOPQ]$") & regexm(RelBy2, "[F][BCDESTUV]$") & length(RelBy2)==2

bys HHid: egen childgen = max(child_gen)

replace fs = 71 if fs== 2 & (df==. | sf==.) & grandchild==1
				
replace fs= 10 if (C2_6_A==1 |C2_6_W==1) & grandchild==1 & fs==.
replace fs = 11 if C2_6_A==1 & childgen==1 & fs==.

* hh where pe and siblings are the children/ living with parents with no families of their own
replace fs = 9 if (C2_6_M==1|C2_6_F==1) & (C2_6_A==1| C2_6_B==1|C2_6_C==1| C2_6_D==1|C2_6_E==1| C2_6_S==1|C2_6_T==1| C2_6_U==1| C2_6_V==1) & fs==.

* misc
replace fs = 9999 if fs==.

* estimating number of multiple child bearing families within HHs
gen mcbf = .
lab var mcbf "Number of multiple child bearing families within a HH"

replace mcbf = 1 if fs==2 | fs==9

* PE with sibling's families
bys HHid: egen num_sib_fam = total(num_sib) if fs==3|fs==31|fs==32| fs==4|fs==41|fs==42| fs==5|fs==51|fs==52|fs==6|fs==61|fs==62

replace mcbf = num_sib_fam +1 if fs==3|fs==31|fs==32|fs==4|fs==41|fs==42 // add pe's family to the counted siblings' families
replace mcbf = num_sib_fam if fs==5|fs==51|fs==52|fs==6|fs==61|fs==62 // pe has no family, just need to count sibling families

* PE with children's families
bys HHid: egen num_child_fam = total(num_child) if (fs==7|fs==8)
replace mcbf = num_child_fam + 1 if fs==7 // adding pe's family

replace num_sib_fam=0 if (fs==7|fs==8) & num_sib_fam==.
replace num_child_fam=0 if (fs==7|fs==8) & num_child_fam==.

replace mcbf = num_sib_fam + num_child_fam + 1 if fs==8

* label values of fs
lab def fs 0 "Only pe"	// no child bearing family (cbf)										
lab def fs 1 "Only pe and wife - two member HH", add // no cbf
lab def fs 2 "Pe and family", add // 1 cbf
// Maximum types of HH comes under this, e.g. MS living in the HH

lab def fs 3 "Pe's family and the male head's brother(s) and sister(s) family", add // count
lab def fs 31 "Pe's family and the male head's brother's family", add
lab def fs 32 "Pe's family and the male head's sister's family", add

lab def fs 4 "Pe's family and the female head's brother(s) and sister(s) family", add // count
lab def fs 41 "Pe's family and the female head's brother's family", add
lab def fs 42 "Pe's family and the female head's sister's family", add

lab def fs 5 "The male head with his brother(s) and sister(s) family", add // count
lab def fs 51 "The male head with only his brother's family", add
lab def fs 52 "The male head with only his sister's family", add

lab def fs 6 "The female head with his brother(s) and sister(s) family", add // count
lab def fs 61 "The female head with only his brother's family", add
lab def fs 62 "The female head with only his sister's family", add

lab def fs 7 "Pe's family and children's family", add // count
lab def fs 71 "Pe and family with grandchild (no parents) ", add // atleats one child of the pe along with a rogue grandchild

lab def fs 8 "Pe's family, sibling's family and children's family", add // count
lab def fs 9 "Pe and siblings living with their parents", add // 1 cbf
lab def fs 10 "Pe with grandchildren", add // no cbf, pe with no child but with a grandchild (his or others)
lab def fs 11 "Pe with siblings children", add
lab def fs 9999 "Miscellaneous", add // no cbf

//label values fs fs

drop C2_6_*

save "${coded}/CompleteData_clean_10Oct2015.dta", replace
