*<<<<<<< Updated upstream:code/stata/6_hypergamy_analyses_with_histdata.do
/*=========================================================================
Project: Wealth, marriage and sex selection
Author: Johannes Maywald
---------------------------------------------------------------------------
Do file: 6_hypergamy_analyses_with_histdata.do

Hypergamy 
=========================================================================*/

	clear all
	set more off


*** Survey   ***

*global Date "2018-01-30" 	// (not necessarily update, unless references in tex document are also updated) "2018-01-11"
global Date "2018-02-01" 	// (not necessarily update, unless references in tex document are also updated) "2018-01-11"

	*cap mkdir "output" 	// only creates new directory if non-existent

	use "${raw}/2017-11-23_married_couples_pred_income_1871.dta" , clear // generated with dofile: "2017-10-19_Hypergamy_Analyses_with_Hist1871Data.do"

	*tab  person questionnaire

// NOTE: When using macros,"\$"  will be translated into "$" => use / forward slash instead.

***   Add variables    ***

	gen age = .
	gen educ =""
	gen occup=""

	do "${subcode}/6_1_add_sichs_Variables.do" 	// age education (occupation) dowry (from raw data)
 														// requires custom ado-file "LoadMergeSICHSVariables"
	*save "${Data}/2018-01-29_AddedSICHS_Variables.dta"
	*use  "${Data}/2018-01-29_AddedSICHS_Variables.dta", clear 	// => use temp dataset instead


*exit

	*sum age, detail
	*sum age if generation==2 , detail
	*sum age if generation==3 , detail

	replace age=. if age<15 | age>100 // outliers

	*sum age if marriage_partner==1 	// bride
	*sum age if marriage_partner==2 	// groom

	sort generation couple_id
	by generation: sum age, detail

	*sum age if marriage_partner==1 	// bride
	*sum age if marriage_partner==2 	// groom
	*tab  educ, missing

	do "${subcode}/6_2_educyears_from_code.do"

	*sum EdYears, detail
	sort generation

	by generation: sum EdYears, detail

	*** ADD CENSUS FOR EDUCATION DISTRIBUTION ***

	*tab age person
	*tab EdYears person

	gen sex = marriage_partner

	*cd "T:/Census Data"

	merge m:1 sex age caste EdYears using "${coded}/2018-01-10_RelEduc.dta"

	*tab 	_merge
	drop if _merge==2
	drop 	_merge


	/*** CHECK if sample is "representative" ***
	hist rel_educ
	hist rel_educ_sex
	hist rel_educ_caste
	hist rel_educ_sex_caste 	// use rel_educ_Xcns instead

	hist age
	hist age if age<=56 , freq
	sum age if age<=56

	*** Relative Education from Survey ***/


	forvalues age_span = 0/10 {
		gen 	rel_educ_`age_span'svy = .
		quietly{
		forvalues age_x = 16/40 {

			bys sex caste: egen 	rank_educ 		= rank(EdYears) 			if age>=`age_x'-`age_span' &  age<=`age_x'+`age_span'
			by  sex caste: replace rank_educ 		= rank_educ-1 				if age>=`age_x'-`age_span' &  age<=`age_x'+`age_span'
			by  sex caste: egen 	rank_educ_max 	= max(rank_educ) 			if age>=`age_x'-`age_span' &  age<=`age_x'+`age_span'

			replace rel_educ_`age_span'svy 	= 	rank_educ/rank_educ_max if age==`age_x'
			drop 								rank_educ rank_educ_max
		}
		}
		display "Age range: `age_span'"
		corr rel_educ_`age_span'svy rel_educ_`age_span'cns

	}

	scatter rel_educ_2svy rel_educ_2cns
	scatter rel_educ_5svy rel_educ_5cns
	scatter rel_educ_10svy rel_educ_10cns


	*** Dowry ***

	//cd "T:/HH survey"
	do "${subcode}/6_3_calculate_dowry.do"


	/*sum dowry 		, detail
	sum dowry_calc 	if person==ownchild  , detail 
	sum dowry_calc 	if person=="son"  , detail 
	sum dowry_calc 	if person=="daughter"  , detail 
	sum dowry_agg 	, detail

	*** SAMPLE ***/
	// NOTE if we were only to restrict the sample later, then the relative measure would be calculated for all

	* ORIGINAL SAMPLE *
	*keep 	if (generation==2 | generation==3)  & age<=56  /// parents & children under 56, i.e. born after 1960

	* TEST OLDER GENERATION * 29 Jan 2018
	*drop 	if (generation==2 | generation==3)  & age<=56

	* Children only *
	*keep if generation==3

	* Children and parents born after 1980 *
	keep 	if (generation==2 | generation==3)  & age<=36

	//	drop if id1871_1==id1871_2
	count // 

	*** rel wealth // rank ***

	// Note: use ALL Survey Households for the relative measure, not just those currently still in the data.

	preserve
		do "${subcode}/6_4_predict_income.do" 		// predict income for all survey households, creates dataset below
				
		sort caste
		by caste: egen 	rank_income 	= rank(predicted1871income)
		replace 		rank_income 	= rank_income-1
		by caste: egen 	rank_income_max = max(rank_income)

		gen rel_wealth_SICHS = rank_income / rank_income_max

		tempfile RelWealthSICHS
		save `RelWealthSICHS'
	restore
	
	append using `RelWealthSICHS'


	*** Relative wealth position from SICHS wealth distribution. ***
	
	replace predicted1871income = pred_income_hist1871_ 	if missing(predicted1871income) 	// fill the SICHS predicted income, with the marriage data

	sort caste
	by   caste: 	ipolate rel_wealth_SICHS predicted1871income, gen(rel_wealth) epolate

	replace rel_wealth=0 	if rel_wealth<0 & !missing(rel_wealth)	// restrict bottom, 21 changes made
	replace rel_wealth=1 	if rel_wealth>1 & !missing(rel_wealth) 	// restrict top, 16 changes made

	hist rel_wealth

	*** Relative wealth position for married people only ***
	
	sort caste marriage_partner

	by caste: 					egen rank_pred_income 				= rank(pred_income_hist1871_)
	replace 	rank_pred_income = 	 rank_pred_income-1 // shift 1 down so that 1 is richtest and 0 poorest
	by caste: 					egen max_rank_pred_income 			= max(rank_pred_income)

	gen rel_wealth_married 	= 	rank_pred_income / max_rank_pred_income 	// relative wealth 0-1 within caste

	hist rel_wealth_married


	*** INSPECT MISSING DATA ***

	count if !missing(pred_income_hist1871_) & !missing(dowry_calc) & marriage_partner==1 // bride
	br if !missing(pred_income_hist1871_) & !missing(dowry_calc) & marriage_partner==1 // bride

	// 518, girls with dowries in the data, and we can predict their income

	reg dowry_calc pred_income_hist1871_ i.caste if marriage_partner==1
	// NOTE: low coefficient

	// collapse couples into a single observation and compare the income of husband and wife

	*br 		if missing(marriage_partner) 	// no information on own child's sex
	drop 	if missing(marriage_partner) 	// only 1 case

	// values of variable marriage_partner not unique within couple_id
	duplicates tag couple_id marriage_partner, gen(_marriage_partner_not_unique)
	*br 		if 	_marriage_partner_not_unique>0 	// 1 case seems like RSN is wrong ?

	drop 	if 	_marriage_partner_not_unique>0 & rsn==51 | _marriage_partner_not_unique>0 & rsn==52
	drop 		_marriage_partner_not_unique

	rename id1871 id1871_

	count if missing(pred_income_hist1871_) 	// 5,949 			31.07%
	count // 19,146 							// predicted for 	69% INDIVIDUALS 

	*sum pred_income_hist1871_, detail
	*hist pred_income_hist1871_

	*** percentiles of wealth ***
	
	forval i= 1/5{
		di `i'
	    egen p`i' = pctile(pred_income_hist1871_) , p(`i')
	}

	
	forval i =95/99 {
		di `i'
	    egen p`i' = pctile(pred_income_hist1871_) , p(`i')
	}
	*sum p1-p99

	*drop if pred_income_hist1871_<p3 
	*drop if pred_income_hist1871_>p97

	drop p1-p99
	gen log_pred_income_hist1871_ = log(pred_income_hist1871_)

//preserve
	local id_vars 		"generation caste age id1871_ p_code"
	local dowry_vars 	"dowry dowry_calc"
	local income_vars 	"pred_income_hist1871_ log_pred_income_hist1871_"
	local rel_wealth 	"rel_wealth rel_wealth_married"
	ds 	EdYears rel_educ_*svy rel_educ_*cns
	local educ_vars = r(varlist) 	// 
	
	*** COMBINE -  ***
	local reg_varlist 	"`id_vars' `dowry_vars' `income_vars' `rel_wealth' `educ_vars'"
	display "`reg_varlist'"

	keep couple_id marriage_partner `reg_varlist'


*** RESHAPE from INDIVIDUALS to COUPLES *** 
*---------------------------------------------------------------------------------------------------------------------------------------------------------------
	reshape wide `reg_varlist' , i(couple_id) j(marriage_partner)

	 * clustering on caste* village
       egen caste_panch = group(caste1 p_code1)
	
	// dowry is one directional (by construction)
	egen dowry 		= rowtotal(dowry1 		dowry2) 	 if generation1==3
	egen dowry_calc = rowtotal(dowry_calc1 	dowry_calc2) if generation1==3

	*sum dowry_calc1 dowry_calc2 dowry_calc, detail

	count if !missing(dowry_calc) & !missing(pred_income_hist1871_1)
	count if missing(pred_income_hist1871_1) | missing(pred_income_hist1871_2) // 3,756 	39.23% 	=> 61%
	count // 9,574  

	*sum dowry_calc1 dowry_calc2 dowry_calc, detail

	count if !missing(dowry_calc) & !missing(pred_income_hist1871_1)

	*sum pred_income_hist1871_1 pred_income_hist1871_1 if generation1==2, detail

	label values generation1 lbl_generation

	label variable pred_income_hist1871_1 	"predicted (1871) wealth of bride"
	label variable pred_income_hist1871_2 	"predicted (1871) wealth of groom"
	
	label variable log_pred_income_hist1871_1 	"log predicted (1871) wealth of bride"
	label variable log_pred_income_hist1871_2 	"log predicted (1871) wealth of groom"

	*sum     pred_income_hist1871_1 , detail // bride
	*sum log_pred_income_hist1871_1 , detail // bride

	*sum     pred_income_hist1871_2 , detail // groom
	*sum log_pred_income_hist1871_2 , detail // groom

*** Regressions ***

	local rel_educ_var "rel_educ_5cns"

		drop if missing(rel_wealth2) | missing(rel_wealth1) | missing(`rel_educ_var'2) | missing(`rel_educ_var'1)
		count // 708

	label variable log_pred_income_hist1871_1 "Log wealth of bride"
	label variable age1 			"Age of bride"
	label variable EdYears1 		"Education of bride"

	label variable rel_wealth1 "Rel. wealth of bride"
	label variable rel_educ_5svy1 "Rel. education of bride"

	*=================================================================

	*** BASELINE (wealth matching only) *** 
	eststo rel_wlth: 	reg rel_wealth2 rel_wealth1, cluster(caste_panch)
	*sum rel_wealth2 if e(sample)==1
	estadd scalar mean_wealth2 	r(mean)
	test _b[rel_wealth1] = 1 		// = 45 degree line	
	estadd scalar p_value1 =	r(p)/2
	estadd local caste_fe "No"

	eststo rel_wlth_educ: 	reg rel_wealth2 rel_wealth1 `rel_educ_var'1, cluster(caste_panch)
	*sum rel_wealth2 if e(sample)==1
	estadd scalar mean_wealth2 	r(mean)
	test _b[rel_wealth1] = 1 		// = 45 degree line	
	estadd scalar p_value1 =	r(p)/2
	estadd local caste_fe "No"

	*** Education matching *** 
	eststo rel_educ_wlth: 	reg `rel_educ_var'2 `rel_educ_var'1 rel_wealth1, cluster(caste_panch)
	*sum `rel_educ_var'2 if e(sample)==1
	estadd scalar mean_educ2 	r(mean)
	test _b[`rel_educ_var'1] = 1 		// = 45 degree line	
	estadd scalar p_value1 =	r(p)/2
	estadd local caste_fe "No"

	*=================================================================

	lpoly `rel_educ_var'2  rel_wealth1,  bw(0.02)

	*** Age of Bride ***
	eststo rel_wlth_age: 		reg rel_wealth2 rel_wealth1 age1  
	*sum rel_wealth2 if e(sample)==1
	estadd scalar mean_wealth2 	r(mean)
	test _b[rel_wealth1] = 1 		// = 45 degree line	
	estadd scalar p_value1 =	r(p)/2
	estadd local caste_fe "No"

	*** Wealth relative to those married (within sample) ***
	eststo rel_wlth_m_age: 	reg rel_wealth_married2 rel_wealth_married1 age1  // married
	*sum rel_wealth_married2 if e(sample)==1
	estadd scalar mean_wealth2 	r(mean)
	test _b[rel_wealth_married1] = 1 		// = 45 degree line	
	estadd scalar p_value1 =	r(p)/2
	estadd local caste_fe "No"


	*** Education Rank by age ***

	foreach wealth_var in rel_wealth rel_wealth_married {

		if "`wealth_var'"=="rel_wealth" {
			local rel_wlth = "rel_wlth"
		}

		if "`wealth_var'"=="rel_wealth_married" {
			local rel_wlth = "rel_wlth_m"
		}

		foreach data in cns svy {

			foreach age_range of numlist 0/10 {

				cap drop rel_educ_`data'
				generate rel_educ_`data' = rel_educ_`age_range'`data'1
				label variable rel_educ_`data' "Rel. Educ. Bride (`data')"

				eststo `rel_wlth'_educ_`age_range'`data': 		reg `wealth_var'2 `wealth_var'1  rel_educ_`data'
				sum `wealth_var'2 if e(sample)==1
				estadd scalar mean_wealth2 	r(mean)
				test _b[`wealth_var'1] = 1 		// = 45 degree line	
				estadd scalar p_value1 =	r(p)/2
				estadd local caste_fe "No"

				eststo `rel_wlth'_age_educ_`age_range'`data': 		reg `wealth_var'2 `wealth_var'1 age1 rel_educ_`data'
				sum `wealth_var'2 if e(sample)==1
				estadd scalar mean_wealth2 	r(mean)
				test _b[`wealth_var'1] = 1 		// = 45 degree line	
				estadd scalar p_value1 =	r(p)/2
				estadd local caste_fe "No"
			}

		}

	}



	*** COMPARE RELATIVE EDUCATION MEASURES ***

	/*
	* Survey *
	esttab 	rel_wlth 	rel_wlth_educ_0svy 		rel_wlth_educ_1svy 		rel_wlth_educ_2svy 		rel_wlth_educ_3svy 	rel_wlth_educ_4svy 	 			///
			rel_wlth_educ_5svy 		rel_wlth_educ_6svy 		rel_wlth_educ_7svy 		rel_wlth_educ_8svy 		rel_wlth_educ_9svy 	rel_wlth_educ_10svy ///
	 		using "${output_dir}/${Date}_Table_Reg_Hypergamy_RelWlth_EducSVY10.tex" , replace ///
	 		cells( b( fmt(3) star vacant("--") )  se( fmt(3) par ) )  starlevels(* 0.10 ** 0.05 *** 0.01) ///
	 		scalars("caste_fe Caste FE") /// indicate("Caste FE=*caste1") ///
	 		indicate("", label("" "")) /// blank row before obs.
 		/// scalars("p_value1  $ H_0 : \beta_{wealth} \geq 1 $, p" "mean_wealth2 Mean of dep. variable ")  sfmt(3 3) ///
	 		label nonotes /*booktabs*/ fragment collabels(none) nomtitles nolines plain substitute(_ _)  /// only the very core of the numbers, any additional formatting/headers in LaTex instead.

	* Census *
	esttab 	rel_wlth 	rel_wlth_educ_0cns 		rel_wlth_educ_1cns 		rel_wlth_educ_2cns 		rel_wlth_educ_3cns 	rel_wlth_educ_4cns 	 			///
			rel_wlth_educ_5cns 		rel_wlth_educ_6cns 		rel_wlth_educ_7cns 		rel_wlth_educ_8cns 		rel_wlth_educ_9cns 	rel_wlth_educ_10cns ///
	 		using "${output_dir}/${Date}_Table_Reg_Hypergamy_RelWlth_EducCNS10.tex" , replace ///
	 		cells( b( fmt(3) star vacant("--") )  se( fmt(3) par ) )  starlevels(* 0.10 ** 0.05 *** 0.01) ///
	 		scalars("caste_fe Caste FE") /// indicate("Caste FE=*caste1") ///
	 		indicate("", label("" "")) /// blank row before obs.
 		/// scalars("p_value1  $ H_0 : \beta_{wealth} \geq 1 $, p" "mean_wealth2 Mean of dep. variable ")  sfmt(3 3) ///
	 		label nonotes /*booktabs*/ fragment collabels(none) nomtitles nolines plain substitute(_ _)  /// only the very core of the numbers, any additional formatting/headers in LaTex instead.


	*** EDUCATION MATCHING ***
	esttab 	rel_wlth 	rel_wlth_educ_0cns 		rel_wlth_educ_1cns 		rel_wlth_educ_2cns 		rel_wlth_educ_3cns 	rel_wlth_educ_4cns 	 			///
			rel_wlth_educ_5cns 		rel_wlth_educ_6cns 		rel_wlth_educ_7cns 		rel_wlth_educ_8cns 		rel_wlth_educ_9cns 	rel_wlth_educ_10cns ///
	 		using "${output_dir}/${Date}_Table_Reg_Hypergamy_RelWlth_EducCNS10.tex" , replace ///
	 		cells( b( fmt(3) star vacant("--") )  se( fmt(3) par ) )  starlevels(* 0.10 ** 0.05 *** 0.01) ///
	 		scalars("caste_fe Caste FE") /// indicate("Caste FE=*caste1") ///
	 		indicate("", label("" "")) /// blank row before obs.
 		/// scalars("p_value1  $ H_0 : \beta_{wealth} \geq 1 $, p" "mean_wealth2 Mean of dep. variable ")  sfmt(3 3) ///
	 		label nonotes /*booktabs*/ fragment collabels(none) nomtitles nolines plain substitute(_ _)  /// only the very core of the numbers, any additional formatting/headers in LaTex instead.

	*/


	label variable rel_wealth1 "Rel. Wealth Bride"
	label variable rel_wealth_married1 "Rel. Wealth Bride (married)"


	forvalues a=0/7 {
		label variable rel_educ_`a'svy1 "Rel. Educ. Bride (survey`a')"
		label variable rel_educ_`a'cns1 "Rel. Educ. Bride (census`a')"

	}



*****************
*** FOR PAPER ***
*****************

	label variable rel_wealth1 "Rel. wealth of bride"
	label variable rel_educ_5svy1 "Rel. education of bride"

	label variable `rel_educ_var'1 		"Rel. educ. of bride"


	*** Table 5 - Hypergamy and Relative Wealth ***

	esttab 	rel_wlth rel_wlth_educ rel_educ_wlth  ///
	 		using "${out}/tables/${Date}_Table_Reg_Hypergamy_EducCNS.tex" , replace ///
	 		keep(rel_wealth1  `rel_educ_var'1	_cons) ///
	 		order(rel_wealth1 `rel_educ_var'1	_cons) ///
	 		cells( b( fmt(3) star vacant("--") )  se( fmt(3) par ) )  starlevels(** 0.05 *** 0.01) ///
	 		scalars("caste_fe Caste FE") /// indicate("Caste FE=*caste1") ///
	 		indicate("", label("" "")) /// blank row before obs.
 		/// scalars("p_value1  $ H_0 : \beta_{wealth} \geq 1 $, p" "mean_wealth2 Mean of dep. variable ")  sfmt(3 3) ///
	 		label nonotes /*booktabs*/ fragment collabels(none) nomtitles nolines plain substitute(_ _)  /// only the very core of the numbers, any additional formatting/headers in LaTex instead.



*****************
*** FOR PAPER ***
*****************

		*** Figure 3 - Hypergamy and Relative Wealth ***
		graph twoway  	(line rel_wealth1 rel_wealth1  ,  lcolor(black) lwidth(0.05) ) /// 45 degree line
			 		  	(lpolyci 	rel_wealth2 		rel_wealth1  			, bw(0.02)  color(blue) fintensity(inten30) alcolor(white) alwidth(none) ) /// alstyle(none) acolor(blue) 
			 		  	(lpoly 		rel_wealth_married2 rel_wealth_married1  	, bw(0.02)  lcolor(red) lpattern(dash) lwidth(medthick)) ///
			 		 , legend( order(3 4) style(column) ///
			 		 			label(3 "Rank based on all households in the caste") ///
			 		 			label(4 "Rank based on households with marriages") ///
			 		 		 ) ///
			 		  ytitle("Groom's rank in caste wealth distribution") ///
			 		  xtitle("Bride's rank in caste wealth distribution") ///
			 		 graphregion(fcolor(white) lcolor(white)) 

		graph export  "${out}/figures/${Date}_Fig_Hypergamy_comb.pdf" , replace


* diff in relative wealth
gen diff_rel_wealth = rel_wealth1 - rel_wealth2	
*sum diff_rel_wealth, d	
		

/*
	local rel_educ_var "rel_educ_5cns"
	*local rel_educ_var "rel_educ_5svy"

		* Figure - Education Matching*
		graph twoway  	(line `rel_educ_var'1 `rel_educ_var'1  ,  lcolor(black) lwidth(0.05) ) /// 45 degree line
			 		  	(lpolyci 	`rel_educ_var'2 		`rel_educ_var'1  			, bw(0.02)  color(blue) fintensity(inten30) alcolor(white) alwidth(none) ) /// alstyle(none) acolor(blue) 
			 		 , legend( order(3) style(column) ///
			 		 			label(3 "Rank based on Females/Males max. 5 years older/younger in the caste") ///
			 		 		 ) ///
			 		  ytitle("Groom's rank in caste education distribution") ///
			 		  xtitle("Bride's rank in caste education distribution") ///
			 		 graphregion(fcolor(white) lcolor(white)) 


		graph export  "${Output}/${Date}_Fig_Hypergamy_Education.pdf" , replace

*/



exit /////////////////////////////////////////

reg rel_wealth2 rel_wealth1 age1 rel_educ_5svy1
reg rel_wealth2 rel_wealth1 age1 rel_educ_5svy1 c.rel_educ_5svy1#c.rel_wealth1 	// does not make much sense...

=======
/*=========================================================================
Project: Wealth, marriage and sex selection
Author: Johannes Maywald
---------------------------------------------------------------------------
Do file: 6_hypergamy_analyses_with_histdata.do

Hypergamy 

Input: 2017-11-23_married_couples_pred_income_1871.dta
=========================================================================*/

	clear all
	set more off

*** Survey   ***

*global Date "2018-01-30" 	// (not necessarily update, unless references in tex document are also updated) "2018-01-11"
global Date "2018-02-01" 	// (not necessarily update, unless references in tex document are also updated) "2018-01-11"

	*cap mkdir "output" 	// only creates new directory if non-existent

	use "${raw}/2017-11-23_married_couples_pred_income_1871.dta" , clear // generated with dofile: "2017-10-19_Hypergamy_Analyses_with_Hist1871Data.do"

	*tab  person questionnaire

// NOTE: When using macros,"\$"  will be translated into "$" => use / forward slash instead.

***   Add variables    ***

	gen age = .
	gen educ =""
	gen occup=""

	do "${subcode}/6_1_add_sichs_Variables.do" 	// age education (occupation) dowry (from raw data)
 	// requires custom ado-file "LoadMergeSICHSVariables"
	*save "${Data}/2018-01-29_AddedSICHS_Variables.dta"
	*use  "${Data}/2018-01-29_AddedSICHS_Variables.dta", clear 	// => use temp dataset instead


*exit

	*sum age, detail
	*sum age if generation==2 , detail
	*sum age if generation==3 , detail

	replace age=. if age<15 | age>100 // outliers

	*sum age if marriage_partner==1 	// bride
	*sum age if marriage_partner==2 	// groom

	sort generation couple_id
	by generation: sum age, detail

	*sum age if marriage_partner==1 	// bride
	*sum age if marriage_partner==2 	// groom
	*tab  educ, missing

	do "${subcode}/6_2_educyears_from_code.do"

	*sum EdYears, detail
	sort generation

	by generation: sum EdYears, detail

	*** ADD CENSUS FOR EDUCATION DISTRIBUTION ***

	*tab age person
	*tab EdYears person

	gen sex = marriage_partner

	*cd "T:/Census Data"

	merge m:1 sex age caste EdYears using "${coded}/2018-01-10_RelEduc.dta"

	*tab 	_merge
	drop if _merge==2
	drop 	_merge


	/*** CHECK if sample is "representative" ***
	hist rel_educ
	hist rel_educ_sex
	hist rel_educ_caste
	hist rel_educ_sex_caste 	// use rel_educ_Xcns instead

	hist age
	hist age if age<=56 , freq
	sum age if age<=56

	*** Relative Education from Survey ***/


	forvalues age_span = 0/10 {
		gen 	rel_educ_`age_span'svy = .
		quietly{
		forvalues age_x = 16/40 {

			bys sex caste: egen 	rank_educ 		= rank(EdYears) 			if age>=`age_x'-`age_span' &  age<=`age_x'+`age_span'
			by  sex caste: replace rank_educ 		= rank_educ-1 				if age>=`age_x'-`age_span' &  age<=`age_x'+`age_span'
			by  sex caste: egen 	rank_educ_max 	= max(rank_educ) 			if age>=`age_x'-`age_span' &  age<=`age_x'+`age_span'

			replace rel_educ_`age_span'svy 	= 	rank_educ/rank_educ_max if age==`age_x'
			drop 								rank_educ rank_educ_max
		}
		}
		display "Age range: `age_span'"
		corr rel_educ_`age_span'svy rel_educ_`age_span'cns

	}

	scatter rel_educ_2svy rel_educ_2cns
	scatter rel_educ_5svy rel_educ_5cns
	scatter rel_educ_10svy rel_educ_10cns


	*** Dowry ***

	//cd "T:/HH survey"
	do "${subcode}/6_3_calculate_dowry.do"

	/*sum dowry 		, detail
	sum dowry_calc 	if person==ownchild  , detail 
	sum dowry_calc 	if person=="son"  , detail 
	sum dowry_calc 	if person=="daughter"  , detail 
	sum dowry_agg 	, detail

	*** SAMPLE ***/
	// NOTE if we were only to restrict the sample later, then the relative measure would be calculated for all

	* ORIGINAL SAMPLE *
	*keep 	if (generation==2 | generation==3)  & age<=56  /// parents & children under 56, i.e. born after 1960

	* TEST OLDER GENERATION * 29 Jan 2018
	*drop 	if (generation==2 | generation==3)  & age<=56

	* Children only *
	*keep if generation==3

	* Children and parents born after 1980 *
	keep 	if (generation==2 | generation==3)  & age<=36

	//	drop if id1871_1==id1871_2
	count // 

	*** rel wealth // rank ***

	// Note: use ALL Survey Households for the relative measure, not just those currently still in the data.

	preserve
		do "${subcode}/6_4_predict_income.do" 		// predict income for all survey households, creates dataset below
				
		sort caste
		by caste: egen 	rank_income 	= rank(predicted1871income)
		replace 		rank_income 	= rank_income-1
		by caste: egen 	rank_income_max = max(rank_income)

		gen rel_wealth_SICHS = rank_income / rank_income_max

		tempfile RelWealthSICHS
		save `RelWealthSICHS'
	restore
	
	append using `RelWealthSICHS'


	*** Relative wealth position from SICHS wealth distribution. ***
	
	replace predicted1871income = pred_income_hist1871_ 	if missing(predicted1871income) 	// fill the SICHS predicted income, with the marriage data

	sort caste
	by   caste: 	ipolate rel_wealth_SICHS predicted1871income, gen(rel_wealth) epolate

	replace rel_wealth=0 	if rel_wealth<0 & !missing(rel_wealth)	// restrict bottom, 21 changes made
	replace rel_wealth=1 	if rel_wealth>1 & !missing(rel_wealth) 	// restrict top, 16 changes made

	hist rel_wealth

	*** Relative wealth position for married people only ***
	
	sort caste marriage_partner

	by caste: 					egen rank_pred_income 				= rank(pred_income_hist1871_)
	replace 	rank_pred_income = 	 rank_pred_income-1 // shift 1 down so that 1 is richtest and 0 poorest
	by caste: 					egen max_rank_pred_income 			= max(rank_pred_income)

	gen rel_wealth_married 	= 	rank_pred_income / max_rank_pred_income 	// relative wealth 0-1 within caste

	hist rel_wealth_married


	*** INSPECT MISSING DATA ***

	count if !missing(pred_income_hist1871_) & !missing(dowry_calc) & marriage_partner==1 // bride
	br if !missing(pred_income_hist1871_) & !missing(dowry_calc) & marriage_partner==1 // bride

	// 518, girls with dowries in the data, and we can predict their income

	reg dowry_calc pred_income_hist1871_ i.caste if marriage_partner==1
	// NOTE: low coefficient

	// collapse couples into a single observation and compare the income of husband and wife

	*br 		if missing(marriage_partner) 	// no information on own child's sex
	drop 	if missing(marriage_partner) 	// only 1 case

	// values of variable marriage_partner not unique within couple_id
	duplicates tag couple_id marriage_partner, gen(_marriage_partner_not_unique)
	*br 		if 	_marriage_partner_not_unique>0 	// 1 case seems like RSN is wrong ?

	drop 	if 	_marriage_partner_not_unique>0 & rsn==51 | _marriage_partner_not_unique>0 & rsn==52
	drop 		_marriage_partner_not_unique

	rename id1871 id1871_

	count if missing(pred_income_hist1871_) 	// 5,949 			31.07%
	count // 19,146 							// predicted for 	69% INDIVIDUALS 

	*sum pred_income_hist1871_, detail
	*hist pred_income_hist1871_

	*** percentiles of wealth ***
	
	forval i= 1/5{
		di `i'
	    egen p`i' = pctile(pred_income_hist1871_) , p(`i')
	}

	
	forval i =95/99 {
		di `i'
	    egen p`i' = pctile(pred_income_hist1871_) , p(`i')
	}
	*sum p1-p99

	*drop if pred_income_hist1871_<p3 
	*drop if pred_income_hist1871_>p97

	drop p1-p99
	gen log_pred_income_hist1871_ = log(pred_income_hist1871_)

//preserve
	local id_vars 		"generation caste age id1871_"
	local dowry_vars 	"dowry dowry_calc"
	local income_vars 	"pred_income_hist1871_ log_pred_income_hist1871_"
	local rel_wealth 	"rel_wealth rel_wealth_married"
	ds 	EdYears rel_educ_*svy rel_educ_*cns
	local educ_vars = r(varlist) 	// 
	
	*** COMBINE -  ***
	local reg_varlist 	"`id_vars' `dowry_vars' `income_vars' `rel_wealth' `educ_vars'"
	display "`reg_varlist'"

	keep couple_id marriage_partner `reg_varlist'


*** RESHAPE from INDIVIDUALS to COUPLES *** 
*---------------------------------------------------------------------------------------------------------------------------------------------------------------
	reshape wide `reg_varlist' , i(couple_id) j(marriage_partner)

	// dowry is one directional (by construction)
	egen dowry 		= rowtotal(dowry1 		dowry2) 	 if generation1==3
	egen dowry_calc = rowtotal(dowry_calc1 	dowry_calc2) if generation1==3

	*sum dowry_calc1 dowry_calc2 dowry_calc, detail

	count if !missing(dowry_calc) & !missing(pred_income_hist1871_1)
	count if missing(pred_income_hist1871_1) | missing(pred_income_hist1871_2) // 3,756 	39.23% 	=> 61%
	count // 9,574  

	*sum dowry_calc1 dowry_calc2 dowry_calc, detail

	count if !missing(dowry_calc) & !missing(pred_income_hist1871_1)

	*sum pred_income_hist1871_1 pred_income_hist1871_1 if generation1==2, detail

	label values generation1 lbl_generation

	label variable pred_income_hist1871_1 	"predicted (1871) wealth of bride"
	label variable pred_income_hist1871_2 	"predicted (1871) wealth of groom"
	
	label variable log_pred_income_hist1871_1 	"log predicted (1871) wealth of bride"
	label variable log_pred_income_hist1871_2 	"log predicted (1871) wealth of groom"

	*sum     pred_income_hist1871_1 , detail // bride
	*sum log_pred_income_hist1871_1 , detail // bride

	*sum     pred_income_hist1871_2 , detail // groom
	*sum log_pred_income_hist1871_2 , detail // groom

*** Regressions ***

	local rel_educ_var "rel_educ_5cns"

		drop if missing(rel_wealth2) | missing(rel_wealth1) | missing(`rel_educ_var'2) | missing(`rel_educ_var'1)
		count // 708

	label variable log_pred_income_hist1871_1 "Log wealth of bride"
	label variable age1 			"Age of bride"
	label variable EdYears1 		"Education of bride"

	label variable rel_wealth1 "Rel. wealth of bride"
	label variable rel_educ_5svy1 "Rel. education of bride"

	*=================================================================

	*** BASELINE (wealth matching only) *** 
	eststo rel_wlth: 	reg rel_wealth2 rel_wealth1
	*sum rel_wealth2 if e(sample)==1
	estadd scalar mean_wealth2 	r(mean)
	test _b[rel_wealth1] = 1 		// = 45 degree line	
	estadd scalar p_value1 =	r(p)/2
	estadd local caste_fe "No"

	eststo rel_wlth_educ: 	reg rel_wealth2 rel_wealth1 `rel_educ_var'1
	*sum rel_wealth2 if e(sample)==1
	estadd scalar mean_wealth2 	r(mean)
	test _b[rel_wealth1] = 1 		// = 45 degree line	
	estadd scalar p_value1 =	r(p)/2
	estadd local caste_fe "No"

	*** Education matching *** 
	eststo rel_educ_wlth: 	reg `rel_educ_var'2 `rel_educ_var'1 rel_wealth1
	*sum `rel_educ_var'2 if e(sample)==1
	estadd scalar mean_educ2 	r(mean)
	test _b[`rel_educ_var'1] = 1 		// = 45 degree line	
	estadd scalar p_value1 =	r(p)/2
	estadd local caste_fe "No"

	*=================================================================

	lpoly `rel_educ_var'2  rel_wealth1,  bw(0.02)

	*** Age of Bride ***
	eststo rel_wlth_age: 		reg rel_wealth2 rel_wealth1 age1  
	*sum rel_wealth2 if e(sample)==1
	estadd scalar mean_wealth2 	r(mean)
	test _b[rel_wealth1] = 1 		// = 45 degree line	
	estadd scalar p_value1 =	r(p)/2
	estadd local caste_fe "No"

	*** Wealth relative to those married (within sample) ***
	eststo rel_wlth_m_age: 	reg rel_wealth_married2 rel_wealth_married1 age1  // married
	*sum rel_wealth_married2 if e(sample)==1
	estadd scalar mean_wealth2 	r(mean)
	test _b[rel_wealth_married1] = 1 		// = 45 degree line	
	estadd scalar p_value1 =	r(p)/2
	estadd local caste_fe "No"


	*** Education Rank by age ***

	foreach wealth_var in rel_wealth rel_wealth_married {

		if "`wealth_var'"=="rel_wealth" {
			local rel_wlth = "rel_wlth"
		}

		if "`wealth_var'"=="rel_wealth_married" {
			local rel_wlth = "rel_wlth_m"
		}

		foreach data in cns svy {

			foreach age_range of numlist 0/10 {

				cap drop rel_educ_`data'
				generate rel_educ_`data' = rel_educ_`age_range'`data'1
				label variable rel_educ_`data' "Rel. Educ. Bride (`data')"

				eststo `rel_wlth'_educ_`age_range'`data': 		reg `wealth_var'2 `wealth_var'1  rel_educ_`data'
				sum `wealth_var'2 if e(sample)==1
				estadd scalar mean_wealth2 	r(mean)
				test _b[`wealth_var'1] = 1 		// = 45 degree line	
				estadd scalar p_value1 =	r(p)/2
				estadd local caste_fe "No"

				eststo `rel_wlth'_age_educ_`age_range'`data': 		reg `wealth_var'2 `wealth_var'1 age1 rel_educ_`data'
				sum `wealth_var'2 if e(sample)==1
				estadd scalar mean_wealth2 	r(mean)
				test _b[`wealth_var'1] = 1 		// = 45 degree line	
				estadd scalar p_value1 =	r(p)/2
				estadd local caste_fe "No"
			}

		}

	}

	*** COMPARE RELATIVE EDUCATION MEASURES ***

	/*
	* Survey *
	esttab 	rel_wlth 	rel_wlth_educ_0svy 		rel_wlth_educ_1svy 		rel_wlth_educ_2svy 		rel_wlth_educ_3svy 	rel_wlth_educ_4svy 	 			///
			rel_wlth_educ_5svy 		rel_wlth_educ_6svy 		rel_wlth_educ_7svy 		rel_wlth_educ_8svy 		rel_wlth_educ_9svy 	rel_wlth_educ_10svy ///
	 		using "${output_dir}/${Date}_Table_Reg_Hypergamy_RelWlth_EducSVY10.tex" , replace ///
	 		cells( b( fmt(3) star vacant("--") )  se( fmt(3) par ) )  starlevels(* 0.10 ** 0.05 *** 0.01) ///
	 		scalars("caste_fe Caste FE") /// indicate("Caste FE=*caste1") ///
	 		indicate("", label("" "")) /// blank row before obs.
 		/// scalars("p_value1  $ H_0 : \beta_{wealth} \geq 1 $, p" "mean_wealth2 Mean of dep. variable ")  sfmt(3 3) ///
	 		label nonotes /*booktabs*/ fragment collabels(none) nomtitles nolines plain substitute(_ _)  /// only the very core of the numbers, any additional formatting/headers in LaTex instead.

	* Census *
	esttab 	rel_wlth 	rel_wlth_educ_0cns 		rel_wlth_educ_1cns 		rel_wlth_educ_2cns 		rel_wlth_educ_3cns 	rel_wlth_educ_4cns 	 			///
			rel_wlth_educ_5cns 		rel_wlth_educ_6cns 		rel_wlth_educ_7cns 		rel_wlth_educ_8cns 		rel_wlth_educ_9cns 	rel_wlth_educ_10cns ///
	 		using "${output_dir}/${Date}_Table_Reg_Hypergamy_RelWlth_EducCNS10.tex" , replace ///
	 		cells( b( fmt(3) star vacant("--") )  se( fmt(3) par ) )  starlevels(* 0.10 ** 0.05 *** 0.01) ///
	 		scalars("caste_fe Caste FE") /// indicate("Caste FE=*caste1") ///
	 		indicate("", label("" "")) /// blank row before obs.
 		/// scalars("p_value1  $ H_0 : \beta_{wealth} \geq 1 $, p" "mean_wealth2 Mean of dep. variable ")  sfmt(3 3) ///
	 		label nonotes /*booktabs*/ fragment collabels(none) nomtitles nolines plain substitute(_ _)  /// only the very core of the numbers, any additional formatting/headers in LaTex instead.


	*** EDUCATION MATCHING ***
	esttab 	rel_wlth 	rel_wlth_educ_0cns 		rel_wlth_educ_1cns 		rel_wlth_educ_2cns 		rel_wlth_educ_3cns 	rel_wlth_educ_4cns 	 			///
			rel_wlth_educ_5cns 		rel_wlth_educ_6cns 		rel_wlth_educ_7cns 		rel_wlth_educ_8cns 		rel_wlth_educ_9cns 	rel_wlth_educ_10cns ///
	 		using "${output_dir}/${Date}_Table_Reg_Hypergamy_RelWlth_EducCNS10.tex" , replace ///
	 		cells( b( fmt(3) star vacant("--") )  se( fmt(3) par ) )  starlevels(* 0.10 ** 0.05 *** 0.01) ///
	 		scalars("caste_fe Caste FE") /// indicate("Caste FE=*caste1") ///
	 		indicate("", label("" "")) /// blank row before obs.
 		/// scalars("p_value1  $ H_0 : \beta_{wealth} \geq 1 $, p" "mean_wealth2 Mean of dep. variable ")  sfmt(3 3) ///
	 		label nonotes /*booktabs*/ fragment collabels(none) nomtitles nolines plain substitute(_ _)  /// only the very core of the numbers, any additional formatting/headers in LaTex instead.

	*/


	label variable rel_wealth1 "Rel. Wealth Bride"
	label variable rel_wealth_married1 "Rel. Wealth Bride (married)"


	forvalues a=0/7 {
		label variable rel_educ_`a'svy1 "Rel. Educ. Bride (survey`a')"
		label variable rel_educ_`a'cns1 "Rel. Educ. Bride (census`a')"

	}



*****************
*** FOR PAPER ***
*****************

	label variable rel_wealth1 "Rel. wealth of bride"
	label variable rel_educ_5svy1 "Rel. education of bride"

	label variable `rel_educ_var'1 		"Rel. educ. of bride"


	*** Table 3 - Hypergamy and Relative Wealth ***

	esttab 	rel_wlth rel_wlth_educ rel_educ_wlth  ///
	 		using "${out}/tables/${Date}_Table_Reg_Hypergamy_EducCNS.tex" , replace ///
	 		keep(rel_wealth1  `rel_educ_var'1	_cons) ///
	 		order(rel_wealth1 `rel_educ_var'1	_cons) ///
	 		cells( b( fmt(3) star vacant("--") )  se( fmt(3) par ) )  starlevels(** 0.05 *** 0.01) ///
	 		scalars("caste_fe Caste FE") /// indicate("Caste FE=*caste1") ///
	 		indicate("", label("" "")) /// blank row before obs.
 		/// scalars("p_value1  $ H_0 : \beta_{wealth} \geq 1 $, p" "mean_wealth2 Mean of dep. variable ")  sfmt(3 3) ///
	 		label nonotes /*booktabs*/ fragment collabels(none) nomtitles nolines plain substitute(_ _)  /// only the very core of the numbers, any additional formatting/headers in LaTex instead.



*****************
*** FOR PAPER ***
*****************
/*
		*** Figure 3 - Hypergamy and Relative Wealth ***
		graph twoway  	(line rel_wealth1 rel_wealth1  ,  lcolor(black) lwidth(0.05) ) /// 45 degree line
			 		  	(lpolyci 	rel_wealth2 		rel_wealth1  			, bw(0.02)  color(blue) fintensity(inten30) alcolor(white) alwidth(none) ) /// alstyle(none) acolor(blue) 
			 		  	(lpoly 		rel_wealth_married2 rel_wealth_married1  	, bw(0.02)  lcolor(red) lpattern(dash) lwidth(medthick)) ///
			 		 , legend( order(3 4) style(column) ///
			 		 			label(3 "Rank based on all households in the caste") ///
			 		 			label(4 "Rank based on households with marriages") ///
			 		 		 ) ///
			 		  ytitle("Groom's rank in caste wealth distribution") ///
			 		  xtitle("Bride's rank in caste wealth distribution") ///
			 		 graphregion(fcolor(white) lcolor(white)) 

		graph export  "output/figures/${Date}_Fig_Hypergamy_comb.pdf" , replace
*/

* diff in relative wealth
gen diff_rel_wealth = rel_wealth1 - rel_wealth2	
*sum diff_rel_wealth, d	
		

/*
	local rel_educ_var "rel_educ_5cns"
	*local rel_educ_var "rel_educ_5svy"

		* Figure - Education Matching*
		graph twoway  	(line `rel_educ_var'1 `rel_educ_var'1  ,  lcolor(black) lwidth(0.05) ) /// 45 degree line
			 		  	(lpolyci 	`rel_educ_var'2 		`rel_educ_var'1  			, bw(0.02)  color(blue) fintensity(inten30) alcolor(white) alwidth(none) ) /// alstyle(none) acolor(blue) 
			 		 , legend( order(3) style(column) ///
			 		 			label(3 "Rank based on Females/Males max. 5 years older/younger in the caste") ///
			 		 		 ) ///
			 		  ytitle("Groom's rank in caste education distribution") ///
			 		  xtitle("Bride's rank in caste education distribution") ///
			 		 graphregion(fcolor(white) lcolor(white)) 


		graph export  "${Output}/${Date}_Fig_Hypergamy_Education.pdf" , replace

*/



exit /////////////////////////////////////////

reg rel_wealth2 rel_wealth1 age1 rel_educ_5svy1
reg rel_wealth2 rel_wealth1 age1 rel_educ_5svy1 c.rel_educ_5svy1#c.rel_wealth1 	// does not make much sense...

