/*=========================================================================
Project: Wealth, marriage and sex selection
Author: Girija Borker, Jan Eeckhout, Nancy Luke, Shantidani Minz, Kaivan 
Munshi and Soumya Swaminathan. 
---------------------------------------------------------------------------
Do file: 7_bootstrap_breg.do
Purpose: it runs the benchmark specification for sex selection and bootstraps the SE
=========================================================================*/


clear all
set more off
*capture log close
set seed 1234

* global sexselection "C:/Users/WB521990/Dropbox/RAship/submission"
	
* cd $sexselection

global PredictedIncome pred_income_cluster_vfe //pred_income
global PredictedIncome_new 
global ns = 500

use "${coded}/DataForReg.dta", clear

do "${subcode}/7_1_coding_breg.do"
	
	* Table 5, col 4-6
	* I * rank based on actual/reported income divided by family size
			gen inc_famsize= monthlyincome/(total_yg_own+2) if LivesWithFather==1 & LivesWithMother==1 & d_youngestgen==1
			
			gen log_inc_famsize = log(inc_famsize)
			
			sort caste log_inc_famsize
			bys caste log_inc_famsize : gen newid = 1 if _n==1
			by caste: gen rank_inc_famsize = sum(newid) if inc_famsize!=.
			
			bys caste: egen num_ranks = max(rank_inc_famsize)

			gen ref_rank_inc_famsize = rank_inc_famsize/num_ranks
			lab var ref_rank_inc_famsize "Rank in caste wealth distribution"
			
			drop newid
			drop num_ranks
	
	* II * rank based on predicted income per OWN youngest generation/ OWN child +2 (not directly estimated)
			gen pred_inc_younggen2p =.
			replace pred_inc_younggen2p = $PredictedIncome /(total_yg_own+2) if LivesWithFather==1 & LivesWithMother==1 & d_youngestgen==1
			lab var pred_inc_younggen2p "Predicted HH montlyincome divided by no. in the youngest generation+ 2(parents)"
			
			gen log_pred_inc_younggen2p = log(pred_inc_younggen2p)
			
			sort caste log_pred_inc_younggen2p
			bys caste log_pred_inc_younggen2p : gen newid = 1 if _n==1
			by caste: gen rank_pred_inc_yg2p = sum(newid) if pred_inc_younggen2p!=.
			
			bys caste: egen num_ranks = max(rank_pred_inc_yg2p)

			gen ref_rank_pred_inc_yg2p = rank_pred_inc_yg2p/num_ranks
			lab var ref_rank_pred_inc_yg2p "Rank in within caste income distribution"
			
			drop newid
			drop num_ranks	
					
	
	/* new predicted income
			gen pred_inc_yg2p_new =.
			replace pred_inc_yg2p_new = $PredictedIncome_new /(total_yg_own+2) if LivesWithFather==1 & LivesWithMother==1 & d_girl6!=. & d_youngestgen==1
			lab var pred_inc_yg2p_new "Predicted HH montlyincome new divided by no. in the youngest generation+ 2 parents"
			
			gen log_pred_inc_yg2p_new = log(pred_inc_yg2p_new)
			
			sort caste log_pred_inc_yg2p_new
			bys caste log_pred_inc_yg2p_new : gen newid = 1 if _n==1
			by caste: gen rank_pred_inc_yg2p_new = sum(newid) if pred_inc_yg2p_new!=.
			
			bys caste: egen num_ranks = max(rank_pred_inc_yg2p_new)

			gen ref_rank_pred_inc_yg2p_new = rank_pred_inc_yg2p_new/num_ranks
			lab var ref_rank_pred_inc_yg2p_new "Rank in within caste income distribution"
			
			drop newid
			drop num_ranks	                                 */
			
	* III * rank based on predicted income per OWN youngest generation/ OWN child +2 (not directly estimated)
	* for all HH in caste with atleast one under 6
	* not just HH where child lives with both parents 

			gen pred_inc_yg2p06 =.
			replace pred_inc_yg2p06 = $PredictedIncome /(total_yg_own+2) if LivesWithFather==1 & LivesWithMother==1 & d_girl6!=.
			lab var pred_inc_yg2p06 "Predicted HH montlyincome divided by no. in the youngest generation+ 2 parents"

			gen log_pred_inc_yg2p06 = log(pred_inc_yg2p06)
			sort caste log_pred_inc_yg2p06
			bys caste log_pred_inc_yg2p06 : gen newid = 1 if _n==1
			by caste: gen rank_pred_inc_yg2p06 = sum(newid) if pred_inc_yg2p06!=.
			bys caste: egen num_ranks = max(rank_pred_inc_yg2p06)

			gen ref_rank_pred_inc_yg2p06 = rank_pred_inc_yg2p06/num_ranks
			lab var ref_rank_pred_inc_yg2p06 "Rank in caste wealth distribution"

			drop newid
			drop num_ranks	
			
		* family size is assumed to be young generation plus two pare
			gen famsize = total_yg_own+2

	* IV * rank based on pca of per capita income, parental education and current landholdings

			sort caste pred_income_pca
			bys caste pred_income_pca : gen newid = 1 if _n==1
			by caste: gen rank_pred_inc_pca = sum(newid) if pred_income_pca!=.
			bys caste: egen num_ranks = max(rank_pred_inc_pca)

			gen ref_rank_pred_inc_pca = rank_pred_inc_pca/num_ranks
			lab var ref_rank_pred_inc_pca "Rank in caste wealth distribution"

			drop newid
			drop num_ranks	
			
*Prepare data for second stage
	keep if fs==2 | fs==9
	// lab def fs 2 "Pe and family", add
	// lab def fs 9 "Pe and siblings living with their parents", add

	preserve
	
		keep A2 caste pred_inc* d_girl6 HH_malehead_ed HH_femalehead_ed ref_rank_* C5_acre famsize* inc_famsize d_bo1 d_girl713 numHH* caste_A2

		save "${coded}/data_for_robinson", replace
	
	restore
	drop pred_inc_yg2p06
	
	*******************************************************
	*regressions using actual income and predicted income *
	*******************************************************
			
	* benchmark regression		
		local ranklist pred_inc_yg2p
		local reglist d_girl6

				foreach reg of local reglist{
					foreach ranktype of local ranklist{
						* income per child *
						eststo bmark_col01: reghdfe `reg' ref_rank_inc_famsize if pred_inc_younggen2p!=. & inc_famsize!=. & ref_rank_pred_inc_pca!=., absorb(caste A2) vce(cluster A2) noconstant
						
						matrix define first = J(10,1,.)
						mat first[1,1] = e(b)
						mat A = r(table)
						mat first[2,1] = A[2,1...]
						su d_girl6 if e(sample)==1
						qui estadd scalar control_mean = r(mean)
						global mean1 : display %4.3fc `r(mean)'
						global obs : display %12.0fc `r(N)'
						qui estadd local caste_fe = "Yes"
						qui estadd local village_fe = "Yes"
						
						eststo bmark_col1: reghdfe `reg' ref_rank_pred_inc_pca if pred_inc_younggen2p!=. & inc_famsize!=., absorb(caste A2) vce(cluster A2)
						
						matrix beta_`reg'1 =  e(b)'
						su `reg' if e(sample)==1
						qui estadd scalar control_mean = r(mean)
						global mean1 : display %4.3fc `r(mean)'
						global obs : display %12.0fc `r(N)'
						qui estadd local caste_fe = "Yes"
						qui estadd local village_fe = "Yes"					
		
						eststo bmark_col2: reghdfe `reg' ref_rank_`ranktype' if pred_inc_younggen2p!=. & inc_famsize!=. & ref_rank_pred_inc_pca!=., absorb(caste A2) vce(cluster caste_A2)
						matrix beta_`reg'2 =  e(b)'
						su `reg' if e(sample)==1
						qui estadd scalar control_mean = r(mean)
						global mean2 : display %4.3fc `r(mean)'
						qui estadd local caste_fe = "Yes"
						qui estadd local village_fe = "Yes"
										
						eststo bmark_col3: reghdfe `reg' ref_rank_`ranktype' $PredictedIncome if pred_inc_younggen2p!=. & inc_famsize!=. & ref_rank_pred_inc_pca!=., absorb(caste A2) vce(cluster caste_A2)
						matrix beta_`reg'3 =  e(b)'
						su `reg' if e(sample)==1
						qui estadd scalar control_mean = r(mean)
						global mean3 : display %4.3fc `r(mean)'
						qui estadd local caste_fe = "Yes"
						qui estadd local village_fe = "Yes"					
						
					}
				}


					
				esttab bmark_col01 bmark_col1 bmark_col2 bmark_col3 using "${out}/tables/d_girl6_bmark_revision.tex", ///
				drop(_cons) replace se booktabs ///
				stats(control_mean N caste_fe village_fe, ///
					labels(`"Mean of dependent variable"' ///
							`"Observations"' ///
							`"Caste FE"' ///
							`"Village FE"')) ///
					coeflabels(ref_rank_pred_inc_yg2p "Rank in caste per capita wealth distribution" ///
						pred_income "Absolute income" ///
						HH_malehead_ed "Father's education" ///
						HH_femalehead_ed "Mother's education") ///
					star(^{*} 0.10 ^{**} 0.05 ^{***} 0.01) nomtitles ///
					nonotes
				
				* extract the betas to merge with bs se later	
				local reglist d_girl6
				foreach reg of local reglist{
					forvalues j = 1/3{
						svmat2 beta_`reg'`j', rnames(var_`reg'`j')
					}

					forval j = 1/3{
						preserve
								keep beta_`reg'`j'1 var_`reg'`j'
								drop if beta_`reg'`j'1==.
								tempfile `reg'_beta`j'
								save ``reg'_beta`j''
						restore
					}
				}
				
	**************************************		
	**************************************		
			* Run BOOTSTRAP *
	**************************************
	**************************************

		use "${coded}/DataForReg.dta", clear

		drop r_Time Series IsPrim IsPrimWife IsPrimHusb PrimSpouse PrimCh TempOrder SendBack ///
		Err_Income RelCodeLast RelatedTo IsParent IsChild IsSibling IsPrimaryEarner ///
		IsWife IsHusband ishusband3 iswife3 RelatedBy ParentTest1 ParentTest2 ParentTest3 ///
		ParentTest4 IsFemale MotherTest1 FatherTest1 IsDaughter IsSon CountSon1 ///
		DaughterAge1 DaughterAge2 SonAge1 SonAge2 IsGP GPTest1 GPTest2 GPTest3 ///
		GPTest4 GMTest1 GFTest1 GPNumDaught GPNumSons GPDaughtAge CountDaught2 ///
		CountSon2 GPDaughtSumAge1 GPDaughtSumAge2 SonAge3 SonAge4 GPSonSumAge1 ///
		GPSonSumAge2 FemaleNotChild MaleNotChild ChildTest1 ChildTest2 ChildTest3 ///
		ChildTest4 ParOfCh1 ChildTest1b ChildTest2b ChildTest3b ChildTest4b ParOfCh2 ///
		ChildFTest2 ChildMTest2 ParOfCh pnod pnos pad pas ChildTest1c CCountDaught1a ///
		CCountDaught1b CCountDaught1c CCountDaught CCountSon1a CCountSon1b CCountSon1c ///
		CCountSon CDaughterAge CDaughterAge2a CDaughterAge2b CDaughterAge2c CDaughterAgeSum ///
		CDaughterAge2 padsum1 padsum2 CSonAge CSonAge2a CSonAge2b CSonAge2c CSonAgeSum ///
		CSonAge2 passum1 passum2 IsGC GCTest1 GCTest2 GCTest3 GCTest4 NotGC GCMotherTest1 ///
		GCFatherTest1 GCCountDaught GCCountSon GDaughterAge GDaughterAge2 GSonAge GSonAge2 ///
		GG CheckManually Tag ChildCountsMissing NumDaughters DaughterAvAge NumSons SonAvAge ///
		qx pe_sex_temp pe_sex wb hb js ws hs df sf RelBy2 gc grandchild child_gen childgen ///
		num_sib_fam num_child_fam unsure villagedescription numberofhouses population brahmans ///
		kshatryias chetties vellalar kanakkan idaiyars othergoodcastes kammalan kanakkan ///
		kaikalar vannian kusavan satani sembadavan shanan ambattan vannan otherhindus pariahs ///
		totalhindu lubbayrs moplars arabs seik syed mogul othermahomedans totalmahomedans ///
		 budhists europeans eurasians otherchristians totalchristians grandtotal governmentservice ///
		 military learned minorprofessions personalservice traders conveyers cultivators dress ///
		 food metals construction books householdgoods combustibles labourers property ///
		 unproductive others total otherchristians notes
		 
		save "${coded}/DataForReg_bs.dta", replace

		//use "data/coded/DataForReg_bs.dta", clear
		
		forvalues i = 1/$ns{
		
			bsample, cluster(HHid)
			gen simulation =`i'
			di `i'
			
			**************
			* First stage
			**************
		qui	do "${subcode}/7_2_coding_breg_bs.do"			
		
			****************
			
			gen inc_famsize= monthlyincome/(total_yg_own+2) if LivesWithFather==1 & LivesWithMother==1 & d_youngestgen==1

			**************
			* Second stage
			**************
			
	* Table 5, col 4-6
	* II * rank based on predicted income per OWN youngest generation/ OWN child +2 (not directly estimated)
			gen pred_inc_younggen2p =.
			replace pred_inc_younggen2p = $PredictedIncome /(total_yg_own+2) if LivesWithFather==1 & LivesWithMother==1 & d_youngestgen==1
			lab var pred_inc_younggen2p "Predicted HH montlyincome divided by no. in the youngest generation+ 2(parents)"
			
			gen log_pred_inc_younggen2p = log(pred_inc_younggen2p)
			
			sort caste log_pred_inc_younggen2p
			bys caste log_pred_inc_younggen2p : gen newid = 1 if _n==1
			by caste: gen rank_pred_inc_yg2p = sum(newid) if pred_inc_younggen2p!=.
			
			bys caste: egen num_ranks = max(rank_pred_inc_yg2p)

			gen ref_rank_pred_inc_yg2p = rank_pred_inc_yg2p/num_ranks
			lab var ref_rank_pred_inc_yg2p "Rank in within caste income distribution"
			
			drop newid
			drop num_ranks	
					
				
		/* new predicted income
			gen pred_inc_yg2p_new =.
			replace pred_inc_yg2p_new = $PredictedIncome_new /(total_yg_own+2) if LivesWithFather==1 & LivesWithMother==1 & d_girl6!=. & d_youngestgen==1
			lab var pred_inc_yg2p_new "Predicted HH montlyincome new divided by no. in the youngest generation+ 2 parents"
			
			gen log_pred_inc_yg2p_new = log(pred_inc_yg2p_new)
			
			sort caste log_pred_inc_yg2p_new
			bys caste log_pred_inc_yg2p_new : gen newid = 1 if _n==1
			by caste: gen rank_pred_inc_yg2p_new = sum(newid) if pred_inc_yg2p_new!=.
			
			bys caste: egen num_ranks = max(rank_pred_inc_yg2p_new)

			gen ref_rank_pred_inc_yg2p_new = rank_pred_inc_yg2p_new/num_ranks
			lab var ref_rank_pred_inc_yg2p_new "Rank in within caste income distribution"
			
			drop newid
			drop num_ranks	*/
			
	* IV * rank based on pca of per capita income, parental education and current landholdings

			sort caste pred_income_pca
			bys caste pred_income_pca : gen newid = 1 if _n==1
			by caste: gen rank_pred_inc_pca = sum(newid) if pred_income_pca!=.
			bys caste: egen num_ranks = max(rank_pred_inc_pca)

			gen ref_rank_pred_inc_pca = rank_pred_inc_pca/num_ranks
			lab var ref_rank_pred_inc_pca "Rank in caste wealth distribution"

			drop newid
			drop num_ranks			
					
			* benchmark regression		
				local ranklist pred_inc_yg2p
				local reglist d_girl6
 
				foreach reg of local reglist{
					foreach ranktype of local ranklist{
						* income per child *
						eststo bmark_col1: reghdfe `reg' ref_rank_pred_inc_pca if pred_inc_younggen2p!=. & inc_famsize!=., absorb(caste A2) vce(cluster A2)
						matrix beta_`reg'1_`i' =  e(b)'
						mat list beta_`reg'1_`i'
						
						
						eststo bmark_col2: reghdfe `reg' ref_rank_`ranktype' if pred_inc_younggen2p!=. & inc_famsize!=. & ref_rank_pred_inc_pca!=., absorb(caste A2) vce(cluster caste_A2)
						matrix beta_`reg'2_`i' =  e(b)'
						mat list beta_`reg'2_`i'
						
						
						eststo bmark_col3: reghdfe `reg' ref_rank_`ranktype' $PredictedIncome if pred_inc_younggen2p!=. & inc_famsize!=. & ref_rank_pred_inc_pca!=., absorb(caste A2) vce(cluster caste_A2)
						matrix beta_`reg'3_`i' =  e(b)'
						mat list beta_`reg'3_`i'
						

					}
				}		
				
				use "${coded}/DataForReg_bs.dta", clear
			
			}

	* Turn matrices into variables
		forvalues i = 1/$ns{
			local reglist d_girl6
			foreach reg of local reglist{
				forvalues j = 1/3{
					svmat2 beta_`reg'`j'_`i', rnames(var_`reg'`j'_`i')		
				}		
			}
		}
		

		* rename and save matrix			
			forvalues j = 1/3{
				rename var_d_girl6`j'_1 var_d_girl6`j'
				drop var_d_girl6`j'_* // need var names only from the first bs
			}
			
			tempfile matrix_var
			save `matrix_var'
		
		
		* Compile the betas and compute the bootstrapped SE
		* child sex ratio
			use `matrix_var', clear
			local reglist d_girl6
			foreach reg of local reglist{
			
				forvalues j = 1/3{ 			//3 is the number of regressions for the reg
					preserve
						keep beta_`reg'`j'_* var_`reg'`j'
						drop if beta_`reg'`j'_11==.
						reshape long beta_`reg'`j'_, i(var_`reg'`j') j(simulation)

						bys var: egen mb_`reg'`j'=mean(beta_`reg'`j'_)
						gen diff=(beta_`reg'`j'_-mb_`reg'`j')^2
						bys var: egen sdiff=sum(diff)
						bys var: gen N =_N 
						gen se`j'=(sdiff/(N))^0.5
						bys var: egen s=seq()
						keep if s==1
						keep var se`j'
						sort var
						merge 1:1 var_`reg'`j' using ``reg'_beta`j'', nogen
						gen tstat = beta_`reg'`j'/se`j'

						save "${coded}/bootstrap/`reg'_betase`j'.dta", replace

					restore	
				}
		}
		
		forvalues j = 1/3{ 
		use "${coded}/bootstrap/d_girl6_betase`j'.dta", clear
 
		gen id = _n
		replace id= 1 if var_d_girl6`j' == "_cons"
		replace id= 2 if var_d_girl6`j' == "ref_rank_pred_inc_pca"
		replace id= 2 if var_d_girl6`j' == "ref_rank_pred_inc_yg2p"
		replace id= 3 if var_d_girl6`j' == "pred_income_cluster_vfe"
		rename (se`j' beta_d_girl6`j')(row2 row1)
		reshape long row, i(id) j(estimate)
		drop if id == 1
		set obs 10
		mkmat row , matrix(column`j')
	 }
		
		
		matrix estimates = first,column1,column2,column3
		svmat estimates
		keep var_d_girl63 estimates*

		* Organize variable for the output table
		replace var_d_girl63 = "Relative wealth" if _n == 1
		replace var_d_girl63 = "Household wealth" if _n == 3
		replace var_d_girl63 = "\vspace{0.5}" if _n == 2
		
		forvalues i = 1/4{ 
		gen est`i' = string(estimates`i', "%8.5f")
		replace est`i'= "("+est`i'+")" if _n == 2
		replace est`i'= "" if est`i' == "."
		}
	
		replace est3 = "("+est3+")" if _n == 4 
		replace est4 = "("+est4+")" if _n == 4 | _n == 6 | _n == 8 | _n == 10 
		
		drop estimates*
		
		** Create table
	listtab var_d_girl63 est1 est2 est3 est4 using "${out}/tables/d_girl6_table4.tex", type rstyle(tabular) replace /// 
		head("\begin{threeparttable}" ///
			"\begin{tabular}{lcccc} \hline" ///
			"Dependent variable & \multicolumn{4}{c}{Girl dummy} \\ & (1) & (2) & (3) & (4) \\ \cmidrule(lr){2-5}") ///
			foot("Mean of dependent variable & $mean1 & $mean2 & $mean3 & $mean4 \\" ///
			"Observations & $obs & $obs & $obs & $obs \\" ///
			"Caste FE & Yes & Yes & Yes & Yes \\" ///
			"Village FE & No & No & No & Yes \\ \hline" ///
			"\end{tabular}" ///
			"\begin{tablenotes} \footnotesize \item{\textit{Notes:}}" ///
			"\end{tablenotes} \end{threeparttable}")
			



