/*=========================================================================
Project: Wealth, marriage and sex selection
Author: Girija Borker, Jan Eeckhout, Nancy Luke, Shantidani Minz, Kaivan 
Munshi and Soumya Swaminathan. 
---------------------------------------------------------------------------
Do file: 8_robinson_newpredinc_castefe.do

Implement robinson for specification with HH level variation and village fixed effects
=========================================================================*/

cls

global PredictedIncome pred_income_cluster_vfe
global PredictedIncome_new 

use "${coded}/data_for_robinson.dta", clear

//create variables for regression

	//family size
	replace famsize = 5 if famsize> 5
	tab famsize, gen(dfamsize)
	drop dfamsize4 //base is family size >= 5
	
	
	//caste_dummies
	tab caste, gen(dummy_caste)
	drop dummy_caste1

	
	//village_dummies
	tab A2, gen(dummy_A2)
	drop dummy_A21
	
	//rename dummies to help in looping variables
	ren (dfamsize1 dfamsize2 dfamsize3) (dummy_1 dummy_2 dummy_3)
	drop famsize 
	
	ds dummy_caste*
	local ncaste: word count `r(varlist)'
	local ic = 3 // this is the last digit of dummy_* created above
	foreach v in `r(varlist)'{
		local ic = `ic'+1
		ren `v' dummy_`ic'
	} //end foreach v
	
	ds dummy_A2*
	local nA2: word count `r(varlist)'
	local ic = 59 // this is the last digit of dummy_* created above
	foreach v in `r(varlist)'{
		local ic = `ic'+1
		ren `v' dummy_`ic'
	} //end foreach v
	
	
	
	//rename dependent and independent variable
	ren  ref_rank_pred_inc_yg2p x1
	ren d_girl6 y
	drop caste A2
	ds dummy_* // fam size dummies, caste and village dummies 
	
	//linear
	local specific1 = "`r(varlist)' $PredictedIncome"

				
				foreach ispec in 1{
					
					//assign varlist
					local vlist  `specific`ispec''
					di "`vlist'"
					
					//lowess y on x , and predict residuals
					lowess y x`ispec', bw(0.1) gen(y_x`ispec')  nograph
					gen stage_1_resid_`ispec' = y - y_x`ispec'
					
					//regress vlist on x, and predict residuals
					foreach v in `vlist'{
						di "`v'"
						lowess `v' x`ispec', bw(0.1) gen(`v'_x`ispec')  nograph
						gen resid_`v'_`ispec' = `v' - `v'_x`ispec'
						drop `v'_x`ispec'
					} //end foreach v
					
					//regress stage 1 residual on stage 2 residuals
					reg stage_1_resid_`ispec' resid_*, noconstant
					//construct matrix Z
					gen Z_`ispec' = 0 
					foreach v in `vlist'{
						sum `v'
						gen temp = r(mean)
						gen temp2_`ispec' = _b[resid_`v'_`ispec'] * (`v' - temp)
						replace Z_`ispec' = Z_`ispec' + temp2_`ispec'
						drop temp*
					} //end foreach v
					
					gen y_`ispec' = y - Z_`ispec'
					
					save "${coded}/HHvariation_predincome_controlfunction_data_`ispec'", replace
					
				}
			
			
//save "data/HHvariation_predincome_controlfunction_data", replace
	
use "${coded}/HHvariation_predincome_controlfunction_data_1", clear
			
			reg stage_1_resid_1 resid_*, noconstant

			drop *dummy_1 *dummy_2 *dummy_3 // drop the family size dummies
			drop resid_dummy_1_1 resid_dummy_2_1 resid_dummy_3_1 resid_pred_income_cluster_vfe_1 // drop resid of family size dummies and the abs income
			ds dummy_*
			
			local specific0 = "`r(varlist)'" // caste and village dummies
			local vlist  `specific0'
			di "`vlist'"
			
			reg stage_1_resid_1 resid_*, noconstant
			gen Z_0 = 0 
			foreach v in `vlist'{
						sum `v'
						gen temp = r(mean)
						gen temp2_0 = _b[resid_`v'_1] * (`v' - temp)
						replace Z_0 = Z_0 + temp2_0
						drop temp*
					} //end foreach v
					
					gen y_0 = y - Z_0

					keep x1 y_1 y_0
									
//best specification
			set scheme s2color
			tw 		(lpolyci y_1 x1, ///
					bw(0.06) xtitle("Rank in caste wealth distribution") ytitle("Pr(Girl)") lpattern("-") lcolor(red) lwidth(medthick) fcolor("red%30") alcolor("red%30") alstyle("l")) ///
					(lpoly y_0 x1, bw(0.06) lcolor(blue)), ///
					legend(order(3 "Benchmark specification" 2 "With control function") col(1) position(6)) graphregion(color(white)) bgcolor(white) 					yscale(range(0.44(0.02)0.58))

gr export "${out}/figures/predincome_controlfunction_lpoly.pdf", replace

