/*=========================================================================
Project: Wealth, marriage and sex selection
Author: Girija Borker
---------------------------------------------------------------------------
Do file: 17_2_marriage_analysis_parents.do

Creates parents databases.
=========================================================================*/

* Section A
***********************
* parental generation *
***********************
		* i.e. MPR

		* For A44 merge
		use "${raw}/ROSTER/HOUSEROSTER_P2_edit.dta", clear

		foreach x of varlist _all {
			rename `x' A44_`x'
		}
		save "${raw}/ROSTER/HOUSEROSTER_P2forA44_edit.dta", replace

		use "${raw}/ROSTER/HOUSEROSTER_P2_edit.dta", clear

		foreach x of varlist _all {
			rename `x' A31_`x'
		}
		save "${raw}/ROSTER/HOUSEROSTER_P2forA31_edit.dta", replace

		use "${raw}/MPR/MPR_SEC_A_edit.dta", clear

		// 94% married only once (of those who answered A28) for those we use A44 to get information on wife 
		// for the people married twice we use A31 to get information on wife

		egen A44_ind_id = concat(P_CODE V_CODE NIRT_NO A44), p("-")

		merge m:1 A44_ind_id using "${raw}/ROSTER/HOUSEROSTER_P2forA44_edit.dta"
		keep if _merge==1|_merge==3
		drop _merge

		egen A31_ind_id = concat(P_CODE V_CODE NIRT_NO A31), p("-")
		
		merge m:1 A31_ind_id using "${raw}/ROSTER/HOUSEROSTER_P2forA31_edit.dta"
		keep if _merge==1|_merge==3
		drop _merge

		* add Mpr's characteristics
		merge 1:1 ind_id using "${raw}/ROSTER/HOUSEROSTER_P2_edit.dta"
		keep if _merge==1|_merge==3

		* current residence
		replace A45 = A44_Z12 if A44_ind_id!=""
		replace A45_1 = A44_Z12_1 if A44_ind_id!=""
		replace A45_2 = A44_Z12_2 if A44_ind_id!=""
		replace A45_3 = A44_Z12_3 if A44_ind_id!=""

		* village originally from
		//A52
		gen mpr_wifesamevill=0 if A28!=.
		replace mpr_wifesamevill = 1 if A52==1 & (MPR_A1>=Z5_1 | A2==1) & mpr_wifesamevill==0
		replace mpr_wifesamevill = 1 if Z12_1==A52_1 & Z12_2==A52_2 & Z12_3==A52_3 & mpr_wifesamevill==0
		su mpr_wifesamevill
		// i.e. if MPR's family has lived in this village (A1) since before the MPR was born


		// A52==1 just says that wife from this village 
		// but we don't know  which village the mpr is originally from
		//replace mpr_wifesamevill = 1

		* age at marriage


		* current occupation
		//Z9

		* highest level of education
		//Z8

		* same caste or not
		// A46

		* caste
		replace A47 = A44_Z14 if A44_ind_id!=""
		
		destring A31_Z14, replace
		replace A34 = A31_Z14 if A31_ind_id!=""
		gen caste_mpr = Z14 if A44_ind_id!=""
		
		destring caste_mpr, replace
		destring A47, replace
		replace A46 = 0 if A47!=caste_mpr & A46==.
		replace A46 = 1 if A47==caste_mpr & A46==.

		replace A33 = 0 if A34!=caste_mpr & A33==.
		replace A33 = 1 if A34==caste_mpr & A33==.

			** Descriptives
			matrix p = J(4,1,.)
			
			* same caste
			tab A46 if A50!=., nolab

			replace A46 = 0 if A46 ==99
			sum A46 if A50!=.
			matrix p[1,1] = `r(mean)'
			
			* Related
			tab A50, nolab
			replace A50 = 0 if A50 ==99
			sum A50 
			matrix p[2,1] = `r(mean)'
			
			* choice of wife
			tab A49, nolab
			replace A49 = 1 if A49 ==1 | A49 ==2 
			replace A49 = 0 if A49 ==3 | A49 ==4 | A49 ==5 | A49 ==6 | A49 ==99
			sum A49 if A50!=.
			matrix p[3,1] = `r(mean)'
			
			* Moved from another village
			gen m_village = 0
			replace m_village =1 if mpr_wifesamevill == 0
			replace m_village =. if mpr_wifesamevill == .
			sum m_village
			matrix p[4,1] = `r(mean)'
	
		* Total observations data 
			count if A50!=.
			global total : display %12.0fc `r(N)'
			
			