/*=========================================================================
Project: Wealth, marriage and sex selection
Author: Girija Borker, Jan Eeckhout, Nancy Luke, Shantidani Minz, Kaivan 
Munshi and Soumya Swaminathan. 
---------------------------------------------------------------------------
Do file: 5_2_parents_children.do
=========================================================================*/

*****************************************
* Attaching each child to their parents *
*****************************************

	* creating a numeric Individual id
	sort HHid
	egen HH_no = group(HHid)
	bys HHid: gen Ind_no = _n
	egen Indid = concat (HH_no Ind_no)
	destring Indid, replace
	
	* sex of pe
	bys HHid: gen pe_sex_tmp = C2_3 if C2_6=="A"
	//bys HHid: egen pe_sex = mean(pe_sex_tmp)

**********
* MOTHER *
**********

	* Relationship code of mother for child

	* Related by - codes
		//gen RelBy2 = reverse(subinstr(reverse(C2_6),RelCodeLast,"",1)) if length(C2_6)>1 // All but the last letter in relationship code

		gen W = "W"
		egen RelBy2_W = concat(RelBy2 W)

		gen M = "M"
		egen RelBy2_M = concat(RelBy2 M)
		
		egen C2_6_M = concat(C2_6 M)

	* primary earner and siblings are the child
	gen mother_code = "M" if LivesWithMother==1 & C2_6=="A"
	//replace mother_code = RelBy2 if LivesWithMother==1 & regexm(RelBy2,"[M]$") & regexm(C2_6,"[1-9GJKOPQ]$") //e.g M6

	* primary earner male, so mother is his wife
	gen d_pe = 1 if C2_6=="A"
	bys HHid: egen pe = max(d_pe) // dummy for whether there is a PRIMARY EARNER IN THE HOUSE (remember we are in a restricted sample if completed HH and families)

	replace mother_code = "W" if LivesWithMother==1 & regexm(C2_6,"[1-9GJKOPQ]$") & length(C2_6)==1 & pe_sex==1
	replace mother_code = "W" if LivesWithMother==1 & regexm(C2_6,"[1-9GJKOPQ]$") & length(C2_6)==1 & pe==0 // no A in the HH

	* primary earner female, so she is the mother
	replace mother_code = "A" if LivesWithMother==1 & regexm(C2_6,"[1-9GJKOPQ]$") & length(C2_6)==1 & pe_sex==2 

	*** pe's parents children/ tehir sibling's children 
	replace mother_code = RelBy2_M if LivesWithMother==1 & regexm(C2_6,"[BCDESTUV]$")
	replace mother_code = C2_6_M if LivesWithMother==1 & regexm(C2_6,"[MFWYH]$")

	* mother/father's siblings children e.g MS6
	replace mother_code = RelBy2 if LivesWithMother==1 & regexm(C2_6,"[1-9GJKOPQ]$") & regexm(RelBy2,"[STUVM]$") //e.g M6
	replace mother_code = RelBy2_W if LivesWithMother==1 & regexm(C2_6,"[1-9GJKOPQ]$") & regexm(RelBy2,"[BCDEH]$") // e.g WXH2

	* ends with child codes + includes starting with W (present wife, miscoding issue) or Y (Second wife)
	replace mother_code = RelBy2 if LivesWithMother==1 & regexm(RelBy2,"[6-9OPQSTUVWY]$") & regexm(C2_6,"[1-9GJKOPQ]$") & length(C2_6)>=2
		
	* children coded with respect to father e.g. 26, B6 etc
	replace mother_code = RelBy2_W if LivesWithMother==1 & regexm(RelBy2,"[1-5GJKBCDE]$") & regexm(C2_6,"[1-9GJKOPQ]$")& length(C2_6)>=2

	* children coded as father's wife's kids vs mother's e.g. FW1 FW6 etc.
	replace mother_code = RelBy2 if LivesWithMother==1 & regexm(C2_6,"[1-9GJKOPQ]$")& regexm(RelBy2,"[W]$")& length(C2_6)>=2

	* codes starting with Z
		* ending with child codes
		replace mother_code = "W" if LivesWithMother==1 & regexm(C2_6,"^[Z]") & regexm(C2_6,"[1-9GJKOPQ]$") & pe_sex==1
		replace mother_code = "A" if LivesWithMother==1 & regexm(C2_6,"^[Z]") & regexm(C2_6,"[1-9GJKOPQ]$") & pe_sex==2
		
	local varlist R
	foreach i of local varlist{
	* codes starting with `i'
	* sex of `i'
	cap drop `i'_sex_tmp `i'_sex
	bys HHid: gen `i'_sex_tmp = C2_3 if C2_6=="`i'"
	bys HHid: egen `i'_sex = mean(`i'_sex_tmp)

		* ending with child codes
		replace mother_code = RelBy2 if LivesWithMother==1 & regexm(C2_6,"^[`i']") & regexm(C2_6,"[1-9GJKOPQ]$") & `i'_sex==2
		replace mother_code = RelBy2_W if LivesWithMother==1 & regexm(C2_6,"^[`i']") & regexm(C2_6,"[1-9GJKOPQ]$") & `i'_sex==1
			
		* ending with sibling codes
		replace mother_code = RelBy2_M if LivesWithMother==1 & regexm(C2_6,"^[`i']") & regexm(C2_6,"[BCDESTUVM]$")
		
	}
	
	*** WXH6
	replace mother_code="W" if regexm(C2_6, "^[W][X][H]") & regexm(C2_6,"[1-9GJKOPQ]$") & length(C2_6)==4


  	****************************************************
	* Attaching mother's characteristics to each child *
	****************************************************
	
		preserve
		* For HH with multiple Y's
			* HHid = 1C1388BD-523F-4975-9C35-D775A91A955C
			replace C2_6 = "OY" if IndividualId=="3C291994-4195-4FA2-8BE7-131F9AFF1345" // older wife is not the mother so we temporarily change her r/p code

			* HHid = 6A06ED73-2BB0-414A-9221-D75A66AE9907
			replace C2_6 = "OY" if IndividualId=="781EE390-9922-493E-BC8F-597D48F61826"
			
			* HHid = D51BB82A-AA44-46CD-AF99-205F7B3E41AE
			replace C2_6 = "OY" if IndividualId=="E831A1D1-310B-4D25-8FF3-CF9D63E1EF96"
			
			* HHid = D51BB82A-AA44-46CD-AF99-205F7B3E41AE
			replace C2_6 = "OY" if IndividualId=="E831A1D1-310B-4D25-8FF3-CF9D63E1EF96"
			
			* HHid F8259E01-842E-4DDF-82FE-D4A6DAC02B24
			replace C2_6 = "OY" if IndividualId=="3618B33F-4D42-423C-940E-97F4B9750F01"


		bys C2_6: gen C2_6_num=1 if _n==1 // numeric equivalent of relationship code
		replace C2_6_num=sum(C2_6_num)
		order HHid C2_6 C2_6_num
		sort HHid

		* creating a data set which will have mother's covariates which we will merge to each child
		
		bys HHid C2_6_num: egen id_ct=count(C2_6_num)

		tab C2_6 if id_ct>1 // ************** realtionship codes which are repeated in a household (MUST CHECK) ****************

		drop if id_ct>1
		keep HHid IndividualId C2_6 Indid C2_4 C2_5 EdYears C2_8 C8 C9
		for var *: rename X mother_X
		rename mother_C2_6 mother_code
		rename mother_HHid HHid
		tempfile using1
		save `using1'
		restore

		merge m:1 HHid mother_code using `using1'
		keep if _merge==3 | _merge==1 // only keep master along with matched
		drop _merge

	
**********
* FATHER *
**********

	* Relationship code of father for child

	* Related by - codes
		
		gen middle_xw = 0
		replace middle_xw = 1 if regexm(C2_6, "XW") 
		
		gen last_char = substr(C2_6,-1,1)
		gen first_char = substr(C2_6,1,1)
		gen first2_char = substr(C2_6,1,2)
		gen last2_char = substr(C2_6,-2,2)
		
		gen mod_C2_6 = C2_6
		replace mod_C2_6 = last_char if middle_xw==1 & regexm(C2_6, "^[X][W]") & regexm(C2_6,"[1-9GJKOPQ]$") & length(C2_6)==3
		replace mod_C2_6 = last2_char if middle_xw==1 & regexm(C2_6, "^[X][W]") & regexm(C2_6,"[1-9GJKOPQ]$") & length(C2_6)==4
		
		* GO Through codes : tab C2_6 if middle_xw==1
		egen tmp_1 = concat(first_char last_char) if middle_xw==1 & regexm(C2_6, "^[1BFH]") & regexm(C2_6,"[1-9GJKOPQM]$") & length(C2_6)==4
		egen tmp_2 = concat(first_char last_char) if middle_xw==1 & regexm(C2_6, "^[F]") & regexm(C2_6,"[1-9GJKOPQMW]$") & length(C2_6)==5
		egen tmp_3 = concat(first2_char last_char) if middle_xw==1 & regexm(C2_6, "^[W]") & regexm(C2_6,"[1-9GJKOPQMW]$") & length(C2_6)==5
		
		replace mod_C2_6 = tmp_1 if middle_xw==1 & regexm(C2_6, "^[1BFH]") & regexm(C2_6,"[1-9GJKOPQM]$") & length(C2_6)==4
		replace mod_C2_6 = tmp_2 if middle_xw==1 & regexm(C2_6, "^[F]") & regexm(C2_6,"[1-9GJKOPQMW]$") & length(C2_6)==5
		replace mod_C2_6 = tmp_3 if middle_xw==1 & regexm(C2_6, "^[W]") & regexm(C2_6,"[1-9GJKOPQMW]$") & length(C2_6)==5
		
		gen mod_RelBy2 = reverse(subinstr(reverse(mod_C2_6),RelCodeLast,"",1)) if length(mod_C2_6)>1 // All but the last letter in relationship code
		
		gen H = "H"
		egen mod_RelBy2_H = concat(mod_RelBy2 H)

		gen F = "F"
		egen mod_RelBy2_F = concat(mod_RelBy2 F)
		
		egen mod_C2_6_F = concat(mod_C2_6 F)
		

	* primary earner and siblings are the child
	gen father_code = "F" if LivesWithFather==1 & mod_C2_6=="A"

	* primary earner male, so mother is his wife
	replace father_code = "H" if LivesWithFather==1 & regexm(mod_C2_6,"[1-9GJKOPQ]$") & length(mod_C2_6)==1 & pe_sex==2

	* primary earner female, so she is the mother
	replace father_code = "A" if LivesWithFather==1 & regexm(mod_C2_6,"[1-9GJKOPQ]$") & length(mod_C2_6)==1 & pe_sex==1

	*** pe's parents children/ tehir sibling's children 
	replace father_code = mod_RelBy2_F if LivesWithFather==1 & regexm(mod_C2_6,"[BCDESTUV]$")
	replace father_code = mod_C2_6_F if LivesWithFather==1 & regexm(mod_C2_6,"[MFWYH]$")

	* mother/father's siblings children e.g MS6
	replace father_code = mod_RelBy2_H if LivesWithFather==1 & regexm(mod_C2_6,"[1-9GJKOPQ]$") & regexm(mod_RelBy2,"[STUVM]$") //e.g S6
	replace father_code = mod_RelBy2 if LivesWithFather==1 & regexm(mod_C2_6,"[1-9GJKOPQ]$") & regexm(mod_RelBy2,"[BCDEH]$") // e.g WXH2

	* children coded with respect to mother e.g. 66, V6 etc
	replace father_code = mod_RelBy2_H if LivesWithFather==1 & regexm(mod_RelBy2,"[6-9OPQSTUVW]$") & regexm(mod_C2_6,"[1-9GJKOPQ]$") & length(mod_C2_6)>=2
		
	* children coded with respect to father e.g. 26, B6 etc
	replace father_code = mod_RelBy2 if LivesWithFather==1 & regexm(mod_RelBy2,"[1-5GJKBCDE]$") & regexm(mod_C2_6,"[1-9GJKOPQ]$")& length(mod_C2_6)>=2

	* children coded as father's wife's kids vs mother's e.g. FW1 FW6 etc.
	replace father_code = mod_RelBy2 if LivesWithFather==1 & regexm(mod_C2_6,"[1-9GJKOPQ]$")& regexm(mod_RelBy2,"[H]$")& length(mod_C2_6)>=2

	* codes starting with Z
		* ending with child codes
		replace father_code = "H" if LivesWithFather==1 & regexm(mod_C2_6,"^[Z]") & regexm(mod_C2_6,"[1-9GJKOPQ]$") & pe_sex==2 // eg Z1
		replace father_code = "A" if LivesWithFather==1 & regexm(mod_C2_6,"^[Z]") & regexm(mod_C2_6,"[1-9GJKOPQ]$") & pe_sex==1
	
	* some codes starting X which are not getting coded properly eg XW1, XW2 etc need to have father's code as A
	//replace father_code = "A" if LivesWithFather==1 & regexm(C2_6,"^[X][WY]") & regexm(C2_6,"[1-9GJKOPQ]$") & pe_sex==1
	
	*** FXY6
	replace father_code="F" if LivesWithFather==1 & regexm(mod_C2_6,"^[F][X][WY]") & regexm(mod_C2_6,"[1-9GJKOPQ]$") & length(C2_6)==4
	
	*** FW6 or FY6
	gen char1 = substr(mod_C2_6,1,1)
	replace father_code=char1 if LivesWithFather==1 & regexm(mod_C2_6,"^[FBCDEH][WY]") & regexm(mod_C2_6,"[1-9GJKOPQ]$") & length(C2_6)==3
	
	*** XY1
	replace father_code="A" if LivesWithFather==1 & regexm(mod_C2_6,"^[X][WY]") & regexm(mod_C2_6,"[1-9GJKOPQ]$")& length(C2_6)==3
	
	*** Y6
	replace father_code="A" if LivesWithFather==1 & regexm(mod_C2_6,"^[YW]") & regexm(mod_C2_6,"[1-9GJKOPQ]$")& length(C2_6)==2
	
	*** FXW11
	gen char4 = substr(mod_C2_6,1,4)
	replace father_code=char4 if LivesWithFather==1 & regexm(mod_C2_6,"^[F][X][WY]") & regexm(mod_C2_6,"[1-9GJKOPQ]$") & length(C2_6)==5
	
	*** WFXW1
	replace father_code= "WF" if LivesWithFather==1 & C2_6=="WFXW1"
	
	local varlist R
	foreach i of local varlist{
	* codes starting with `i'
	* sex of `i'
	cap drop `i'_sex_tmp `i'_sex
	bys HHid: gen `i'_sex_tmp = C2_3 if C2_6=="`i'"
	bys HHid: egen `i'_sex = mean(`i'_sex_tmp)

		* ending with child codes
		replace father_code = mod_RelBy2 if LivesWithFather==1 & regexm(C2_6,"^[`i']") & regexm(C2_6,"[1-9GJKOPQ]$") & `i'_sex==1
		replace father_code = mod_RelBy2_H if LivesWithFather==1 & regexm(C2_6,"^[`i']") & regexm(C2_6,"[1-9GJKOPQ]$") & `i'_sex==2
			
		* ending with sibling codes
		replace father_code = mod_RelBy2_F if LivesWithFather==1 & regexm(C2_6,"^[`i']") & regexm(C2_6,"[BCDESTUVM]$")
		
	}


	****************************************************
	* Attaching father's characteristics to each child *
	****************************************************

	* creating a data set which will have father's covariates which we will merge to each child
	preserve
	bys C2_6: gen C2_6_num=1 if _n==1 // numeric equivalent of relationship code
	replace C2_6_num=sum(C2_6_num)
	bys HHid C2_6_num: egen id_ct=count(C2_6_num)

	tab C2_6 if id_ct>1 // ************** realtionship codes which are repeated in a household (MUST CHECK) ****************

	drop if id_ct>1
	keep HHid IndividualId C2_6 Indid C2_4 C2_5 EdYears C2_8 C8 C9 //familytree_income
	for var *: rename X father_X
	rename father_C2_6 father_code
	rename father_HHid HHid
	tempfile using2
	save `using2', replace
	restore

	merge m:1 HHid father_code using `using2'
	keep if _merge==3 | _merge==1 // only keep master along with matched
	drop _merge
	
	drop H F M W

* Birth order
gen rev_age = -C2_4

sort HHid mother_code rev_age

bys HHid mother_code: gen bo = 1 if _n==1 & mother_code!=""
bys HHid mother_code: replace bo = sum(bo) if mother_code!=""
bys HHid mother_code: gen birth_order = sum(bo) if mother_code!=""
drop bo

gen age_2 = C2_4 if birth_order!=.

bys HHid mother_code: gen spacing = age_2 - age_2[_n-1] if birth_order>1

replace spacing = -spacing

/**********
* CHECKS *
**********

* children for which the parents acharcteristics were'nr matched ==> wrong relationship code for parent
tab mother_code if LivesWithMother==1 & mother_C2_4==. & mother_EdYears==.

tab father_code if LivesWithFather==1 & father_C2_4==. & father_EdYears==.


	preserve
	keep if spacing>=20 & spacing!=.
	keep HHid
	tempfile using3
	save `using3'
	restore

	merge m:1 HHid using `using3'

	preserve
	keep if _merge==3
	save "Census Data/possible_errors", replace
	restore
	
drop _m

sort HHid father_code rev_age

bys HHid father_code: gen bo_f = 1 if _n==1 & father_code!="" & mother_code==""
bys HHid father_code: replace bo_f = sum(bo_f) if father_code!="" & mother_code==""
bys HHid father_code: gen birth_order_f = sum(bo_f) if father_code!="" & mother_code==""
drop bo_f

gen age_2_f = C2_4 if birth_order_f!=.

bys HHid father_code: gen spacing_f = age_2_f - age_2_f[_n-1] if birth_order_f>1

replace spacing_f = -spacing_f

replace spacing = spacing_f if LivesWithMother==0 & LivesWithFather==1
