/*=========================================================================
Project: Wealth, marriage and sex selection
Author: Girija Borker, Jan Eeckhout, Nancy Luke, Shantidani Minz, Kaivan 
Munshi and Soumya Swaminathan. 
---------------------------------------------------------------------------
Do file: 6_1_add_sichs_Variables.do
=========================================================================*/

*** 2017-11-23_AddSICHS_Variables.do ***

*** MPR (grandparents) ***

LoadMergeSICHSVariables mpr_a7 mpr_a8 ///
	using "${raw}/MPR/MPR_SEC_A_PG1.dta" ///
	, questionnaire("MPR") person("father") nogen

replace educ =mpr_a7 if missing(educ)
replace occup=mpr_a8 if missing(occup)

LoadMergeSICHSVariables mpr_a20 mpr_a21 ///
	using "${raw}/MPR/MPR_SEC_A_PG1.dta" ///
	, questionnaire("MPR") person("mother") nogen

replace educ =mpr_a20 if missing(educ)
replace occup=mpr_a21 if missing(occup)


*** SPO (grandparents) ***

LoadMergeSICHSVariables spo_b22 spo_b23 ///
	using "${raw}/SPO/SPO_SEC_B.dta" ///
	, questionnaire("SPO") person("father") nogen

replace educ =spo_b22  if missing(educ)
replace occup=spo_b23 if missing(occup)

LoadMergeSICHSVariables spo_b35 spo_b36 ///
	using "${raw}/SPO/SPO_SEC_B.dta" ///
	, questionnaire("SPO") person("mother") nogen

replace educ =spo_b35 if missing(educ)
replace occup=spo_b36 if missing(occup)


*** FPR (grandparents) ***

LoadMergeSICHSVariables fpr_c9 fpr_c10 ///
	using "${raw}/FPR/FPR_SEC_C_P1.dta" ///
	, questionnaire("FPR") person("father") nogen

replace educ =fpr_c9  if missing(educ)
replace occup=fpr_c10 if missing(occup)


LoadMergeSICHSVariables fpr_c22 fpr_c23 ///
	using "${raw}/FPR/FPR_SEC_C_P1.dta" ///
	, questionnaire("FPR") person("mother") nogen

replace educ =fpr_c22 if missing(educ)
replace occup=fpr_c23 if missing(occup)

*** AGE AT MARRIAGE ***

gen age_at_marriage = .
gen year_marriage   = .

*** MPR (ownchildren) *** 

LoadMergeSICHSVariables  mpr_e8 mpr_e7 mpr_e2_2 mpr_e4 mpr_e5 mpr_e3 ///
 						mpr_e31_0 mpr_e31_1  mpr_e31_2  mpr_e31_3  mpr_e31_4  mpr_e31_5  mpr_e31_6  mpr_e31_7  mpr_e31_8  mpr_e31_9   /// for dowry received
 						mpr_e31_10 mpr_e31_11 mpr_e31_12 mpr_e31_13 mpr_e31_14 mpr_e31_15 mpr_e31_16 mpr_e31_17 mpr_e32  /// 	
	using "${raw}/MPR/MPR_SEC_E_P2.dta" ///
	, questionnaire("MPR") person("son") nogen mastermergevar(ownchild_rsn) usingmergevar(mpr_e3)

LoadMergeSICHSVariables  mpr_e8 mpr_e7 mpr_e2_2 mpr_e4 mpr_e5 mpr_e3 ///
 						mpr_e30_0 mpr_e30_1  mpr_e30_2  mpr_e30_3  mpr_e30_4  mpr_e30_5  mpr_e30_6  mpr_e30_7  mpr_e30_8  mpr_e30_9   /// for dowry given
 						mpr_e30_10 mpr_e30_11 mpr_e30_12 mpr_e30_13 mpr_e30_14 mpr_e30_15 mpr_e30_16 mpr_e30_17 mpr_e32  /// 
	using "${raw}/MPR/MPR_SEC_E_P2.dta" ///
	, questionnaire("MPR") person("daughter") nogen mastermergevar(ownchild_rsn) usingmergevar(mpr_e3)

replace educ =mpr_e8  if missing(educ)
replace occup=mpr_e7 if missing(occup)

replace age_at_marriage=mpr_e5 if missing(age_at_marriage)
replace year_marriage=mpr_e2_2 if missing(year_marriage)


*** MPR (inlaws) *** 

LoadMergeSICHSVariables mpr_e14 mpr_e13 mpr_e2_2 mpr_e12 mpr_e10 ///
	using "${raw}/MPR/MPR_SEC_E_P2.dta" ///
	, questionnaire("MPR") person("daughter-inlaw") nogen mastermergevar(ownchild_rsn) usingmergevar(mpr_e3)

LoadMergeSICHSVariables mpr_e14 mpr_e13 mpr_e2_2 mpr_e12 mpr_e10 ///
	using "${raw}/MPR/MPR_SEC_E_P2.dta" ///
	, questionnaire("MPR") person("son-inlaw") nogen mastermergevar(ownchild_rsn) usingmergevar(mpr_e3)

replace educ =mpr_e14  if missing(educ)
replace occup=mpr_e13 if missing(occup)

replace age_at_marriage=mpr_e12 if missing(age_at_marriage)
replace year_marriage=mpr_e2_2 	if missing(year_marriage)



*** FPR (ownchildren) *** 

LoadMergeSICHSVariables  fpr_e8 fpr_e7 fpr_e2_2 fpr_e4 fpr_e5 fpr_e3 ///
 						fpr_e31_0  fpr_e31_1  fpr_e31_2  fpr_e31_3  fpr_e31_4  fpr_e31_5  fpr_e31_6  fpr_e31_7  fpr_e31_8  fpr_e31_9 /// for dowry received
 						fpr_e31_10 fpr_e31_11 fpr_e31_12 fpr_e31_13 fpr_e31_14 fpr_e31_15 fpr_e31_16 fpr_e31_17 fpr_e32  /// 	
	using "${raw}/FPR/FPR_SEC_E_P2.dta" ///
	, questionnaire("FPR") person("son") nogen mastermergevar(ownchild_rsn) usingmergevar(fpr_e3)

LoadMergeSICHSVariables  fpr_e8 fpr_e7 fpr_e2_2 fpr_e4 fpr_e5 fpr_e3 ///
 						fpr_e30_0  fpr_e30_1  fpr_e30_2  fpr_e30_3  fpr_e30_4  fpr_e30_5  fpr_e30_6  fpr_e30_7  fpr_e30_8  fpr_e30_9 /// for dowry given
 						fpr_e30_10 fpr_e30_11 fpr_e30_12 fpr_e30_13 fpr_e30_14 fpr_e30_15 fpr_e30_16 fpr_e30_17 fpr_e32  /// 
	using "${raw}/FPR/FPR_SEC_E_P2.dta" ///
	, questionnaire("FPR") person("daughter") nogen mastermergevar(ownchild_rsn) usingmergevar(fpr_e3)

replace educ =mpr_e8  if missing(educ)
replace occup=mpr_e7 if missing(occup)

replace age_at_marriage=fpr_e5 if missing(age_at_marriage)
replace year_marriage=fpr_e2_2 if missing(year_marriage)



*** FPR (inlaws) *** 

LoadMergeSICHSVariables fpr_e14 fpr_e13 fpr_e2_2 fpr_e12 fpr_e10 ///
	using "${raw}/FPR/FPR_SEC_E_P2.dta" ///
	, questionnaire("FPR") person("daughter-inlaw") nogen mastermergevar(ownchild_rsn) usingmergevar(fpr_e3)

LoadMergeSICHSVariables fpr_e14 fpr_e13 fpr_e2_2 fpr_e12 fpr_e10 ///
	using "${raw}/FPR/FPR_SEC_E_P2.dta" ///
	, questionnaire("FPR") person("son-inlaw") nogen mastermergevar(ownchild_rsn) usingmergevar(fpr_e3)

replace educ =fpr_e14  if missing(educ)
replace occup=fpr_e13 if missing(occup)

replace age_at_marriage=fpr_e12 if missing(age_at_marriage)
replace year_marriage=fpr_e2_2 	if missing(year_marriage)



replace age_at_marriage = .	 if age_at_marriage>70 // codes for unknown / invalid

*** interview year ***

/*
	LoadMergeSICHSVariables m:1 p_code v_code nirt_no rsn using "MPR\MPR_SEC_A_PG1.dta", 	keepusing(mpr_interview_year)
	LoadMergeSICHSVariables m:1 p_code v_code nirt_no rsn using "SPO\SPO_SEC_B.dta", 		keepusing(spo_interview_year)
	LoadMergeSICHSVariables m:1 p_code v_code nirt_no rsn using "FPR\FPR_SEC_E_P1.dta", 	keepusing(fpr_interview_year)
*/
// Most took place in 2015/2016 anyway
replace age = age_at_marriage + (2016-year_marriage) 	if missing(age)


***   Add variables AGE/EDUCATION (Roster)   ***


LoadMergeSICHSVariables z5_1 z8 z9 ///
	using "${raw}/ROSTER/HOUSEROSTER_P2.dta" ///
	, questionnaire("MPR") person("mpr") nogen 

LoadMergeSICHSVariables z5_1 z8 z9 ///
	using "${raw}/ROSTER/HOUSEROSTER_P2.dta" ///
	, questionnaire("SPO") person("spo") nogen 

LoadMergeSICHSVariables z5_1 z8 z9 ///
	using "${raw}/ROSTER/HOUSEROSTER_P2.dta" ///
	, questionnaire("FPR") person("fpr") nogen 


replace age = z5_1 if missing(age)

replace educ =z8  if missing(educ)
replace occup=z9  if missing(occup)


// NOTE: RSN is used always for merging 
// NOTE: row_id is also always used for merging

gen row_id_copy = row_id
replace row_id = .			if (person=="son" | person=="daughter") & ownchild_rsn<66

replace rsn = ownchild_rsn 	if (person=="son" | person=="daughter") & ownchild_rsn<66
 
*** own children in house ***
LoadMergeSICHSVariables z5_1 z8 z9 ///
	using "${raw}/ROSTER/HOUSEROSTER_P2.dta" ///
	, questionnaire("MPR") person("son") nogen 

LoadMergeSICHSVariables z5_1 z8 z9 ///
	using "${raw}/ROSTER/HOUSEROSTER_P2.dta" ///
	, questionnaire("MPR") person("daughter") nogen 


LoadMergeSICHSVariables z5_1 z8 z9 ///
	using "${raw}/ROSTER/HOUSEROSTER_P2.dta" ///
	, questionnaire("FPR") person("son") nogen

LoadMergeSICHSVariables z5_1 z8 z9 ///
	using "${raw}/ROSTER/HOUSEROSTER_P2.dta" ///
	, questionnaire("FPR") person("daughter") nogen 


*** inlaws in house ***
gen 	inlaw_rsn = mpr_e10
replace inlaw_rsn = fpr_e10 	if missing(inlaw_rsn)

replace row_id = .			if (person=="son-inlaw" | person=="daughter-inlaw") & inlaw_rsn<66


replace rsn = inlaw_rsn 	if (person=="son-inlaw" | person=="daughter-inlaw") & inlaw_rsn<66
 

LoadMergeSICHSVariables z5_1 z8 z9 ///
	using "${raw}/ROSTER/HOUSEROSTER_P2.dta" ///
	, questionnaire("MPR") person("son-inlaw") nogen 

LoadMergeSICHSVariables z5_1 z8 z9 ///
	using "${raw}/ROSTER/HOUSEROSTER_P2.dta" ///
	, questionnaire("MPR") person("daughter-inlaw") nogen 


LoadMergeSICHSVariables z5_1 z8 z9 ///
	using "${raw}/ROSTER/HOUSEROSTER_P2.dta" ///
	, questionnaire("FPR") person("son-inlaw") nogen 

LoadMergeSICHSVariables z5_1 z8 z9 ///
	using "${raw}/ROSTER/HOUSEROSTER_P2.dta" ///
	, questionnaire("FPR") person("daughter-inlaw") nogen 


replace age = z5_1 if missing(age)

replace educ =z8  if missing(educ)
replace occup=z9  if missing(occup)


replace row_id = row_id_copy
drop  row_id_copy
