/*=========================================================================
Project: Wealth, marriage and sex selection
Author: Girija Borker, Jan Eeckhout, Nancy Luke, Shantidani Minz, Kaivan 
Munshi and Soumya Swaminathan. 
---------------------------------------------------------------------------
Do file: 6_3_calculate_dowry.do
=========================================================================*/

*** aggreagate items from questionnaires MPR/FPR ***

	egen E4 = rowtotal(mpr_e4 fpr_e4)

forval i=0/17{	
	egen E30_`i' = rowtotal(mpr_e30_`i' fpr_e30_`i')
	egen E31_`i' = rowtotal(mpr_e31_`i' fpr_e31_`i')
}

	egen E32 = rowtotal(mpr_e32 fpr_e32)

* STATA code for dowry calculation
* dowry = E32, only for daughters
gen dowry = E32/1000 if E4==1
lab var dowry "Dowry (in thousands)"

* see how diff components contribute/are correlated with the dowry
forval i=0/17{	
	replace E30_`i' = 0 if E30_`i'==.
	replace E31_`i' = 0 if E31_`i'==.
}
// now all the E30 and E31 variables are dummies

gen dowry_calc = 0 	if generation==3

* dummy variables, assume if yes, then one unit of the good is given

// Prices in "GoodPrices_dowrycalcs.xlsx"

* for daughters, dowry = what her side gave to the couple
replace dowry_calc 	= E30_1*   2240.82 	/// Bed
 					+ E30_2*   1329.16 	/// Bureau
 					+ E30_3*  10000 	/// Kitchen utensils - bronze 
 					+ E30_4*  20000 	/// Kitchen utensils - stainless steel 
 					+ E30_5*    736 	/// Grinder
 					+ E30_6*   1099 	/// Mixer
 					+ E30_7*   9890 	/// Fridge
 					+ E30_8*   5490 	/// TV
 					+ E30_9*   4150 	/// Microwave
 					+ E30_10*  3869 	/// Washing machine 
 					+ E30_11* 10000 	/// Silk saris 
 										/// Groceries - excluded because no way of attaching a valuation
 					+ E30_13* 11700 	/// Motorbike
 					+ E30_14*  3201.48 	/// Bicycle
 					+ E30_15*150000 	/// Car
 					+ E30_16*  2793 	/// Gold jewelry (SPECIFY AMOUNT IN SOVEREIGNS)
 					+ E30_17 			/// Cash (in Rs.)
 					if person=="daughter" // if E4==1 

* for sons, dowry = what his side received
replace dowry_calc 	= E31_1*   2240.82 	/// Bed
 					+ E31_2*   1329.16 	/// Bureau
 					+ E31_3*  10000 	/// Kitchen utensils - bronze 
 					+ E31_4*  20000 	/// Kitchen utensils - stainless steel 
 					+ E31_5*    736 	/// Grinder
 					+ E31_6*   1099 	/// Mixer
 					+ E31_7*   9890 	/// Fridge
 					+ E31_8*   5490 	/// TV
 					+ E31_9*   4150 	/// Microwave
 					+ E31_10*  3869 	/// Washing machine 
 					+ E31_11* 10000 	/// Silk saris 
 										/// Groceries - excluded because no way of attaching a valuation
 					+ E31_13* 11700 	/// Motorbike
 					+ E31_14*  3201.48 	/// Bicycle
 					+ E31_15*150000 	/// Car
 					+ E31_16*  2793 	/// Gold jewelry (SPECIFY AMOUNT IN SOVEREIGNS)
 					+ E31_17 			/// Cash (in Rs.)
 					if person=="son" // if E4==2 



replace dowry_calc = dowry_calc/1000
lab var dowry_calc "dowry calculated in '000s"

replace dowry      =.  	if generation!=3
replace dowry_calc =.  	if generation!=3

/*
	egen 	dowry_agg  = 	rowtotal(dowry dowry_calc)
	replace dowry_agg  =.  	if generation!=3
*/


