/*=========================================================================
Project: Wealth, marriage and sex selection
Author: Girija Borker, Jan Eeckhout, Nancy Luke, Shantidani Minz, Kaivan 
Munshi and Soumya Swaminathan. 
---------------------------------------------------------------------------
Do file: 6_4_predict_income.do

Use Girija's estimates for the relation of 1871 land revenues, caste (interaction) and current household income.
=========================================================================*/

	clear

	** create panchayat level data
	use "${raw}/TamilNadu-Habitations_Original.dta"
	drop HabitationCode HabitationName
	duplicates drop PanchNo, force
	save "${coded}/TamilNadu-Panchayats_Original.dta", replace
	
	*** Predict the relationship (coefficients) based on whole census  ***
	*------------------------------------------------------------------------------------------------------------------------------------------------

	// cap use "T:\VillageMatching\Girijas_IncomePredictionMatching.dta", clear
	// cap use "T:\VillageMatching\Girijas_Hist1871Matching.dta", clear

	if _N==0 { // only recreate the dataset above, if it could not be loaded

	/*
		// only execute via selection
		cd "T:\Historical Data (Girija's do files and data - Google Drive)"
		use "DataForReg.dta", clear

		br dd_landrev*
	*/

		use "${coded}/DataForReg.dta", clear

		keep if curr_hist_match==3 // villages for which we have both the historical and the current information

		* First stage
			duplicates drop HHid, force

		* (2a) Using hist_wealth1 "DD on account of land revenue per cultivated acre" 
		* alternative specification with clustering on caste and panchayat
		* only castes with at least 10 HH
			egen caste_A2 = group(caste A2)
			bys caste: egen count_caste = count(caste)
			xi: reg monthlyincome i.caste*hist_wealth1 i.A2 if count_caste>10, cluster(caste_A2)
			predict pred_income_cluster_vfe
			testparm hist_wealth1 _IcasXhist* _IA2* // F-stat 30.05			
			
			keep HHid pred_* numHH_caste*
				
			merge 1:m HHid using "${coded}/DataForReg.dta", keep(3) nogen

		count 								//  255,067
		count if missing(pred_income_cluster_vfe) 		// 	 43,055 	17% ni income predicted
		gen _missing_landrev = 1 	if missing(dd_landrev)
		gen Blockcode = substr(A2, 1, 1)
		
		*tab Blockcode if missing(pred_income), sort
		*tab Blockcode _missing_landrev, missing cell
		*tab taluk 	if missing(pred_income)
		*tab taluk 	// only wallajah Arcot and tirupattur in the study area

		*_________________________________________________________________________________________

		estimates store predict_income_from1871 	// store the coefficients from this regression
		*_________________________________________________________________________________________


		rename (A2 A3 A1 consecno villagename taluk) (p_code v_code nirt_no consecno_Girija villagename_Girija taluk_Girija)
		sort p_code v_code nirt_no

		keep p_code v_code nirt_no caste monthlyincome 	///
		 	consecno_Girija villagename_Girija taluk_Girija hist_wealth1


		// Note: consecno and Hist_Taluk should uniquely identify each village in hist 1871 data.

		save "${coded}/IncomePredictionMatching.dta" , replace

		keep p_code v_code consecno_Girija villagename_Girija taluk_Girija

		duplicates tag p_code v_code , gen(_dupl_pvcode)
		tab _dupl_pvcode

		duplicates drop

		replace taluk_Girija = "Arcot" /*11*/				if taluk=="Arcot"
		replace taluk_Girija = "Tripatoor" /*38*/ 		if taluk=="Tirupattur"
		replace taluk_Girija = "Wallajah Taluq" /*23*/ 	if taluk=="Wallajah"

		save "${coded}/Hist1871Matching.dta" , replace

	}
	
	use "${raw}/Predicted1871IncomeForSICHS.dta", clear


	/*** Predict income for census households based on their panchayat and caste  ***
	*------------------------------------------------------------------------------------------------------------------------------------------------
	
	* INTERNAL NOTE: THE FILE Girijas_Hist1871Matching.dta COULD NOT BE FOUND IN THE FOLDERS. THEREFORE, IT WAS DECIDED TO COMMENT THIS SECTION AND USE THE FINAL DATABASE CREATED HERE Predicted1871IncomeForSICHS.DTA
	
	*** Household Roster ***

	use "data/raw/ROSTER/HOUSEROSTER_P2.dta" , clear

	*** Recode castes ***
	do "code/coding/6_5_1_recoding_castes_survey.do"

	keep p_code v_code nirt_no caste

	duplicates drop 

	rename p_code pcode
	rename v_code vcode

	*** Panchayat codes to Village Masterlist ***
	cd "data/coded"
	do "$sexselection/code/coding/6_5_2_sichs_pv_codes_to_masterlist.do"

	assert !missing(Masterlist_ID)

	rename pcode p_code
	rename vcode v_code

	*** MERGE MASTERLIST to hist 1871 data matches ***

	* Towns/Villages *
	merge m:1 Masterlist_State Masterlist_District Masterlist_Subdistrict Masterlist_TownVillage  /// Masterlist_Level
	  using "$sexselection/data/raw/2017-11-17_Masterlist_hist1871_TownVillage_Matches_PRELIM.dta" , gen(_merge_hist1871_townvillage)  update replace // generated with (2)

	br   if _merge_hist1871_townvillage==2 	// these are towns, that were matched to hist1871, but are not IN the marital data?
	drop if _merge_hist1871_townvillage==2


	* Panchayats *
	merge m:1 Masterlist_State Masterlist_District Masterlist_Block Masterlist_Panchayat ///
	  using "2017-11-17_Masterlist_hist1871_Panchayats_Matches_PRELIM.dta" , gen(_merge_hist1871_panch)	 update // generated with (2)

	//br   if _merge_hist1871_panch==2
	drop if _merge_hist1871_panch==2

	tab _merge_hist1871* 	// 75% matched to historical villages. 180 hist. villages not matched !


	egen matched_hist1871=rowmax(_merge_hist1871*)
	tab matched_hist1871


	//br if matched_hist1871==1


	*** Merge with Girijas Matching *** 

	merge m:1 p_code v_code using "T:\VillageMatching\Girijas_Hist1871Matching.dta", gen(_merge_Girija)

	drop if _merge_Girija==2

	sort p_code v_code nirt_no caste

	gen 	same_1871taluk = 0	
	replace same_1871taluk = 1 		if Hist_Taluk==taluk_Girija

	gen 	same_1871consecno = 0
	replace same_1871consecno = 1 	if consecno==consecno_Girija

	gen 	same_1871match = 0
	replace same_1871match = 1 if same_1871taluk==1 & same_1871consecno==1


	tab _merge_Girija matched_hist1871, sum(same_1871taluk) means freq missing 

	tab _merge_Girija matched_hist1871, sum(same_1871match) means freq missing
	

	br if same_1871match==0

	br if missing(consecno) & !missing(consecno_Girija)

	br if missing(Hist_Taluk) & !missing(taluk_Girija)

	count if missing(consecno)  // 659

	replace consecno=6 	if missing(consecno) & id1871==6 // 39

	br if missing(consecno) & !missing(Hist_Taluk) 

	count if missing(Hist_Taluk) // 620

	*** Update with Girijas matches ***

	replace consecno = consecno_Girija 	if missing(consecno)
	replace Hist_Taluk = taluk_Girija 	if missing(Hist_Taluk)


	keep p_code v_code nirt_no caste consecno Hist_Taluk

	gen 	taluk1871=11 	if Hist_Taluk=="Arcot"
	replace taluk1871=38 	if Hist_Taluk=="Tripatoor"
	replace taluk1871=23 	if Hist_Taluk=="Wallajah Taluq"

	*** MERGE with hist data ***
	merge m:1 consecno taluk1871 using "data/raw/census1871_allvillages.dta" , gen(_merge1871)

	drop if _merge1871==2


	*** hist income data ***

	* The historical wealth statistic should be demand on account of land revenue divided by cultivated area.

	gen dd_landrev_a_in_rs = dd_landrev_a/16
	gen dd_landrev_p_in_rs = dd_landrev_p/192

	egen dd_landrev = rowtotal(dd_landrev_rs dd_landrev_a_in_rs dd_landrev_p_in_rs) , missing 	// if all are missing, only then set to missing
	
	replace dd_landrev=dd_landrev/1000 		// in Thousand Rupees

	// gen dd_landrev = (dd_landrev_rs + (dd_landrev_a/16) + (dd_landrev_p/192))/1000
	* 1 anna = 1/16 of a rupee
	* 1 pies = 1/192 of a rupee (old paisa, pre-1950) - not paisa

	label var dd_landrev "DD on account of land revenue"

	* dividing by area occupied for cultivation
	gen hist_wealth1 = dd_landrev/areaoccupiedforcultivation
	lab var hist_wealth1 "DD on account of land revenue per cultivated acre"

	// dd_landrev = rowtotal( (dd_landrev_rs+ (dd_landrev_a/16) + (dd_landrev_p/192))/1000 ) 



	// create caste dummies to apply estimates
	forvalues i=1/68 {

		gen 	_Icaste_`i' = 0 				// caste indicator
		replace _Icaste_`i' = 1 				if caste==`i'

		gen 	_IcasXhist_`i' = 0 				// caste X hist wealth interaction
		replace _IcasXhist_`i' = hist_wealth1 	if caste==`i'

	}

	*** predict income ***

	estimates restore predict_income_from1871

	predict predicted1871income


	sum predicted1871income, detail
		hist predicted1871income if predicted1871income>-50 & predicted1871income<100

	count if missing(predicted1871income)

	duplicates tag p_code v_code nirt_no, gen(_duplHH)

	tab _duplHH
	br if _duplHH > 0

	keep p_code v_code nirt_no caste predicted1871income

	save "data/coded/Predicted1871IncomeForSICHS.dta" , replace 
*/